@@ -16,15 +16,16 @@
 #include "H5Include.h"
 #include "H5Exception.h"
 #include "H5IdComponent.h"
+#include "H5DataSpace.h"
 #include "H5PropList.h"
-#include "H5StrcreatProp.h"
+#include "H5OcreatProp.h"
+#include "H5DcreatProp.h"
 #include "H5LcreatProp.h"
 #include "H5LaccProp.h"
+#include "H5DaccProp.h"
 #include "H5Location.h"
 #include "H5Object.h"
 #include "H5DataType.h"
-#include "H5OcreatProp.h"
-#include "H5DcreatProp.h"
 
 namespace H5 {
 
@@ -77,8 +78,7 @@ DSetCreatPropList::getConstant()
 void
 DSetCreatPropList::deleteConstants()
 {
-    if (DEFAULT_ != 0)
-        delete DEFAULT_;
+    delete DEFAULT_;
 }
 
 //--------------------------------------------------------------------------
@@ -99,7 +99,7 @@ DSetCreatPropList::DSetCreatPropList() : ObjCreatPropList(H5P_DATASET_CREATE)
 
 //--------------------------------------------------------------------------
 // Function:    DSetCreatPropList copy constructor
-///\brief       Copy constructor: makes a copy of the original
+///\brief       Copy constructor: same HDF5 object as \a original
 ///             DSetCreatPropList object
 // Programmer   Binh-Minh Ribler - 2000
 //--------------------------------------------------------------------------
@@ -166,8 +166,8 @@ DSetCreatPropList::getChunk(int max_ndims, hsize_t *dim) const
 ///\param       layout - IN: Type of storage layout for raw data
 ///\exception   H5::PropListIException
 ///\par Description
-///             For information on valid layout types, please refer to
-/// https://support.hdfgroup.org/HDF5/doc/RM/RM_H5P.html#Property-SetLayout
+///             For information, please refer to the H5Pset_layout API in
+///             the HDF5 C Reference Manual.
 // Programmer   Binh-Minh Ribler - 2000
 //--------------------------------------------------------------------------
 void
@@ -238,9 +238,8 @@ DSetCreatPropList::setDeflate(int level) const
 ///\par Description
 ///             The associate C function sets an SZIP compression filter,
 ///             H5Z_FILTER_SZIP, for a dataset.  For more information about
-///             SZIP and usage, please refer to the C layer Reference
-///             Manual at:
-/// https://support.hdfgroup.org/HDF5/doc/RM_H5P.html#Property-SetSzip
+///             SZIP and usage, please refer to the H5Pset_szip API in
+///             the HDF5 C Reference Manual.
 // Programmer   Binh-Minh Ribler - Jan, 2007
 //--------------------------------------------------------------------------
 void
@@ -256,12 +255,12 @@ DSetCreatPropList::setSzip(unsigned int options_mask, unsigned int pixels_per_bl
 // Function:    DSetCreatPropList::setNbit
 ///\brief       Sets up for the use of the Nbit compression filter.
 ///\exception   H5::PropListIException
+///
 ///\par Description
 ///             The associate C function sets an Nbit compression filter,
 ///             H5Z_FILTER_NBIT, for a dataset.  For more information about
-///             Nbit compression, please refer to the C layer Reference
-///             Manual at:
-/// https://support.hdfgroup.org/HDF5/doc/RM/RM_H5P.html#Property-setNbit
+///             Nbit compression, please refer to the H5Pset_nbit API in
+///             the HDF5 C Reference Manual.
 // Programmer   Binh-Minh Ribler - Apr, 2016
 //--------------------------------------------------------------------------
 void
@@ -287,8 +286,7 @@ DSetCreatPropList::setNbit() const
 ///             according to the actual dataset datatype.
 ///\par
 ///             For information on setting fill value, please refer to the
-///             C layer Reference Manual at:
-/// https://support.hdfgroup.org/HDF5/doc/RM/RM_H5P.html#Property-SetFillValue
+///             H5Pset_fill_value API in the HDF5 C Reference Manual.
 // Programmer   Binh-Minh Ribler - 2000
 //--------------------------------------------------------------------------
 void
@@ -534,9 +532,8 @@ DSetCreatPropList::allFiltersAvail() const
 ///
 ///\exception   H5::PropListIException
 ///\par Description
-///             Please refer to the Reference Manual of \c H5Pset_shuffle for
-///             details.
-/// https://support.hdfgroup.org/HDF5/doc/RM/RM_H5P.html#Property-SetShuffle
+///             For information, please refer to the H5Pset_shuffle API in
+///             the HDF5 C Reference Manual.
 // Programmer   Binh-Minh Ribler - 2000
 //--------------------------------------------------------------------------
 void
@@ -555,7 +552,7 @@ DSetCreatPropList::setShuffle() const
 ///\exception   H5::PropListIException
 ///\par Description
 ///             The values of space allocation time can be one of the
-///             followings:
+///             following:
 ///             \li \c H5D_ALLOC_TIME_DEFAULT
 ///             \li \c H5D_ALLOC_TIME_EARLY
 ///             \li \c H5D_ALLOC_TIME_LATE
@@ -663,7 +660,7 @@ DSetCreatPropList::setFletcher32() const
 ///\param       size   - IN: Number of bytes reserved in the file for the data
 ///\exception   H5::PropListIException
 ///\par Description
-///             If a dataset is splitted across multiple files then the files
+///             If a dataset is split across multiple files then the files
 ///             should be defined in order. The total size of the dataset is
 ///             the sum of the \a size arguments for all the external files.  If
 ///             the total size is larger than the size of a dataset then the
@@ -730,6 +727,59 @@ DSetCreatPropList::getExternal(unsigned idx, size_t name_size, char *name, off_t
     }
 }
 
+//--------------------------------------------------------------------------
+// Function:    DSetCreatPropList::setVirtual
+///\brief       Maps elements of a virtual dataset to elements of the source
+///             dataset.
+///\param       vspace     - IN: Dataspace the virtual dataset, possibly an
+///                             unlimited selection
+///\param       src_fname  - IN: Name of the HDF5 file where the source dataset
+///                             is located (\a char*)
+///\param       src_dsname - IN: Path to the dataset in the file specified by
+///                             \a src_file_name (\a char*)
+///\param       sspace     - IN: Dataspace with a selection applied, possibly
+///                             an unlimited selection
+///\exception   H5::PropListIException
+///\par Description
+///             For information, please refer to the H5Pset_virtual API in
+///             the HDF5 C Reference Manual.
+// Programmer   Binh-Minh Ribler - Mar, 2017
+//--------------------------------------------------------------------------
+void
+DSetCreatPropList::setVirtual(const DataSpace &vspace, const char *src_fname, const char *src_dsname,
+                              const DataSpace &sspace) const
+{
+    herr_t ret_value = H5Pset_virtual(id, vspace.getId(), src_fname, src_dsname, sspace.getId());
+    if (ret_value < 0) {
+        throw PropListIException("DSetCreatPropList::setVirtual", "H5Pset_virtual failed");
+    }
+}
+
+//--------------------------------------------------------------------------
+// Function:    DSetCreatPropList::setVirtual
+///\brief       Maps elements of a virtual dataset to elements of the source
+///             dataset.
+///\param       vspace     - IN: Dataspace the virtual dataset, possibly an
+///                             unlimited selection
+///\param       src_fname  - IN: Name of the HDF5 file where the source dataset
+///                             is located (\a H5std_string)
+///\param       src_dsname - IN: Path to the dataset in the file specified by
+///                             \a src_file_name (\a H5std_string)
+///\param       sspace     - IN: Dataspace with a selection applied, possibly
+///                             an unlimited selection
+///\exception   H5::PropListIException
+///\par Description
+///             For information, please refer to the H5Pset_virtual API in
+///             the HDF5 C Reference Manual.
+// Programmer   Binh-Minh Ribler - Mar, 2017
+//--------------------------------------------------------------------------
+void
+DSetCreatPropList::setVirtual(const DataSpace &vspace, const H5std_string src_fname,
+                              const H5std_string src_dsname, const DataSpace &sspace) const
+{
+    setVirtual(vspace, src_fname.c_str(), src_dsname.c_str(), sspace);
+}
+
 //--------------------------------------------------------------------------
 // Function:    DSetCreatPropList destructor
 ///\brief       Noop destructor.
