@@ -11,9 +11,9 @@
  * help@hdfgroup.org.                                                        *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 
+#include <cstring>
 #include <string>
 
-#include "H5private.h" // for HDmemset
 #include "H5Include.h"
 #include "H5Exception.h"
 #include "H5IdComponent.h"
@@ -72,8 +72,7 @@ DSetMemXferPropList::getConstant()
 void
 DSetMemXferPropList::deleteConstants()
 {
-    if (DEFAULT_ != 0)
-        delete DEFAULT_;
+    delete DEFAULT_;
 }
 
 //--------------------------------------------------------------------------
@@ -87,7 +86,7 @@ const DSetMemXferPropList &DSetMemXferPropList::DEFAULT = *getConstant();
 // Function     DSetMemXferPropList default constructor
 ///\brief       Default constructor: creates a stub dataset memory and
 ///             transfer property list object.
-// Programmer:  Binh-Minh Ribler - 2000
+// Programmer   Binh-Minh Ribler - 2000
 //--------------------------------------------------------------------------
 DSetMemXferPropList::DSetMemXferPropList() : PropList(H5P_DATASET_XFER)
 {
@@ -97,7 +96,7 @@ DSetMemXferPropList::DSetMemXferPropList() : PropList(H5P_DATASET_XFER)
 // Function     DSetMemXferPropList constructor
 ///\brief       Creates a dataset transfer property list with transform
 ///             expression.
-// March 2014
+// Programmer   Binh-Minh Ribler - 2000
 //--------------------------------------------------------------------------
 DSetMemXferPropList::DSetMemXferPropList(const char *exp) : PropList(H5P_DATASET_XFER)
 {
@@ -106,11 +105,11 @@ DSetMemXferPropList::DSetMemXferPropList(const char *exp) : PropList(H5P_DATASET
 
 //--------------------------------------------------------------------------
 // Function     DSetMemXferPropList copy constructor
-///\brief       Copy constructor: makes a copy of the original
+///\brief       Copy constructor: same HDF5 object as \a original
 ///             DSetMemXferPropList object
 ///\param       original - IN: Original dataset memory and transfer property
-///                             list object to copy
-// Programmer:  Binh-Minh Ribler - 2000
+///                            list object to copy
+// Programmer   Binh-Minh Ribler - 2000
 //--------------------------------------------------------------------------
 DSetMemXferPropList::DSetMemXferPropList(const DSetMemXferPropList &original) : PropList(original)
 {
@@ -121,8 +120,8 @@ DSetMemXferPropList::DSetMemXferPropList(const DSetMemXferPropList &original) :
 ///\brief       Creates a DSetMemXferPropList object using the id of an
 ///             existing DSetMemXferPropList.
 ///\param       plist_id - IN: Id of an existing dataset memory and transfer
-///                             property list
-// Programmer:  Binh-Minh Ribler - 2000
+///                            property list
+// Programmer   Binh-Minh Ribler - 2000
 //--------------------------------------------------------------------------
 DSetMemXferPropList::DSetMemXferPropList(const hid_t plist_id) : PropList(plist_id)
 {
@@ -135,7 +134,7 @@ DSetMemXferPropList::DSetMemXferPropList(const hid_t plist_id) : PropList(plist_
 ///\param       tconv - IN: Pointer to application-allocated type conversion buffer
 ///\param       bkg   - IN: Pointer to application-allocated background buffer
 ///\exception   H5::PropListIException
-// Programmer:  Binh-Minh Ribler - 2000
+// Programmer   Binh-Minh Ribler - 2000
 //--------------------------------------------------------------------------
 void
 DSetMemXferPropList::setBuffer(size_t size, void *tconv, void *bkg) const
@@ -153,7 +152,7 @@ DSetMemXferPropList::setBuffer(size_t size, void *tconv, void *bkg) const
 ///\param       bkg   - OUT: Pointer to application-allocated background buffer
 ///\return      Buffer size, in bytes
 ///\exception   H5::PropListIException
-// Programmer:  Binh-Minh Ribler - 2000
+// Programmer   Binh-Minh Ribler - 2000
 //--------------------------------------------------------------------------
 size_t
 DSetMemXferPropList::getBuffer(void **tconv, void **bkg) const
@@ -171,12 +170,12 @@ DSetMemXferPropList::getBuffer(void **tconv, void **bkg) const
 ///\brief       Sets the dataset transfer property list status to true or false.
 ///\param       status - IN: Status to set, true or false
 ///\exception   H5::PropListIException
-// Programmer:  Binh-Minh Ribler - 2000
+// Programmer   Binh-Minh Ribler - 2000
 //--------------------------------------------------------------------------
 void
 DSetMemXferPropList::setPreserve(bool status) const
 {
-    herr_t ret_value = H5Pset_preserve(id, (hbool_t)status);
+    herr_t ret_value = H5Pset_preserve(id, static_cast<hbool_t>(status));
     if (ret_value < 0) {
         throw PropListIException("DSetMemXferPropList::setPreserve", "H5Pset_preserve failed");
     }
@@ -187,7 +186,7 @@ DSetMemXferPropList::setPreserve(bool status) const
 ///\brief       Checks status of the dataset transfer property list.
 ///\return      Status of the dataset transfer property list
 ///\exception   H5::PropListIException
-// Programmer:  Binh-Minh Ribler - 2000
+// Programmer   Binh-Minh Ribler - 2000
 //--------------------------------------------------------------------------
 bool
 DSetMemXferPropList::getPreserve() const
@@ -210,7 +209,7 @@ DSetMemXferPropList::getPreserve() const
 ///\param       middle - IN: B-tree split ratio for right-most nodes and lone nodes
 ///\param       right  - IN: B-tree split ratio for all other nodes
 ///\exception   H5::PropListIException
-// Programmer:  Binh-Minh Ribler - 2000
+// Programmer   Binh-Minh Ribler - 2000
 //--------------------------------------------------------------------------
 void
 DSetMemXferPropList::setBtreeRatios(double left, double middle, double right) const
@@ -228,7 +227,7 @@ DSetMemXferPropList::setBtreeRatios(double left, double middle, double right) co
 ///\param       middle - OUT: B-tree split ratio for right-most nodes and lone nodes
 ///\param       right  - OUT: B-tree split ratio for all other nodes
 ///\exception   H5::PropListIException
-// Programmer:  Binh-Minh Ribler - 2000
+// Programmer   Binh-Minh Ribler - 2000
 //--------------------------------------------------------------------------
 void
 DSetMemXferPropList::getBtreeRatios(double &left, double &middle, double &right) const
@@ -244,7 +243,7 @@ DSetMemXferPropList::getBtreeRatios(double &left, double &middle, double &right)
 ///\brief       Sets data transform expression.
 ///\param       expression - IN: null-terminated data transform expression (char*)
 ///\exception   H5::PropListIException
-// Programmer:  Binh-Minh Ribler - Mar, 2014
+// Programmer   Binh-Minh Ribler - Mar, 2014
 //--------------------------------------------------------------------------
 void
 DSetMemXferPropList::setDataTransform(const char *expression) const
@@ -261,7 +260,7 @@ DSetMemXferPropList::setDataTransform(const char *expression) const
 ///             It takes a reference to a \c H5std_string for the expression.
 ///\param       expression - IN: H5std_string data transform expression
 ///\exception   H5::PropListIException
-// Programmer:  Binh-Minh Ribler - Mar, 2014
+// Programmer   Binh-Minh Ribler - Mar, 2014
 //--------------------------------------------------------------------------
 void
 DSetMemXferPropList::setDataTransform(const H5std_string &expression) const
@@ -276,7 +275,7 @@ DSetMemXferPropList::setDataTransform(const H5std_string &expression) const
 ///\param       buf_size   - IN: size of buffer for expression, including the
 ///                              null terminator
 ///\exception   H5::PropListIException
-// Programmer:  Binh-Minh Ribler - Mar, 2014
+// Programmer   Binh-Minh Ribler - Mar, 2014
 //--------------------------------------------------------------------------
 ssize_t
 DSetMemXferPropList::getDataTransform(char *exp, size_t buf_size) const
@@ -305,17 +304,17 @@ DSetMemXferPropList::getDataTransform(char *exp, size_t buf_size) const
 ///             It takes no parameter and returns a \c H5std_string for the expression.
 ///
 ///\exception   H5::PropListIException
-// Programmer:  Binh-Minh Ribler - Mar, 2014
+// Programmer   Binh-Minh Ribler - Mar, 2014
 //--------------------------------------------------------------------------
 H5std_string
 DSetMemXferPropList::getDataTransform() const
 {
     // Initialize string to "", so that if there is no expression, the returned
     // string will be empty
-    H5std_string expression("");
+    H5std_string expression;
 
     // Preliminary call to get the expression's length
-    ssize_t exp_len = H5Pget_data_transform(id, NULL, (size_t)0);
+    ssize_t exp_len = H5Pget_data_transform(id, NULL, 0);
 
     // If H5Pget_data_transform returns a negative value, raise an exception
     if (exp_len < 0) {
@@ -326,7 +325,7 @@ DSetMemXferPropList::getDataTransform() const
     else if (exp_len > 0) {
         // Temporary buffer for char* expression
         char *exp_C = new char[exp_len + 1];
-        HDmemset(exp_C, 0, exp_len + 1); // clear buffer
+        memset(exp_C, 0, exp_len + 1);
 
         // Used overloaded function
         exp_len = getDataTransform(exp_C, exp_len + 1);
@@ -348,7 +347,7 @@ DSetMemXferPropList::getDataTransform() const
 ///\param       op        - IN: User's function
 ///\param       user_data - IN: User's data
 ///\exception   H5::PropListIException
-// Programmer:  Binh-Minh Ribler - April, 2004
+// Programmer   Binh-Minh Ribler - April, 2004
 //--------------------------------------------------------------------------
 void
 DSetMemXferPropList::setTypeConvCB(H5T_conv_except_func_t op, void *user_data) const
@@ -365,7 +364,7 @@ DSetMemXferPropList::setTypeConvCB(H5T_conv_except_func_t op, void *user_data) c
 ///\param       op        - IN: Retrieved user function
 ///\param       user_data - IN: Retrieved user data
 ///\exception   H5::PropListIException
-// Programmer:  Binh-Minh Ribler - April, 2004
+// Programmer   Binh-Minh Ribler - April, 2004
 //--------------------------------------------------------------------------
 void
 DSetMemXferPropList::getTypeConvCB(H5T_conv_except_func_t *op, void **user_data) const
@@ -384,7 +383,7 @@ DSetMemXferPropList::getTypeConvCB(H5T_conv_except_func_t *op, void **user_data)
 ///\param       free_func  - IN: User's free routine
 ///\param       free_info  - IN: User's free parameters
 ///\exception   H5::PropListIException
-// Programmer:  Binh-Minh Ribler - 2000
+// Programmer   Binh-Minh Ribler - 2000
 //--------------------------------------------------------------------------
 void
 DSetMemXferPropList::setVlenMemManager(H5MM_allocate_t alloc_func, void *alloc_info, H5MM_free_t free_func,
@@ -402,7 +401,7 @@ DSetMemXferPropList::setVlenMemManager(H5MM_allocate_t alloc_func, void *alloc_i
 ///             allocation - system \c malloc and \c free will be used.
 ///
 ///\exception   H5::PropListIException
-// Programmer:  Binh-Minh Ribler - 2000
+// Programmer   Binh-Minh Ribler - 2000
 //--------------------------------------------------------------------------
 void
 DSetMemXferPropList::setVlenMemManager() const
@@ -418,7 +417,7 @@ DSetMemXferPropList::setVlenMemManager() const
 ///\param       free_func  - OUT: User's free routine
 ///\param       free_info  - OUT: User's free parameters
 ///\exception   H5::PropListIException
-// Programmer:  Binh-Minh Ribler - 2000
+// Programmer   Binh-Minh Ribler - 2000
 //--------------------------------------------------------------------------
 void
 DSetMemXferPropList::getVlenMemManager(H5MM_allocate_t &alloc_func, void **alloc_info, H5MM_free_t &free_func,
@@ -436,9 +435,9 @@ DSetMemXferPropList::getVlenMemManager(H5MM_allocate_t &alloc_func, void **alloc
 ///\param       size - IN: Maximum size, in bytes, of the small data block.
 ///\exception   H5::PropListIException
 ///\par Description
-///             For detail, please refer to the C layer Reference Manual at:
-/// https://support.hdfgroup.org/HDF5/doc/RM/RM_H5P.html#Property-SetSmallData
-// Programmer:  Binh-Minh Ribler - April, 2004
+///             For detail, please refer to the H5Pset_small_data_block_size
+///             API in the HDF5 C Reference Manual.
+// Programmer   Binh-Minh Ribler - April, 2004
 //--------------------------------------------------------------------------
 void
 DSetMemXferPropList::setSmallDataBlockSize(hsize_t size) const
@@ -455,7 +454,7 @@ DSetMemXferPropList::setSmallDataBlockSize(hsize_t size) const
 ///\brief       Returns the current small data block size setting.
 ///\return      Size of the small data block, in bytes
 ///\exception   H5::PropListIException
-// Programmer:  Binh-Minh Ribler - April, 2004
+// Programmer   Binh-Minh Ribler - April, 2004
 //--------------------------------------------------------------------------
 hsize_t
 DSetMemXferPropList::getSmallDataBlockSize() const
@@ -475,10 +474,9 @@ DSetMemXferPropList::getSmallDataBlockSize() const
 ///
 ///\exception   H5::PropListIException
 ///\par Description
-///             For information, please refer to the C layer Reference
-///             Manual at:
-/// https://support.hdfgroup.org/HDF5/doc/RM/RM_H5P.html#Property-SetHyperVectorSize
-// Programmer:  Binh-Minh Ribler - April, 2004
+///             For detail, please refer to the H5Pset_hyper_vector_size
+///             API in the HDF5 C Reference Manual.
+// Programmer   Binh-Minh Ribler - April, 2004
 //--------------------------------------------------------------------------
 void
 DSetMemXferPropList::setHyperVectorSize(size_t vector_size) const
@@ -496,7 +494,7 @@ DSetMemXferPropList::setHyperVectorSize(size_t vector_size) const
 ///             hyperslab I/O.
 ///\return      Number of I/O vectors
 ///\exception   H5::PropListIException
-// Programmer:  Binh-Minh Ribler - April, 2004
+// Programmer   Binh-Minh Ribler - April, 2004
 //--------------------------------------------------------------------------
 size_t
 DSetMemXferPropList::getHyperVectorSize() const
@@ -515,7 +513,7 @@ DSetMemXferPropList::getHyperVectorSize() const
 ///\brief       Enables or disables error-detecting for a dataset reading
 ///             process.
 ///\param       check - IN: Specifies whether error detection is enabled or
-///                             disabled
+///                         disabled
 ///\exception   H5::PropListIException
 ///\par Description
 ///             The error detection algorithm used is the algorithm previously
@@ -526,7 +524,7 @@ DSetMemXferPropList::getHyperVectorSize() const
 ///             Valid values are as follows:
 ///             \li \c H5Z_ENABLE_EDC   (default)
 ///             \li \c H5Z_DISABLE_EDC
-// Programmer:  Binh-Minh Ribler - April, 2004
+// Programmer   Binh-Minh Ribler - April, 2004
 //--------------------------------------------------------------------------
 void
 DSetMemXferPropList::setEDCCheck(H5Z_EDC_t check) const
@@ -542,7 +540,7 @@ DSetMemXferPropList::setEDCCheck(H5Z_EDC_t check) const
 ///\brief       Determines whether error-detection is enabled for dataset reads.
 ///\return      \c H5Z_ENABLE_EDC or \c H5Z_DISABLE_EDC
 ///\exception   H5::PropListIException
-// Programmer:  Binh-Minh Ribler - April, 2004
+// Programmer   Binh-Minh Ribler - April, 2004
 //--------------------------------------------------------------------------
 H5Z_EDC_t
 DSetMemXferPropList::getEDCCheck() const
