@@ -18,6 +18,12 @@
 
 #define RANK 2
 
+/* For superblock version 0, 1: the offset to "file consistency flags" is 20 with size of 4 bytes */
+/* The file consistency flags is the "status_flags" field in H5F_super_t */
+/* Note: the offset and size will be different when using superblock version 2 for the test file */
+#define SUPER_STATUS_FLAGS_OFF_V0_V1  20
+#define SUPER_STATUS_FLAGS_SIZE_V0_V1 4
+
 /* Test of file image operations.
 
    The following code provides a means to thoroughly test the file image
@@ -45,9 +51,9 @@
  *-------------------------------------------------------------------------
  */
 static int
-test_file_image(size_t open_images, size_t nflags, unsigned *flags)
+test_file_image(size_t open_images, size_t nflags, const unsigned *flags)
 {
-    hid_t  *file_id = NULL, *dset_id = NULL, file_space, plist; /* HDF5 ids */
+    hid_t * file_id = NULL, *dset_id = NULL, file_space, plist; /* HDF5 ids */
     hsize_t dims1[RANK]    = {2, 3};                            /* original dimension of datasets */
     hsize_t max_dims[RANK] = {H5S_UNLIMITED, H5S_UNLIMITED};
     int     data1[6]       = {1, 2, 3, 4, 5, 6};    /* original contents of dataset */
@@ -57,13 +63,13 @@ test_file_image(size_t open_images, size_t nflags, unsigned *flags)
     hsize_t dims4[RANK] = {3, 5};                   /* extended dimensions of datasets */
     int     data4[15]   = {1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15};
     /* extended contents of dataset */
-    ssize_t        *buf_size    = NULL; /* pointer to array of buffer sizes */
-    void          **buf_ptr     = NULL; /* pointer to array of pointers to image buffers */
-    char          **filename    = NULL; /* pointer to array of pointers to filenames */
-    unsigned       *input_flags = NULL; /* pointer to array of flag combinations */
+    ssize_t *       buf_size    = NULL; /* pointer to array of buffer sizes */
+    void **         buf_ptr     = NULL; /* pointer to array of pointers to image buffers */
+    char **         filename    = NULL; /* pointer to array of pointers to filenames */
+    unsigned *      input_flags = NULL; /* pointer to array of flag combinations */
     size_t          i, j, k, nrow, n_values;
     herr_t          status1;
-    void           *handle_ptr       = NULL; /* pointers to driver buffer */
+    void *          handle_ptr       = NULL; /* pointers to driver buffer */
     unsigned char **core_buf_ptr_ptr = NULL;
 
     VERIFY(open_images > 1, "The number of open images must be greater than 1");
@@ -79,7 +85,7 @@ test_file_image(size_t open_images, size_t nflags, unsigned *flags)
         FAIL_PUTS_ERROR("malloc() failed");
 
     /* allocate array to store the name of each of the open images */
-    if (NULL == (filename = (char **)HDmalloc(sizeof(char *) * open_images)))
+    if (NULL == (filename = (char **)HDcalloc(1, sizeof(char *) * open_images)))
         FAIL_PUTS_ERROR("malloc() failed");
 
     /* allocate array to store the size of each of the open images */
@@ -103,10 +109,13 @@ test_file_image(size_t open_images, size_t nflags, unsigned *flags)
         input_flags[i] = flags[(nflags + i) % nflags];
 
         /* allocate name buffer for image i */
-        filename[i] = (char *)HDmalloc(sizeof(char) * 32);
+        size_t filenamelength = sizeof(char) * 32;
+        filename[i]           = (char *)HDmalloc(filenamelength);
+        if (!filename[i])
+            FAIL_PUTS_ERROR("HDmalloc() failed");
 
         /* create file name */
-        HDsprintf(filename[i], "image_file%d.h5", (int)i);
+        HDsnprintf(filename[i], filenamelength, "image_file%d.h5", (int)i);
 
         /* create file */
         if ((file_id[i] = H5Fcreate(filename[i], H5F_ACC_TRUNC, H5P_DEFAULT, H5P_DEFAULT)) < 0)
@@ -216,10 +225,39 @@ test_file_image(size_t open_images, size_t nflags, unsigned *flags)
             else
                 VERIFY(*core_buf_ptr_ptr != buf_ptr[i], "vfd buffer and user buffer should be different");
 
-            /* test whether the contents of the user buffer and driver buffer */
-            /* are equal.                                                     */
-            if (HDmemcmp(*core_buf_ptr_ptr, buf_ptr[i], (size_t)buf_size[i]) != 0)
-                FAIL_PUTS_ERROR("comparison of vfd and user buffer failed");
+            /*
+             *  When the vfd and user buffers are different and H5LT_FILE_IMAGE_OPEN_RW is enabled,
+             *  status_flags in the superblock needs to be cleared in the vfd buffer for
+             *  the comparison to proceed as expected.  The user buffer as returned from H5Fget_file_image()
+             *  has already cleared status_flags.  The superblock's status_flags is used for the
+             *  implementation of file locking.
+             */
+            if (input_flags[i] & H5LT_FILE_IMAGE_OPEN_RW && !(input_flags[i] & H5LT_FILE_IMAGE_DONT_COPY)) {
+
+                void *tmp_ptr = HDmalloc((size_t)buf_size[i]);
+                if (!tmp_ptr)
+                    FAIL_PUTS_ERROR("buffer allocation failed");
+
+                /* Copy vfd buffer to a temporary buffer */
+                HDmemcpy(tmp_ptr, (void *)*core_buf_ptr_ptr, (size_t)buf_size[i]);
+                /* Clear status_flags in the superblock for the vfd buffer: file locking is using status_flags
+                 */
+                HDmemset((uint8_t *)tmp_ptr + SUPER_STATUS_FLAGS_OFF_V0_V1, (int)0,
+                         (size_t)SUPER_STATUS_FLAGS_SIZE_V0_V1);
+                /* Does the comparison */
+                if (HDmemcmp(tmp_ptr, buf_ptr[i], (size_t)buf_size[i]) != 0)
+                    FAIL_PUTS_ERROR("comparison of TMP vfd and user buffer failed");
+                /* Free the temporary buffer */
+                if (tmp_ptr)
+                    HDfree(tmp_ptr);
+            }
+            else {
+
+                /* test whether the contents of the user buffer and driver buffer */
+                /* are equal.                                                     */
+                if (HDmemcmp(*core_buf_ptr_ptr, buf_ptr[i], (size_t)buf_size[i]) != 0)
+                    FAIL_PUTS_ERROR("comparison of vfd and user buffer failed");
+            }
         } /* end else */
     }     /* end for */
 
@@ -379,7 +417,9 @@ test_file_image(size_t open_images, size_t nflags, unsigned *flags)
                     H5Aclose(attr_id);
                 } H5E_END_TRY;
 #endif
-                file_id[i] = -1;
+                if (H5Dclose(dset_id[i]) < 0)
+                    FAIL_PUTS_ERROR("H5Dclose() failed");
+                dset_id[i] = -1;
             } /* end if */
             else {
                 /* write dataset without extending it */
@@ -408,7 +448,7 @@ test_file_image(size_t open_images, size_t nflags, unsigned *flags)
     /* read open file images and verify data */
     for (i = 0; i < open_images; i++) {
         /* if opening the file image failed, continue next iteration */
-        if ((file_id[i] < 0) || (!(input_flags[i] & H5LT_FILE_IMAGE_OPEN_RW)))
+        if ((dset_id[i] < 0) || (file_id[i] < 0) || (!(input_flags[i] & H5LT_FILE_IMAGE_OPEN_RW)))
             continue;
 
         /* open dataset in file image */
@@ -475,6 +515,8 @@ test_file_image(size_t open_images, size_t nflags, unsigned *flags)
     } /* end for */
 
     /* release temporary working buffers */
+    for (i = 0; i < open_images; i++)
+        HDfree(filename[i]);
     HDfree(filename);
     HDfree(file_id);
     HDfree(dset_id);
@@ -489,6 +531,17 @@ test_file_image(size_t open_images, size_t nflags, unsigned *flags)
     return 0;
 
 error:
+    if (filename) {
+        for (i = 0; i < open_images; i++)
+            HDfree(filename[i]);
+        HDfree(filename);
+    }
+    HDfree(file_id);
+    HDfree(dset_id);
+    HDfree(buf_ptr);
+    HDfree(buf_size);
+    HDfree(input_flags);
+
     H5_FAILED();
     return -1;
 }
