@@ -219,7 +219,7 @@ test_simple(void)
      *-------------------------------------------------------------------------
      */
 
-    HL_TESTING2("pallete functions");
+    HL_TESTING2("palette functions");
 
     if (H5IMget_npalettes(fid, IMAGE1_NAME, &npals) < 0)
         goto out;
@@ -422,7 +422,7 @@ test_data(void)
 
     /*-------------------------------------------------------------------------
      * palette #4. blue-red
-     * make a palette whith blue to red colors
+     * make a palette with blue to red colors
      *-------------------------------------------------------------------------
      */
     for (i = 0, n = 0; i < 256 * 3; i += 3, n++) {
@@ -580,11 +580,11 @@ test_generate(void)
     !
     */
 
-    if (fscanf(f, "%d %d %d", &imax, &jmax, &kmax) < 0 && HDferror(f)) {
+    if (HDfscanf(f, "%d %d %d", &imax, &jmax, &kmax) < 0 && HDferror(f)) {
         HDprintf("fscanf error in file %s.\n", data_file);
         goto out;
     } /* end if */
-    if (fscanf(f, "%f %f %f", &valex, &xmin, &xmax) < 0 && HDferror(f)) {
+    if (HDfscanf(f, "%f %f %f", &valex, &xmin, &xmax) < 0 && HDferror(f)) {
         HDprintf("fscanf error in file %s.\n", data_file);
         goto out;
     } /* end if */
@@ -615,7 +615,7 @@ test_generate(void)
         goto out;
 
     for (i = 0; i < n_elements; i++) {
-        if (fscanf(f, "%f ", &value) < 0 && HDferror(f)) {
+        if (HDfscanf(f, "%f ", &value) < 0 && HDferror(f)) {
             HDprintf("fscanf error in file %s.\n", data_file);
             goto out;
         } /* end if */
@@ -650,10 +650,10 @@ test_generate(void)
     HL_TESTING2("make indexed image from land data");
 
     for (i = 0; i < n_elements; i++) {
-        if (data[i] < 0)
+        if (data[i] < 0.0F)
             image_data[i] = 0;
         else
-            image_data[i] = (unsigned char)((255 * (data[i])) / xmax);
+            image_data[i] = (unsigned char)((255 * data[i]) / xmax);
     }
 
     /* make the image */
@@ -671,10 +671,11 @@ test_generate(void)
     HL_TESTING2("make indexed image from sea data");
 
     for (i = 0; i < n_elements; i++) {
-        if (data[i] > 0)
+        if (data[i] > 0.0F)
             image_data[i] = 0;
-        else
-            image_data[i] = (unsigned char)((255 * (data[i] - xmin)) / xmin);
+        else {
+            image_data[i] = (unsigned char)((255.0F * (data[i] - xmin)) / (xmax - xmin));
+        }
     }
 
     /* make the image */
@@ -778,32 +779,32 @@ read_data(const char *fname, /*IN*/
         goto out;
     }
 
-    if (fscanf(f, "%s", str) < 0 && HDferror(f)) {
+    if (HDfscanf(f, "%s", str) < 0 && HDferror(f)) {
         HDprintf("fscanf error in file %s.\n", data_file);
         goto out;
     } /* end if */
 
-    if (fscanf(f, "%d", &color_planes) < 0 && HDferror(f)) {
+    if (HDfscanf(f, "%d", &color_planes) < 0 && HDferror(f)) {
         HDprintf("fscanf error in file %s.\n", data_file);
         goto out;
     } /* end if */
 
-    if (fscanf(f, "%s", str) < 0 && HDferror(f)) {
+    if (HDfscanf(f, "%s", str) < 0 && HDferror(f)) {
         HDprintf("fscanf error in file %s.\n", data_file);
         goto out;
     } /* end if */
 
-    if (fscanf(f, "%d", &h) < 0 && HDferror(f)) {
+    if (HDfscanf(f, "%d", &h) < 0 && HDferror(f)) {
         HDprintf("fscanf error in file %s.\n", data_file);
         goto out;
     } /* end if */
 
-    if (fscanf(f, "%s", str) < 0 && HDferror(f)) {
+    if (HDfscanf(f, "%s", str) < 0 && HDferror(f)) {
         HDprintf("fscanf error in file %s.\n", data_file);
         goto out;
     } /* end if */
 
-    if (fscanf(f, "%d", &w) < 0 && HDferror(f)) {
+    if (HDfscanf(f, "%d", &w) < 0 && HDferror(f)) {
         HDprintf("fscanf error in file %s.\n", data_file);
         goto out;
     } /* end if */
@@ -837,7 +838,7 @@ read_data(const char *fname, /*IN*/
 
     /* Read data elements */
     for (i = 0; i < n_elements; i++) {
-        if (fscanf(f, "%d", &n) < 0 && HDferror(f)) {
+        if (HDfscanf(f, "%d", &n) < 0 && HDferror(f)) {
             HDprintf("fscanf error in file %s.\n", data_file);
             goto out;
         } /* end if */
@@ -935,7 +936,7 @@ read_palette(const char *fname, rgb_t *palette, size_t palette_size)
         return -1;
     }
 
-    if (sscanf(buffer, "%u", &nentries) != 1) {
+    if (HDsscanf(buffer, "%u", &nentries) != 1) {
         HDfclose(file);
         return -1;
     }
@@ -949,7 +950,7 @@ read_palette(const char *fname, rgb_t *palette, size_t palette_size)
     /* read the palette entries */
     for (u = 0; u < nentries; u++) {
         /* extract the red, green and blue color components.  */
-        if (fscanf(file, "%u %u %u", &red, &green, &blue) != 3) {
+        if (HDfscanf(file, "%u %u %u", &red, &green, &blue) != 3) {
             HDfclose(file);
             return -1;
         }
