@@ -43,8 +43,9 @@
 #define ATTR7_NAME    "attr ushort"
 #define ATTR8_NAME    "attr uint"
 #define ATTR9_NAME    "attr ulong"
-#define ATTR10_NAME   "attr float"
-#define ATTR11_NAME   "attr double"
+#define ATTR10_NAME   "attr ullong"
+#define ATTR11_NAME   "attr float"
+#define ATTR12_NAME   "attr double"
 
 static herr_t make_attributes(hid_t loc_id, const char *obj_name);
 
@@ -467,33 +468,35 @@ make_attributes(hid_t loc_id, const char *obj_name)
 {
 
     int         rank_out;
-    hsize_t    *dims_out = 0;
+    hsize_t *   dims_out = 0;
     H5T_class_t type_class;
     size_t      type_size;
     int         i;
 
-    char           attr_str_in[] = {"My attribute"};
-    char           attr_str_out[20];
-    char           attr_char_in[5] = {1, 2, 3, 4, 5};
-    char           attr_char_out[5];
-    short          attr_short_in[5] = {1, 2, 3, 4, 5};
-    short          attr_short_out[5];
-    int            attr_int_in[5] = {1, 2, 3, 4, 5};
-    int            attr_int_out[5];
-    long           attr_long_in[5] = {1, 2, 3, 4, 5};
-    long           attr_long_out[5];
-    float          attr_float_in[5] = {1, 2, 3, 4, 5};
-    float          attr_float_out[5];
-    double         attr_double_in[5] = {1, 2, 3, 4, 5};
-    double         attr_double_out[5];
-    unsigned char  attr_uchar_in[5] = {1, 2, 3, 4, 5};
-    unsigned char  attr_uchar_out[5];
-    unsigned short attr_ushort_in[5] = {1, 2, 3, 4, 5};
-    unsigned short attr_ushort_out[5];
-    unsigned int   attr_uint_in[5] = {1, 2, 3, 4, 5};
-    unsigned int   attr_uint_out[5];
-    unsigned long  attr_ulong_in[5] = {1, 2, 3, 4, 5};
-    unsigned long  attr_ulong_out[5];
+    char               attr_str_in[] = {"My attribute"};
+    char               attr_str_out[20];
+    char               attr_char_in[5] = {1, 2, 3, 4, 5};
+    char               attr_char_out[5];
+    short              attr_short_in[5] = {1, 2, 3, 4, 5};
+    short              attr_short_out[5];
+    int                attr_int_in[5] = {1, 2, 3, 4, 5};
+    int                attr_int_out[5];
+    long               attr_long_in[5] = {1, 2, 3, 4, 5};
+    long               attr_long_out[5];
+    float              attr_float_in[5] = {1, 2, 3, 4, 5};
+    float              attr_float_out[5];
+    double             attr_double_in[5] = {1, 2, 3, 4, 5};
+    double             attr_double_out[5];
+    unsigned char      attr_uchar_in[5] = {1, 2, 3, 4, 5};
+    unsigned char      attr_uchar_out[5];
+    unsigned short     attr_ushort_in[5] = {1, 2, 3, 4, 5};
+    unsigned short     attr_ushort_out[5];
+    unsigned int       attr_uint_in[5] = {1, 2, 3, 4, 5};
+    unsigned int       attr_uint_out[5];
+    unsigned long      attr_ulong_in[5] = {1, 2, 3, 4, 5};
+    unsigned long      attr_ulong_out[5];
+    unsigned long long attr_ullong_in[5] = {1, 2, 3, 4, 5};
+    unsigned long long attr_ullong_out[5];
 
     /*-------------------------------------------------------------------------
      * H5LTset_attribute_string test
@@ -509,7 +512,7 @@ make_attributes(hid_t loc_id, const char *obj_name)
     PASSED();
 
     /*-------------------------------------------------------------------------
-     * H5LTset_attribute_string test
+     * H5LTget_attribute_string test
      *-------------------------------------------------------------------------
      */
 
@@ -859,7 +862,7 @@ make_attributes(hid_t loc_id, const char *obj_name)
     PASSED();
 
     /*-------------------------------------------------------------------------
-     * H5LTget_attribute_long test
+     * H5LTget_attribute_ulong test
      *-------------------------------------------------------------------------
      */
 
@@ -887,6 +890,48 @@ make_attributes(hid_t loc_id, const char *obj_name)
 
     PASSED();
 
+    /*-------------------------------------------------------------------------
+     * H5LTset_attribute_ullong test
+     *-------------------------------------------------------------------------
+     */
+
+    HL_TESTING2("H5LTset_attribute_ullong");
+
+    /* Set the attribute */
+    if (H5LTset_attribute_ullong(loc_id, obj_name, ATTR10_NAME, attr_ullong_in, (size_t)5) < 0)
+        return -1;
+
+    PASSED();
+
+    /*-------------------------------------------------------------------------
+     * H5LTget_attribute_ullong test
+     *-------------------------------------------------------------------------
+     */
+
+    HL_TESTING2("H5LTget_attribute_ullong");
+
+    /* Get the attribute */
+    if (H5LTget_attribute_ullong(loc_id, obj_name, ATTR10_NAME, attr_ullong_out) < 0)
+        return -1;
+
+    for (i = 0; i < 5; i++) {
+        if (attr_ullong_in[i] != attr_ullong_out[i]) {
+            return -1;
+        }
+    }
+
+    /* Get the attribute */
+    if (H5LTget_attribute(loc_id, obj_name, ATTR10_NAME, H5T_NATIVE_ULLONG, attr_ullong_out) < 0)
+        return -1;
+
+    for (i = 0; i < 5; i++) {
+        if (attr_ullong_in[i] != attr_ullong_out[i]) {
+            return -1;
+        }
+    }
+
+    PASSED();
+
     /*-------------------------------------------------------------------------
      * H5LTset_attribute_float test
      *-------------------------------------------------------------------------
@@ -895,7 +940,7 @@ make_attributes(hid_t loc_id, const char *obj_name)
     HL_TESTING2("H5LTset_attribute_float");
 
     /* Set the attribute */
-    if (H5LTset_attribute_float(loc_id, obj_name, ATTR10_NAME, attr_float_in, (size_t)5) < 0)
+    if (H5LTset_attribute_float(loc_id, obj_name, ATTR11_NAME, attr_float_in, (size_t)5) < 0)
         return -1;
 
     PASSED();
@@ -908,7 +953,7 @@ make_attributes(hid_t loc_id, const char *obj_name)
     HL_TESTING2("H5LTget_attribute_float");
 
     /* Get the attribute */
-    if (H5LTget_attribute_float(loc_id, obj_name, ATTR10_NAME, attr_float_out) < 0)
+    if (H5LTget_attribute_float(loc_id, obj_name, ATTR11_NAME, attr_float_out) < 0)
         return -1;
 
     for (i = 0; i < 5; i++) {
@@ -918,7 +963,7 @@ make_attributes(hid_t loc_id, const char *obj_name)
     }
 
     /* Get the attribute */
-    if (H5LTget_attribute(loc_id, obj_name, ATTR10_NAME, H5T_NATIVE_FLOAT, attr_float_out) < 0)
+    if (H5LTget_attribute(loc_id, obj_name, ATTR11_NAME, H5T_NATIVE_FLOAT, attr_float_out) < 0)
         return -1;
 
     for (i = 0; i < 5; i++) {
@@ -937,7 +982,7 @@ make_attributes(hid_t loc_id, const char *obj_name)
     HL_TESTING2("H5LTset_attribute_double");
 
     /* Set the attribute */
-    if (H5LTset_attribute_double(loc_id, obj_name, ATTR11_NAME, attr_double_in, (size_t)5) < 0)
+    if (H5LTset_attribute_double(loc_id, obj_name, ATTR12_NAME, attr_double_in, (size_t)5) < 0)
         return -1;
 
     PASSED();
@@ -950,7 +995,7 @@ make_attributes(hid_t loc_id, const char *obj_name)
     HL_TESTING2("H5LTget_attribute_double");
 
     /* Get the attribute */
-    if (H5LTget_attribute_double(loc_id, obj_name, ATTR11_NAME, attr_double_out) < 0)
+    if (H5LTget_attribute_double(loc_id, obj_name, ATTR12_NAME, attr_double_out) < 0)
         return -1;
 
     for (i = 0; i < 5; i++) {
@@ -960,7 +1005,7 @@ make_attributes(hid_t loc_id, const char *obj_name)
     }
 
     /* Get the attribute */
-    if (H5LTget_attribute(loc_id, obj_name, ATTR11_NAME, H5T_NATIVE_DOUBLE, attr_double_out) < 0)
+    if (H5LTget_attribute(loc_id, obj_name, ATTR12_NAME, H5T_NATIVE_DOUBLE, attr_double_out) < 0)
         return -1;
 
     for (i = 0; i < 5; i++) {
@@ -1028,7 +1073,7 @@ static int
 test_integers(void)
 {
     hid_t  dtype;
-    char  *dt_str;
+    char * dt_str;
     size_t str_len;
 
     HL_TESTING3("\n        text for integer types");
@@ -1086,7 +1131,7 @@ static int
 test_fps(void)
 {
     hid_t  dtype;
-    char  *dt_str;
+    char * dt_str;
     size_t str_len;
 
     HL_TESTING3("        text for floating-point types");
@@ -1148,7 +1193,7 @@ test_strings(void)
     H5T_str_t   str_pad;
     H5T_cset_t  str_cset;
     H5T_class_t type_class;
-    char       *dt_str = NULL;
+    char *      dt_str = NULL;
     size_t      str_len;
 
     HL_TESTING3("        text for string types");
@@ -1293,7 +1338,7 @@ test_opaques(void)
     hid_t       dtype;
     size_t      opq_size;
     H5T_class_t type_class;
-    char       *dt_str;
+    char *      dt_str;
     size_t      str_len;
 
     HL_TESTING3("        text for opaque types");
@@ -1355,7 +1400,7 @@ test_enums(void)
     const char *name2  = "WHITE";
     int         value2;
     H5T_class_t type_class;
-    char       *dt_str;
+    char *      dt_str;
     size_t      str_len;
 
     HL_TESTING3("        text for enum types");
@@ -1431,7 +1476,7 @@ test_variables(void)
 {
     hid_t       dtype;
     H5T_class_t type_class;
-    char       *dt_str;
+    char *      dt_str;
     size_t      str_len;
 
     HL_TESTING3("        text for variable types");
@@ -1493,7 +1538,7 @@ test_arrays(void)
     int         ndims;
     hsize_t     dims[3];
     H5T_class_t type_class;
-    char       *dt_str;
+    char *      dt_str;
     size_t      str_len;
 
     HL_TESTING3("        text for array types");
@@ -1556,10 +1601,10 @@ test_compounds(void)
 {
     hid_t       dtype;
     int         nmembs;
-    char       *memb_name = NULL;
+    char *      memb_name = NULL;
     H5T_class_t memb_class;
     H5T_class_t type_class;
-    char       *dt_str;
+    char *      dt_str;
     size_t      str_len;
 
     HL_TESTING3("        text for compound types");
@@ -1637,41 +1682,41 @@ test_compound_bug(void)
     hid_t       dtype;
     H5T_class_t type_class;
     int         nmembs;
-    char       *memb_name = NULL;
-    char       *dt_str;
+    char *      memb_name = NULL;
+    char *      dt_str;
     size_t      str_len;
-    char        text[]  = "H5T_COMPOUND { H5T_STD_I32LE "
-                          "\"state_________________________________________________________________________________"
-                          "\"; H5T_STD_I32LE "
-                          "\"desc____________________________________________________________________________________"
-                          "_____\"; H5T_VLEN { H5T_COMPOUND { H5T_ENUM { H5T_STD_I16LE; \"ZERO\" 0; \"ONE\" 1; "
-                          "\"TWO\" 2;  \"THREE\" 3; } \"type____\"; H5T_STD_I32LE "
-                          "\"sub_____________________________________________________________________________________"
-                          "__________________________\"; H5T_STRING { STRSIZE H5T_VARIABLE; STRPAD H5T_STR_SPACEPAD; "
-                          "CSET H5T_CSET_ASCII; CTYPE H5T_C_S1; } \"sub_desc\"; H5T_STD_I32LE "
-                          "\"final___________________________________________________________________________________"
-                          "________________\"; } } \"sub\"; }";
-    char        text2[] = "H5T_COMPOUND {\n"
-                          "  H5T_STD_I16LE \"state___________________________"
-                          "__________________________________________________"
-                          "____\" : 0;\n"
-                          "  H5T_STD_I16LE \"desc____________________________"
-                          "__________________________________________________"
-                          "___________\" : 2;\n"
-                          "  H5T_VLEN { H5T_COMPOUND {\n"
-                          "    H5T_ENUM { H5T_STD_I16LE; \"ZERO\" 0; \"ONE\" "
-                          "1; \"TWO\" 2;  \"THREE\" 3; } \"type____\" : 0;\n"
-                          "    H5T_STD_I32LE \"sub___________________________"
-                          "__________________________________________________"
-                          "__________________________________1\" : 4;\n"
-                          "    H5T_STRING { STRSIZE H5T_VARIABLE; STRPAD H5T_"
-                          "STR_SPACEPAD; CSET H5T_CSET_ASCII; CTYPE H5T_C_S1;"
-                          " } \"sub_desc\" : 8;\n"
-                          "    H5T_STD_I32LE \"final_________________________"
-                          "__________________________________________________"
-                          "________________________\" : 16;\n"
-                          "  } } \"sub\" : 8;\n"
-                          "}\n";
+    char        text[] = "H5T_COMPOUND { H5T_STD_I32LE "
+                  "\"state_________________________________________________________________________________"
+                  "\"; H5T_STD_I32LE "
+                  "\"desc____________________________________________________________________________________"
+                  "_____\"; H5T_VLEN { H5T_COMPOUND { H5T_ENUM { H5T_STD_I16LE; \"ZERO\" 0; \"ONE\" 1; "
+                  "\"TWO\" 2;  \"THREE\" 3; } \"type____\"; H5T_STD_I32LE "
+                  "\"sub_____________________________________________________________________________________"
+                  "__________________________\"; H5T_STRING { STRSIZE H5T_VARIABLE; STRPAD H5T_STR_SPACEPAD; "
+                  "CSET H5T_CSET_ASCII; CTYPE H5T_C_S1; } \"sub_desc\"; H5T_STD_I32LE "
+                  "\"final___________________________________________________________________________________"
+                  "________________\"; } } \"sub\"; }";
+    char text2[] = "H5T_COMPOUND {\n"
+                   "  H5T_STD_I16LE \"state___________________________"
+                   "__________________________________________________"
+                   "____\" : 0;\n"
+                   "  H5T_STD_I16LE \"desc____________________________"
+                   "__________________________________________________"
+                   "___________\" : 2;\n"
+                   "  H5T_VLEN { H5T_COMPOUND {\n"
+                   "    H5T_ENUM { H5T_STD_I16LE; \"ZERO\" 0; \"ONE\" "
+                   "1; \"TWO\" 2;  \"THREE\" 3; } \"type____\" : 0;\n"
+                   "    H5T_STD_I32LE \"sub___________________________"
+                   "__________________________________________________"
+                   "__________________________________1\" : 4;\n"
+                   "    H5T_STRING { STRSIZE H5T_VARIABLE; STRPAD H5T_"
+                   "STR_SPACEPAD; CSET H5T_CSET_ASCII; CTYPE H5T_C_S1;"
+                   " } \"sub_desc\" : 8;\n"
+                   "    H5T_STD_I32LE \"final_________________________"
+                   "__________________________________________________"
+                   "________________________\" : 16;\n"
+                   "  } } \"sub\" : 8;\n"
+                   "}\n";
 
     HL_TESTING3("        text for compound type of bug fix");
 
@@ -1761,8 +1806,8 @@ test_complicated_compound(void)
     hid_t       dtype;
     int         nmembs;
     H5T_class_t type_class;
-    char       *line     = NULL;
-    FILE       *fp       = NULL;
+    char *      line     = NULL;
+    FILE *      fp       = NULL;
     size_t      size     = 1024;
     const char *filename = H5_get_srcdir_filename(INPUT_FILE);
 
@@ -2069,11 +2114,11 @@ test_valid_path(void)
      * CHECK ABSOLUTE PATHS
      **************************************/
 
-    if ((path_valid = H5LTpath_valid(file_id, "/", TRUE)) != FALSE) {
+    if ((path_valid = H5LTpath_valid(file_id, "/", TRUE)) != TRUE) {
         goto out;
     }
 
-    if ((path_valid = H5LTpath_valid(file_id, "/", FALSE)) != FALSE) {
+    if ((path_valid = H5LTpath_valid(file_id, "/", FALSE)) != TRUE) {
         goto out;
     }
 
@@ -2126,11 +2171,11 @@ test_valid_path(void)
     if ((group = H5Gopen2(file_id, "/", H5P_DEFAULT)) < 0)
         goto out;
 
-    if ((path_valid = H5LTpath_valid(group, "/", TRUE)) != FALSE) {
+    if ((path_valid = H5LTpath_valid(group, "/", TRUE)) != TRUE) {
         goto out;
     }
 
-    if ((path_valid = H5LTpath_valid(group, "/", FALSE)) != FALSE) {
+    if ((path_valid = H5LTpath_valid(group, "/", FALSE)) != TRUE) {
         goto out;
     }
 
