@@ -6,7 +6,7 @@
  * This file is part of HDF5.  The full HDF5 copyright notice, including     *
  * terms governing use, modification, and redistribution, is contained in    *
  * the COPYING file, which can be found at the root of the source code       *
- * distribution tree, or in https://support.hdfgroup.org/ftp/HDF5/releases.  *
+ * distribution tree, or in https://www.hdfgroup.org/licenses.               *
  * If you do not have access to either file, you may request a copy from     *
  * help@hdfgroup.org.                                                        *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
@@ -26,7 +26,6 @@ extern "C" {
 #include "h5jni.h"
 #include "h5rImp.h"
 
-
 /* H5R: HDF5 1.12 Reference API Functions */
 
 /*
@@ -35,13 +34,12 @@ extern "C" {
  * Signature: (JLjava/lang/String;)[B
  */
 JNIEXPORT jbyteArray JNICALL
-Java_hdf_hdf5lib_H5_H5Rcreate_1object
-  (JNIEnv *env, jclass clss, jlong loc_id, jstring name, jlong aid)
+Java_hdf_hdf5lib_H5_H5Rcreate_1object(JNIEnv *env, jclass clss, jlong loc_id, jstring name, jlong aid)
 {
     const char *refName = NULL;
-    jbyteArray  ref = NULL;
-    jbyte      *refBuf = NULL;
-    herr_t      status = FAIL;
+    jbyteArray  ref     = NULL;
+    jbyte *     refBuf  = NULL;
+    herr_t      status  = FAIL;
 
     UNUSED(clss);
 
@@ -71,20 +69,19 @@ done:
     return ref;
 } /* end Java_hdf_hdf5lib_H5_H5Rcreate_1object */
 
-
 /*
  * Class:     hdf_hdf5lib_H5
  * Method:    H5Rcreate_region
  * Signature: (JLjava/lang/String;J)[B
  */
 JNIEXPORT jbyteArray JNICALL
-Java_hdf_hdf5lib_H5_H5Rcreate_1region
-  (JNIEnv *env, jclass clss, jlong loc_id, jstring name, jlong space_id, jlong aid)
+Java_hdf_hdf5lib_H5_H5Rcreate_1region(JNIEnv *env, jclass clss, jlong loc_id, jstring name, jlong space_id,
+                                      jlong aid)
 {
     const char *refName = NULL;
-    jbyteArray  ref = NULL;
-    jbyte      *refBuf = NULL;
-    herr_t      status = FAIL;
+    jbyteArray  ref     = NULL;
+    jbyte *     refBuf  = NULL;
+    herr_t      status  = FAIL;
 
     UNUSED(clss);
 
@@ -96,7 +93,8 @@ Java_hdf_hdf5lib_H5_H5Rcreate_1region
     if (NULL == (refBuf = HDcalloc(1, H5R_REF_BUF_SIZE)))
         H5_OUT_OF_MEMORY_ERROR(ENVONLY, "H5Rcreate_region: failed to allocate reference buffer");
 
-    if ((status = H5Rcreate_region((hid_t)loc_id, refName, space_id, (hid_t)aid, (const H5R_ref_t *)refBuf)) < 0)
+    if ((status = H5Rcreate_region((hid_t)loc_id, refName, space_id, (hid_t)aid, (const H5R_ref_t *)refBuf)) <
+        0)
         H5_LIBRARY_ERROR(ENVONLY);
 
     if (NULL == (ref = ENVPTR->NewByteArray(ENVONLY, (jsize)H5R_REF_BUF_SIZE)))
@@ -120,14 +118,14 @@ done:
  * Signature: (JLjava/lang/String;Ljava/lang/String;)[B
  */
 JNIEXPORT jbyteArray JNICALL
-Java_hdf_hdf5lib_H5_H5Rcreate_1attr
-  (JNIEnv *env, jclass clss, jlong loc_id, jstring name, jstring attr_name, jlong aid)
+Java_hdf_hdf5lib_H5_H5Rcreate_1attr(JNIEnv *env, jclass clss, jlong loc_id, jstring name, jstring attr_name,
+                                    jlong aid)
 {
-    const char *refName = NULL;
+    const char *refName  = NULL;
     const char *attrName = NULL;
-    jbyteArray  ref = NULL;
-    jbyte      *refBuf = NULL;
-    herr_t      status = FAIL;
+    jbyteArray  ref      = NULL;
+    jbyte *     refBuf   = NULL;
+    herr_t      status   = FAIL;
 
     UNUSED(clss);
 
@@ -143,7 +141,8 @@ Java_hdf_hdf5lib_H5_H5Rcreate_1attr
     if (NULL == (refBuf = HDcalloc(1, H5R_REF_BUF_SIZE)))
         H5_OUT_OF_MEMORY_ERROR(ENVONLY, "H5Rcreate_attr: failed to allocate reference buffer");
 
-    if ((status = H5Rcreate_attr((hid_t)loc_id, refName, attrName, (hid_t)aid, (const H5R_ref_t *)refBuf)) < 0)
+    if ((status = H5Rcreate_attr((hid_t)loc_id, refName, attrName, (hid_t)aid, (const H5R_ref_t *)refBuf)) <
+        0)
         H5_LIBRARY_ERROR(ENVONLY);
 
     if (NULL == (ref = ENVPTR->NewByteArray(ENVONLY, (jsize)H5R_REF_BUF_SIZE)))
@@ -169,13 +168,12 @@ done:
  * Signature: ([B)V
  */
 JNIEXPORT void JNICALL
-Java_hdf_hdf5lib_H5_H5Rdestroy
-  (JNIEnv *env, jclass clss, jbyteArray ref)
+Java_hdf_hdf5lib_H5_H5Rdestroy(JNIEnv *env, jclass clss, jbyteArray ref)
 {
-    jboolean    isCopy;
-    jbyte      *refBuf = NULL;
-    jsize       refBufLen;
-    herr_t      status = FAIL;
+    jboolean isCopy;
+    jbyte *  refBuf = NULL;
+    jsize    refBufLen;
+    herr_t   status = FAIL;
 
     UNUSED(clss);
 
@@ -203,13 +201,12 @@ done:
  * Signature: ([B)I
  */
 JNIEXPORT jint JNICALL
-Java_hdf_hdf5lib_H5_H5Rget_1type
-  (JNIEnv *env, jclass clss, jbyteArray ref)
+Java_hdf_hdf5lib_H5_H5Rget_1type(JNIEnv *env, jclass clss, jbyteArray ref)
 {
-    jboolean    isCopy;
-    jbyte      *refBuf = NULL;
-    jsize       refBufLen;
-    H5R_type_t  ref_type = -1;
+    jboolean   isCopy;
+    jbyte *    refBuf = NULL;
+    jsize      refBufLen;
+    H5R_type_t ref_type = -1;
 
     UNUSED(clss);
 
@@ -239,15 +236,14 @@ done:
  * Signature: ([B[B)Z
  */
 JNIEXPORT jboolean JNICALL
-Java_hdf_hdf5lib_H5_H5Requal
-  (JNIEnv *env, jclass clss, jbyteArray ref1, jbyteArray ref2)
+Java_hdf_hdf5lib_H5_H5Requal(JNIEnv *env, jclass clss, jbyteArray ref1, jbyteArray ref2)
 {
-    jboolean    isCopy;
-    jbyte      *refBuf1 = NULL;
-    jbyte      *refBuf2 = NULL;
-    jsize       refBufLen;
-    htri_t      bval = JNI_FALSE;
-    herr_t      status = FAIL;
+    jboolean isCopy;
+    jbyte *  refBuf1 = NULL;
+    jbyte *  refBuf2 = NULL;
+    jsize    refBufLen;
+    htri_t   bval   = JNI_FALSE;
+    herr_t   status = FAIL;
 
     UNUSED(clss);
 
@@ -292,15 +288,14 @@ done:
  * Signature: ([B)[B
  */
 JNIEXPORT jbyteArray JNICALL
-Java_hdf_hdf5lib_H5_H5Rcopy
-  (JNIEnv *env, jclass clss, jbyteArray src_ref)
+Java_hdf_hdf5lib_H5_H5Rcopy(JNIEnv *env, jclass clss, jbyteArray src_ref)
 {
-    jboolean    isCopy;
-    jbyte      *src_refBuf = NULL;
-    jsize       refBufLen;
-    jbyteArray  dst_ref = NULL;
-    jbyte      *dst_refBuf = NULL;
-    herr_t      status = FAIL;
+    jboolean   isCopy;
+    jbyte *    src_refBuf = NULL;
+    jsize      refBufLen;
+    jbyteArray dst_ref    = NULL;
+    jbyte *    dst_refBuf = NULL;
+    herr_t     status     = FAIL;
 
     UNUSED(clss);
 
@@ -341,13 +336,12 @@ done:
  * Signature: ([BJJ)J
  */
 JNIEXPORT jlong JNICALL
-Java_hdf_hdf5lib_H5_H5Ropen_1object
-  (JNIEnv *env, jclass clss, jbyteArray ref, jlong rapl_id, jlong oapl_id)
+Java_hdf_hdf5lib_H5__1H5Ropen_1object(JNIEnv *env, jclass clss, jbyteArray ref, jlong rapl_id, jlong oapl_id)
 {
-    jboolean    isCopy;
-    jbyte      *refBuf = NULL;
-    jsize       refBufLen;
-    hid_t     retVal = H5I_INVALID_HID;
+    jboolean isCopy;
+    jbyte *  refBuf = NULL;
+    jsize    refBufLen;
+    hid_t    retVal = H5I_INVALID_HID;
 
     UNUSED(clss);
 
@@ -377,13 +371,12 @@ done:
  * Signature: ([BJJ)J
  */
 JNIEXPORT jlong JNICALL
-Java_hdf_hdf5lib_H5_H5Ropen_1region
-  (JNIEnv *env, jclass clss, jbyteArray ref, jlong rapl_id, jlong oapl_id)
+Java_hdf_hdf5lib_H5__1H5Ropen_1region(JNIEnv *env, jclass clss, jbyteArray ref, jlong rapl_id, jlong oapl_id)
 {
-    jboolean    isCopy;
-    jbyte      *refBuf = NULL;
-    jsize       refBufLen;
-    hid_t       retVal = H5I_INVALID_HID;
+    jboolean isCopy;
+    jbyte *  refBuf = NULL;
+    jsize    refBufLen;
+    hid_t    retVal = H5I_INVALID_HID;
 
     UNUSED(clss);
 
@@ -413,13 +406,12 @@ done:
  * Signature: ([BJJ)J
  */
 JNIEXPORT jlong JNICALL
-Java_hdf_hdf5lib_H5_H5Ropen_1attr
-  (JNIEnv *env, jclass clss, jbyteArray ref, jlong rapl_id, jlong aapl_id)
+Java_hdf_hdf5lib_H5__1H5Ropen_1attr(JNIEnv *env, jclass clss, jbyteArray ref, jlong rapl_id, jlong aapl_id)
 {
-    jboolean    isCopy;
-    jbyte      *refBuf = NULL;
-    jsize       refBufLen;
-    hid_t       retVal = H5I_INVALID_HID;
+    jboolean isCopy;
+    jbyte *  refBuf = NULL;
+    jsize    refBufLen;
+    hid_t    retVal = H5I_INVALID_HID;
 
     UNUSED(clss);
 
@@ -449,13 +441,12 @@ done:
  * Signature: ([BJ)I
  */
 JNIEXPORT jint JNICALL
-Java_hdf_hdf5lib_H5_H5Rget_1obj_1type3
-  (JNIEnv *env, jclass clss, jbyteArray ref, jlong rapl_id)
+Java_hdf_hdf5lib_H5_H5Rget_1obj_1type3(JNIEnv *env, jclass clss, jbyteArray ref, jlong rapl_id)
 {
-    H5O_type_t  object_info = -1;
-    jboolean    isCopy;
-    jbyte      *refBuf = NULL;
-    int         retVal = -1;
+    H5O_type_t object_info = -1;
+    jboolean   isCopy;
+    jbyte *    refBuf = NULL;
+    int        retVal = -1;
 
     UNUSED(clss);
 
@@ -483,15 +474,14 @@ done:
  * Signature: ([B)Ljava/lang/String;
  */
 JNIEXPORT jstring JNICALL
-Java_hdf_hdf5lib_H5_H5Rget_1file_1name
-  (JNIEnv *env, jclass clss, jbyteArray ref)
+Java_hdf_hdf5lib_H5_H5Rget_1file_1name(JNIEnv *env, jclass clss, jbyteArray ref)
 {
-    jboolean    isCopy;
-    jbyte      *refBuf = NULL;
-    jstring     str = NULL;
-    ssize_t     buf_size;
-    ssize_t     check_size = -1;
-    char       *namePtr = NULL;
+    jboolean isCopy;
+    jbyte *  refBuf = NULL;
+    jstring  str    = NULL;
+    ssize_t  buf_size;
+    ssize_t  check_size = -1;
+    char *   namePtr    = NULL;
 
     UNUSED(clss);
 
@@ -529,15 +519,14 @@ done:
  * Signature: ([BJ)Ljava/lang/String;
  */
 JNIEXPORT jstring JNICALL
-Java_hdf_hdf5lib_H5_H5Rget_1obj_1name
-  (JNIEnv *env, jclass clss, jbyteArray ref, jlong rapl_id)
+Java_hdf_hdf5lib_H5_H5Rget_1obj_1name(JNIEnv *env, jclass clss, jbyteArray ref, jlong rapl_id)
 {
-    jboolean    isCopy;
-    jbyte      *refBuf = NULL;
-    jstring     str = NULL;
-    ssize_t     buf_size;
-    ssize_t     check_size = -1;
-    char       *namePtr = NULL;
+    jboolean isCopy;
+    jbyte *  refBuf = NULL;
+    jstring  str    = NULL;
+    ssize_t  buf_size;
+    ssize_t  check_size = -1;
+    char *   namePtr    = NULL;
 
     UNUSED(clss);
 
@@ -553,7 +542,8 @@ Java_hdf_hdf5lib_H5_H5Rget_1obj_1name
     if (NULL == (namePtr = HDmalloc(sizeof(char) * (size_t)buf_size + 1)))
         H5_OUT_OF_MEMORY_ERROR(ENVONLY, "H5Rget_obj_name: malloc failed");
 
-    if ((check_size = H5Rget_obj_name((const H5R_ref_t *)refBuf, (hid_t)rapl_id, namePtr, (size_t)buf_size + 1)) < 0)
+    if ((check_size =
+             H5Rget_obj_name((const H5R_ref_t *)refBuf, (hid_t)rapl_id, namePtr, (size_t)buf_size + 1)) < 0)
         H5_LIBRARY_ERROR(ENVONLY);
     namePtr[buf_size] = '\0';
 
@@ -575,15 +565,14 @@ done:
  * Signature: ([B)Ljava/lang/String;
  */
 JNIEXPORT jstring JNICALL
-Java_hdf_hdf5lib_H5_H5Rget_1attr_1name
-  (JNIEnv *env, jclass clss, jbyteArray ref)
+Java_hdf_hdf5lib_H5_H5Rget_1attr_1name(JNIEnv *env, jclass clss, jbyteArray ref)
 {
-    jboolean    isCopy;
-    jbyte      *refBuf = NULL;
-    jstring     str = NULL;
-    ssize_t     buf_size;
-    ssize_t     check_size = -1;
-    char       *namePtr = NULL;
+    jboolean isCopy;
+    jbyte *  refBuf = NULL;
+    jstring  str    = NULL;
+    ssize_t  buf_size;
+    ssize_t  check_size = -1;
+    char *   namePtr    = NULL;
 
     UNUSED(clss);
 
@@ -623,12 +612,12 @@ done:
  * Signature: ([BJLjava/lang/String;IJ)I
  */
 JNIEXPORT jint JNICALL
-Java_hdf_hdf5lib_H5_H5Rcreate
-    (JNIEnv *env, jclass clss, jbyteArray ref, jlong loc_id, jstring name, jint ref_type, jlong space_id)
+Java_hdf_hdf5lib_H5_H5Rcreate(JNIEnv *env, jclass clss, jbyteArray ref, jlong loc_id, jstring name,
+                              jint ref_type, jlong space_id)
 {
     const char *refName = NULL;
     jboolean    isCopy;
-    jbyte      *refBuf = NULL;
+    jbyte *     refBuf = NULL;
     jsize       refBufLen;
     herr_t      status = FAIL;
 
@@ -647,7 +636,8 @@ Java_hdf_hdf5lib_H5_H5Rcreate
     if ((H5R_OBJECT == ref_type) && (refBufLen != H5R_OBJ_REF_BUF_SIZE))
         H5_BAD_ARGUMENT_ERROR(ENVONLY, "H5Rcreate: reference input array length != H5R_OBJ_REF_BUF_SIZE");
     else if ((H5R_DATASET_REGION == ref_type) && (refBufLen != H5R_DSET_REG_REF_BUF_SIZE))
-        H5_BAD_ARGUMENT_ERROR(ENVONLY, "H5Rcreate: region reference input array length != H5R_DSET_REG_REF_BUF_SIZE");
+        H5_BAD_ARGUMENT_ERROR(ENVONLY,
+                              "H5Rcreate: region reference input array length != H5R_DSET_REG_REF_BUF_SIZE");
     else if ((H5R_OBJECT != ref_type) && (H5R_DATASET_REGION != ref_type))
         H5_BAD_ARGUMENT_ERROR(ENVONLY, "H5Rcreate: unknown reference type");
 
@@ -673,13 +663,13 @@ done:
  * Signature: (JJI[B)J
  */
 JNIEXPORT jlong JNICALL
-Java_hdf_hdf5lib_H5__1H5Rdereference
-    (JNIEnv *env, jclass clss, jlong dataset, jlong access_list, jint ref_type, jbyteArray ref)
+Java_hdf_hdf5lib_H5__1H5Rdereference(JNIEnv *env, jclass clss, jlong dataset, jlong access_list,
+                                     jint ref_type, jbyteArray ref)
 {
-    jboolean  isCopy;
-    jbyte    *refBuf = NULL;
-    jsize     refBufLen;
-    hid_t     retVal = H5I_INVALID_HID;
+    jboolean isCopy;
+    jbyte *  refBuf = NULL;
+    jsize    refBufLen;
+    hid_t    retVal = H5I_INVALID_HID;
 
     UNUSED(clss);
 
@@ -692,9 +682,11 @@ Java_hdf_hdf5lib_H5__1H5Rdereference
     }
 
     if ((H5R_OBJECT == ref_type) && (refBufLen != H5R_OBJ_REF_BUF_SIZE))
-        H5_BAD_ARGUMENT_ERROR(ENVONLY, "H5Rdereference: reference input array length != H5R_OBJ_REF_BUF_SIZE");
+        H5_BAD_ARGUMENT_ERROR(ENVONLY,
+                              "H5Rdereference: reference input array length != H5R_OBJ_REF_BUF_SIZE");
     else if ((H5R_DATASET_REGION == ref_type) && (refBufLen != H5R_DSET_REG_REF_BUF_SIZE))
-        H5_BAD_ARGUMENT_ERROR(ENVONLY, "H5Rdereference: region reference input array length != H5R_DSET_REG_REF_BUF_SIZE");
+        H5_BAD_ARGUMENT_ERROR(
+            ENVONLY, "H5Rdereference: region reference input array length != H5R_DSET_REG_REF_BUF_SIZE");
     else if ((H5R_OBJECT != ref_type) && (H5R_DATASET_REGION != ref_type))
         H5_BAD_ARGUMENT_ERROR(ENVONLY, "H5Rdereference: unknown reference type");
 
@@ -716,13 +708,12 @@ done:
  * Signature: (JI[B)J
  */
 JNIEXPORT jlong JNICALL
-Java_hdf_hdf5lib_H5__1H5Rget_1region
-    (JNIEnv *env, jclass clss, jlong dataset, jint ref_type, jbyteArray ref)
+Java_hdf_hdf5lib_H5__1H5Rget_1region(JNIEnv *env, jclass clss, jlong dataset, jint ref_type, jbyteArray ref)
 {
-    jboolean  isCopy;
-    jbyte    *refBuf = NULL;
-    jsize     refBufLen;
-    hid_t     retVal = H5I_INVALID_HID;
+    jboolean isCopy;
+    jbyte *  refBuf = NULL;
+    jsize    refBufLen;
+    hid_t    retVal = H5I_INVALID_HID;
 
     UNUSED(clss);
 
@@ -737,7 +728,8 @@ Java_hdf_hdf5lib_H5__1H5Rget_1region
     }
 
     if (refBufLen != H5R_DSET_REG_REF_BUF_SIZE)
-        H5_BAD_ARGUMENT_ERROR(ENVONLY, "H5Rget_region: region reference input array length != H5R_DSET_REG_REF_BUF_SIZE");
+        H5_BAD_ARGUMENT_ERROR(
+            ENVONLY, "H5Rget_region: region reference input array length != H5R_DSET_REG_REF_BUF_SIZE");
 
     PIN_BYTE_ARRAY(ENVONLY, ref, refBuf, &isCopy, "H5Rget_region: reference buffer not pinned");
 
@@ -757,13 +749,12 @@ done:
  * Signature: (JI[B)I
  */
 JNIEXPORT jint JNICALL
-Java_hdf_hdf5lib_H5_H5Rget_1obj_1type
-    (JNIEnv *env, jclass clss, jlong loc_id, jint ref_type, jbyteArray ref)
+Java_hdf_hdf5lib_H5_H5Rget_1obj_1type(JNIEnv *env, jclass clss, jlong loc_id, jint ref_type, jbyteArray ref)
 {
-    H5O_type_t  object_info;
-    jboolean    isCopy;
-    jbyte      *refBuf = NULL;
-    int         retVal = -1;
+    H5O_type_t object_info;
+    jboolean   isCopy;
+    jbyte *    refBuf = NULL;
+    int        retVal = -1;
 
     UNUSED(clss);
 
@@ -791,14 +782,14 @@ done:
  * Signature: (JI[B[I)I
  */
 JNIEXPORT jint JNICALL
-Java_hdf_hdf5lib_H5_H5Rget_1obj_1type2
-    (JNIEnv *env, jclass clss, jlong loc_id, jint ref_type, jbyteArray ref, jintArray ref_obj)
+Java_hdf_hdf5lib_H5_H5Rget_1obj_1type2(JNIEnv *env, jclass clss, jlong loc_id, jint ref_type, jbyteArray ref,
+                                       jintArray ref_obj)
 {
-    jboolean  isCopy, isCopy2;
-    jbyte    *refBuf = NULL;
-    jint     *ref_objP = NULL;
-    jint      status = -1;
-    int       retVal = -1;
+    jboolean isCopy, isCopy2;
+    jbyte *  refBuf   = NULL;
+    jint *   ref_objP = NULL;
+    jint     status   = -1;
+    int      retVal   = -1;
 
     UNUSED(clss);
 
@@ -831,15 +822,15 @@ done:
  * Signature: (JI[B[Ljava/lang/String;J)J
  */
 JNIEXPORT jlong JNICALL
-Java_hdf_hdf5lib_H5_H5Rget_1name
-    (JNIEnv *env, jclass clss, jlong loc_id, jint ref_type, jbyteArray ref, jobjectArray name, jlong size)
+Java_hdf_hdf5lib_H5_H5Rget_1name(JNIEnv *env, jclass clss, jlong loc_id, jint ref_type, jbyteArray ref,
+                                 jobjectArray name, jlong size)
 {
-    jboolean  isCopy;
-    jstring   str;
-    jsize     refBufLen;
-    jbyte    *refBuf = NULL;
-    char     *aName = NULL;
-    jlong     ret_val = -1;
+    jboolean isCopy;
+    jstring  str;
+    jsize    refBufLen;
+    jbyte *  refBuf  = NULL;
+    char *   aName   = NULL;
+    jlong    ret_val = -1;
 
     UNUSED(clss);
 
@@ -856,7 +847,8 @@ Java_hdf_hdf5lib_H5_H5Rget_1name
     if ((H5R_OBJECT == ref_type) && (refBufLen != H5R_OBJ_REF_BUF_SIZE))
         H5_BAD_ARGUMENT_ERROR(ENVONLY, "H5Rget_name: reference input array length != H5R_OBJ_REF_BUF_SIZE");
     else if ((H5R_DATASET_REGION == ref_type) && (refBufLen != H5R_DSET_REG_REF_BUF_SIZE))
-        H5_BAD_ARGUMENT_ERROR(ENVONLY, "H5Rget_name: region reference input array length != H5R_DSET_REG_REF_BUF_SIZE");
+        H5_BAD_ARGUMENT_ERROR(
+            ENVONLY, "H5Rget_name: region reference input array length != H5R_DSET_REG_REF_BUF_SIZE");
     else if ((H5R_OBJECT != ref_type) && (H5R_DATASET_REGION != ref_type))
         H5_BAD_ARGUMENT_ERROR(ENVONLY, "H5Rget_name: unknown reference type");
 
@@ -865,14 +857,15 @@ Java_hdf_hdf5lib_H5_H5Rget_1name
     if (NULL == (aName = HDmalloc(sizeof(char) * (size_t)size + 1)))
         H5_OUT_OF_MEMORY_ERROR(ENVONLY, "H5Rget_name: failed to allocate referenced object name buffer");
 
-    if ((ret_val = (jlong)H5Rget_name((hid_t)loc_id, (H5R_type_t)ref_type, refBuf, aName, (size_t)size + 1)) < 0)
+    if ((ret_val = (jlong)H5Rget_name((hid_t)loc_id, (H5R_type_t)ref_type, refBuf, aName, (size_t)size + 1)) <
+        0)
         H5_LIBRARY_ERROR(ENVONLY);
     aName[(size_t)size] = '\0';
 
     if (NULL == (str = ENVPTR->NewStringUTF(ENVONLY, aName)))
         CHECK_JNI_EXCEPTION(ENVONLY, JNI_FALSE);
 
-    ENVPTR->SetObjectArrayElement(ENVONLY, name, (jsize) 0, str);
+    ENVPTR->SetObjectArrayElement(ENVONLY, name, (jsize)0, str);
     CHECK_JNI_EXCEPTION(ENVONLY, JNI_FALSE);
 
 done:
@@ -884,7 +877,6 @@ done:
     return ret_val;
 } /* end Java_hdf_hdf5lib_H5_H5Rget_1name */
 
-
 #ifdef __cplusplus
 } /* end extern "C" */
 #endif /* __cplusplus */
