@@ -1,12 +1,11 @@
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
  * Copyright by The HDF Group.                                               *
- * Copyright by the Board of Trustees of the University of Illinois.         *
  * All rights reserved.                                                      *
  *                                                                           *
  * This file is part of HDF5.  The full HDF5 copyright notice, including     *
  * terms governing use, modification, and redistribution, is contained in    *
  * the COPYING file, which can be found at the root of the source code       *
- * distribution tree, or in https://support.hdfgroup.org/ftp/HDF5/releases.  *
+ * distribution tree, or in https://www.hdfgroup.org/licenses.               *
  * If you do not have access to either file, you may request a copy from     *
  * help@hdfgroup.org.                                                        *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
@@ -105,7 +104,7 @@ public class TestH5Fparams {
 
     @Test
     public void testH5Fcreate() {
-        long fid = -1;
+        long fid = HDF5Constants.H5I_INVALID_HID;
         File file = null;
 
         try {
@@ -132,7 +131,7 @@ public class TestH5Fparams {
 
     @Test
     public void testH5Fflush_global() {
-        long fid = -1;
+        long fid = HDF5Constants.H5I_INVALID_HID;
 
         try {
             fid = H5.H5Fcreate("test.h5", HDF5Constants.H5F_ACC_TRUNC,
@@ -158,7 +157,7 @@ public class TestH5Fparams {
 
     @Test
     public void testH5Fflush_local() {
-        long fid = -1;
+        long fid = HDF5Constants.H5I_INVALID_HID;
 
         try {
             fid = H5.H5Fcreate("test.h5", HDF5Constants.H5F_ACC_TRUNC,
@@ -184,7 +183,7 @@ public class TestH5Fparams {
 
     @Test
     public void testH5Fget_info() {
-        long fid = -1;
+        long fid = HDF5Constants.H5I_INVALID_HID;
 
         try {
             try {
@@ -215,7 +214,7 @@ public class TestH5Fparams {
 
     @Ignore//(expected = HDF5FunctionArgumentException.class)
     public void testH5Fset_libver_bounds_invalidlow() throws Throwable {
-        long fid = -1;
+        long fid = HDF5Constants.H5I_INVALID_HID;
 
         try {
             try {
@@ -234,7 +233,7 @@ public class TestH5Fparams {
 
     @Ignore//(expected = HDF5FunctionArgumentException.class)
     public void testH5Fset_libver_bounds_invalidhigh() throws Throwable {
-        long fid = -1;
+        long fid = HDF5Constants.H5I_INVALID_HID;
 
         try {
             try {
