@@ -17,26 +17,15 @@
 #ifndef H5CSprivate_H
 #define H5CSprivate_H
 
-#ifdef NOT_YET
-#include "H5CSpublic.h"
-#endif /* NOT_YET */
-
 /* Private headers needed by this file */
 #include "H5private.h"
 
-#define H5CS_NSLOTS 48 /*number of slots in an function stack	     */
-
-/* A function stack */
-typedef struct H5CS_t {
-    unsigned    nused;             /*num slots currently used in stack  */
-    const char *slot[H5CS_NSLOTS]; /*array of function records	     */
-} H5CS_t;
-
-H5_DLL herr_t H5CS_push(const char *func_name);
-H5_DLL herr_t H5CS_pop(void);
-H5_DLL herr_t H5CS_print(FILE *stream);
-H5_DLL herr_t H5CS_print_stack(const H5CS_t *stack, FILE *stream);
-H5_DLL herr_t H5CS_copy_stack(H5CS_t *stack);
-H5_DLL herr_t H5CS_close_stack(H5CS_t *stack);
+/* Forward declarations for structure fields */
+struct H5CS_t;
+H5_DLL herr_t         H5CS_push(const char *func_name);
+H5_DLL herr_t         H5CS_pop(void);
+H5_DLL herr_t         H5CS_print_stack(const struct H5CS_t *stack, FILE *stream);
+H5_DLL struct H5CS_t *H5CS_copy_stack(void);
+H5_DLL herr_t         H5CS_close_stack(struct H5CS_t *stack);
 
 #endif /* H5CSprivate_H */
