@@ -1,5 +1,6 @@
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
  * Copyright by The HDF Group.                                               *
+ * Copyright by the Board of Trustees of the University of Illinois.         *
  * All rights reserved.                                                      *
  *                                                                           *
  * This file is part of HDF5.  The full HDF5 copyright notice, including     *
@@ -107,7 +108,7 @@ typedef enum H5F_scope_t {
 /**
  * Unlimited file size for H5Pset_external()
  */
-#define H5F_UNLIMITED HSIZE_UNDEF
+#define H5F_UNLIMITED ((hsize_t)(-1L))
 
 /**
  * How does file close behave?
@@ -187,10 +188,11 @@ typedef enum H5F_libver_t {
     H5F_LIBVER_EARLIEST = 0, /**< Use the earliest possible format for storing objects */
     H5F_LIBVER_V18      = 1, /**< Use the latest v18 format for storing objects */
     H5F_LIBVER_V110     = 2, /**< Use the latest v110 format for storing objects */
+    H5F_LIBVER_V112     = 3, /**< Use the latest v112 format for storing objects */
     H5F_LIBVER_NBOUNDS       /**< Sentinel */
 } H5F_libver_t;
 
-#define H5F_LIBVER_LATEST H5F_LIBVER_V110
+#define H5F_LIBVER_LATEST H5F_LIBVER_V112
 
 /**
  * File space handling strategy
@@ -253,18 +255,23 @@ extern "C" {
  * \brief Checks if a file can be opened with a given file access property
  *        list
  *
- * \param[in] filename Name of a file
+ * \param[in] container_name Name of a file
+ * \fapl_id
  *
  * \return \htri_t
  *
- * \details H5F__is_hdf5() checks if the file specified by \p
- *          filename can be opened.
+ * \details H5Fis_accessible() checks if the file specified by \p
+ *          container_name can be opened with the file access property list
+ *          \p fapl_id.
  *
- * \note The H5Fis_hdf5(), only uses
+ * \note The H5Fis_accessible() function enables files to be checked with a
+ *       given file access property list, unlike H5Fis_hdf5(), which only uses
  *       the default file driver when opening a file.
  *
+ * \since 1.12.0
+ *
  */
-H5_DLL htri_t H5Fis_hdf5(const char *filename);
+H5_DLL htri_t H5Fis_accessible(const char *container_name, hid_t fapl_id);
 /**
  * \ingroup H5F
  *
@@ -379,7 +386,7 @@ H5_DLL hid_t H5Fcreate(const char *filename, unsigned flags, hid_t fcpl_id, hid_
  *          opened.
  *
  *          The \p fapl_id parameter specifies the file access property list.
- *          The use of #H5P_DEFAULT specifies that default I/O access properties
+ *          Use of #H5P_DEFAULT specifies that default I/O access properties
  *          are to be used.
  *
  *          The \p flags parameter specifies whether the file will be opened in
@@ -489,7 +496,7 @@ H5_DLL hid_t H5Freopen(hid_t file_id);
  * \snippet H5F_examples.c flush
  *
  * \attention HDF5 does not possess full control over buffering. H5Fflush()
- *            flushes the internal HDF5 buffers and then asks the operating system
+ *            flushes the internal HDF5 buffers then asks the operating system
  *            (the OS) to flush the system buffers for the open files. After
  *            that, the OS is responsible for ensuring that the data is
  *            actually flushed to disk.
@@ -516,7 +523,7 @@ H5_DLL herr_t H5Fflush(hid_t object_id, H5F_scope_t scope);
  * \snippet H5F_examples.c minimal
  *
  * \note \Bold{Delayed close:} Note the following deviation from the
- *       above-described behavior. If H5Fclose() is called for a file, but one
+ *       above-described behavior. If H5Fclose() is called for a file but one
  *       or more objects within the file remain open, those objects will remain
  *       accessible until they are individually closed. Thus, if the dataset
  *       \c data_sample is open when H5Fclose() is called for the file
@@ -525,7 +532,7 @@ H5_DLL herr_t H5Fflush(hid_t object_id, H5F_scope_t scope);
  *       automatically closed once all objects in the file have been closed.\n
  *       Be warned, however, that there are circumstances where it is not
  *       possible to delay closing a file. For example, an MPI-IO file close is
- *       a collective call; all of the processes that open the file must
+ *       a collective call; all of the processes that opened the file must
  *       close it collectively. The file cannot be closed at some time in the
  *       future by each process in an independent fashion. Another example is
  *       that an application using an AFS token-based file access privilege may
@@ -540,6 +547,45 @@ H5_DLL herr_t H5Fflush(hid_t object_id, H5F_scope_t scope);
  *
  */
 H5_DLL herr_t H5Fclose(hid_t file_id);
+/**
+ * \ingroup H5F
+ *
+ * \brief Deletes an HDF5 file
+ *
+ * \param[in] filename Name of the file to delete
+ * \fapl_id
+ *
+ * \return \herr_t
+ *
+ * \details H5Fdelete() deletes an HDF5 file \p filename with a file access
+ *          property list \p fapl_id. The \p fapl_id should be configured with
+ *          the same VOL connector or VFD that was used to open the file.
+ *
+ *          This API was introduced for use with the Virtual Object Layer
+ *          (VOL). With the VOL, HDF5 "files" can map to arbitrary storage
+ *          schemes such as object stores and relational database tables. The
+ *          data created by these implementations may be inconvenient for a
+ *          user to remove without a detailed knowledge of the storage scheme.
+ *          H5Fdelete() gives VOL connector authors the ability to add
+ *          connector-specific delete code to their connectors so that users
+ *          can remove these "files" without detailed knowledge of the storage
+ *          scheme.
+ *
+ *          For a VOL connector, H5Fdelete() deletes the file in a way that
+ *          makes sense for the specified VOL connector.
+ *
+ *          For the native HDF5 connector, HDF5 files will be deleted via the
+ *          VFDs, each of which will have to be modified to delete the files it
+ *          creates.
+ *
+ *          For all implementations, H5Fdelete() will first check if the file
+ *          is an HDF5 file via H5Fis_accessible(). This is done to ensure that
+ *          H5Fdelete() cannot be used as an arbitrary file deletion call.
+ *
+ * \since 1.12.0
+ *
+ */
+H5_DLL herr_t H5Fdelete(const char *filename, hid_t fapl_id);
 /**
  * \ingroup H5F
  *
@@ -598,6 +644,24 @@ H5_DLL hid_t H5Fget_access_plist(hid_t file_id);
  *
  */
 H5_DLL herr_t H5Fget_intent(hid_t file_id, unsigned *intent);
+/**
+ * \ingroup H5F
+ *
+ * \brief Retrieves a file's file number that uniquely identifies an open file
+ *
+ * \file_id
+ * \param[out] fileno A buffer to hold the file number
+ *
+ * \return \herr_t
+ *
+ * \details H5Fget_fileno() retrieves a file number for a file specified by the
+ *          file identifier \p file_id and the pointer \p fnumber to the file
+ *          number.
+ *
+ * \since 1.12.0
+ *
+ */
+H5_DLL herr_t H5Fget_fileno(hid_t file_id, unsigned long *fileno);
 /**
  * \ingroup H5F
  *
@@ -1240,7 +1304,7 @@ H5_DLL herr_t H5Fstart_swmr_write(hid_t file_id);
  *          \snippet this H5F_sect_info_t_snip
  *
  *          This routine retrieves free-space section information for \p nsects
- *          sections or, at most, the maximum number of sections in the specified
+ *          sections or at most the maximum number of sections in the specified
  *          free-space manager. If the number of sections is not known, a
  *          preliminary H5Fget_free_sections() call can be made by setting \p
  *          sect_info to NULL and the total number of free-space sections for
@@ -1506,7 +1570,7 @@ H5_DLL herr_t H5Fget_page_buffering_stats(hid_t file_id, unsigned accesses[2], u
  * \brief Obtains information about a cache image if it exists
  *
  * \file_id
- * \param[out] image_addr Offset of the cache image if it exists, or HADDR_UNDEF if it does not
+ * \param[out] image_addr Offset of the cache image if it exists, or #HADDR_UNDEF if it does not
  * \param[out] image_size Length of the cache image if it exists, or 0 if it does not
  * \returns \herr_t
  *
@@ -1548,7 +1612,7 @@ H5_DLL herr_t H5Fget_mdc_image_info(hid_t file_id, haddr_t *image_addr, hsize_t
  *          file_id. This setting is used to inform the library to create
  *          minimized dataset object headers when \c TRUE.
  *
- *          The setting's value is returned in the boolean pointer minimized.
+ *          The setting's value is returned in the boolean pointer minimize.
  *
  * \since 1.10.5
  *
@@ -1747,7 +1811,7 @@ H5_DLL herr_t H5Fget_info1(hid_t obj_id, H5F_info1_t *file_info);
 /**
  * \ingroup H5F
  *
- * \brief Sets the latest version of the library to be used for writing objects
+ * \brief Sets thelatest version of the library to be used for writing objects
  *
  * \file_id
  * \param[in] latest_format Latest format flag
@@ -1761,6 +1825,23 @@ H5_DLL herr_t H5Fget_info1(hid_t obj_id, H5F_info1_t *file_info);
  *
  */
 H5_DLL herr_t H5Fset_latest_format(hid_t file_id, hbool_t latest_format);
+/**
+ * \ingroup H5F
+ *
+ * \brief Determines whether a file is in the HDF5 format
+ *
+ * \param[in] file_name File name
+ *
+ * \return \htri_t
+ *
+ * \deprecated When?
+ *
+ * \details H5Fis_hdf5() determines whether a file is in the HDF5 format.
+ *
+ * \todo In which version was this function deprecated?
+ *
+ */
+H5_DLL htri_t H5Fis_hdf5(const char *file_name);
 
 #endif /* H5_NO_DEPRECATED_SYMBOLS */
 
