@@ -26,8 +26,8 @@
 /* Module Setup */
 /****************/
 
-#define H5HF_PACKAGE   /*suppress error about including H5HFpkg  */
-#define H5HF_DEBUGGING /* Need access to fractal heap debugging routines */
+#include "H5HFmodule.h" /* This source code file is part of the H5HF module */
+#define H5HF_DEBUGGING  /* Need access to fractal heap debugging routines */
 
 /***********/
 /* Headers */
@@ -49,8 +49,8 @@
 
 /* User data for direct block debugging iterator callback */
 typedef struct {
-    FILE    *stream;      /* Stream for output */
-    int      indent;      /* Indention amount */
+    FILE *   stream;      /* Stream for output */
+    int      indent;      /* Indentation amount */
     int      fwidth;      /* Field width mount */
     haddr_t  dblock_addr; /* Direct block's address */
     hsize_t  dblock_size; /* Direct block's size */
@@ -62,8 +62,8 @@ typedef struct {
 /* User data for free space section iterator callback */
 typedef struct {
     H5FS_t *fspace; /* Free space manager */
-    FILE   *stream; /* Stream for output */
-    int     indent; /* Indention amount */
+    FILE *  stream; /* Stream for output */
+    int     indent; /* Indentation amount */
     int     fwidth; /* Field width mount */
 } H5HF_debug_iter_ud2_t;
 
@@ -75,7 +75,7 @@ typedef struct {
 /* Local Prototypes */
 /********************/
 
-static herr_t H5HF_dtable_debug(const H5HF_dtable_t *dtable, FILE *stream, int indent, int fwidth);
+static herr_t H5HF__dtable_debug(const H5HF_dtable_t *dtable, FILE *stream, int indent, int fwidth);
 
 /*********************/
 /* Package Variables */
@@ -90,7 +90,78 @@ static herr_t H5HF_dtable_debug(const H5HF_dtable_t *dtable, FILE *stream, int i
 /*******************/
 
 /*-------------------------------------------------------------------------
- * Function:	H5HF_dtable_debug
+ * Function:	H5HF_id_print
+ *
+ * Purpose:	Prints a fractal heap ID.
+ *
+ * Return:	Non-negative on success/Negative on failure
+ *
+ * Programmer:	Quincey Koziol
+ *		Aug 20 2015
+ *
+ *-------------------------------------------------------------------------
+ */
+herr_t
+H5HF_id_print(H5HF_t *fh, const void *_id, FILE *stream, int indent, int fwidth)
+{
+    const uint8_t *id = (const uint8_t *)_id; /* Object ID */
+    uint8_t        id_flags;                  /* Heap ID flag bits */
+    hsize_t        obj_off;                   /* Offset of object */
+    size_t         obj_len;                   /* Length of object */
+    char           id_type;                   /* Character for the type of heap ID */
+    herr_t         ret_value = SUCCEED;       /* Return value */
+
+    FUNC_ENTER_NOAPI_NOINIT
+
+    /*
+     * Check arguments.
+     */
+    HDassert(fh);
+    HDassert(id);
+    HDassert(stream);
+    HDassert(indent >= 0);
+    HDassert(fwidth >= 0);
+
+    /* Get the ID flags */
+    id_flags = *id;
+
+    /* Check for correct heap ID version */
+    if ((id_flags & H5HF_ID_VERS_MASK) != H5HF_ID_VERS_CURR)
+        HGOTO_ERROR(H5E_HEAP, H5E_VERSION, FAIL, "incorrect heap ID version")
+
+    /* Check type of object in heap */
+    if ((id_flags & H5HF_ID_TYPE_MASK) == H5HF_ID_TYPE_MAN) {
+        id_type = 'M';
+    } /* end if */
+    else if ((id_flags & H5HF_ID_TYPE_MASK) == H5HF_ID_TYPE_HUGE) {
+        id_type = 'H';
+    } /* end if */
+    else if ((id_flags & H5HF_ID_TYPE_MASK) == H5HF_ID_TYPE_TINY) {
+        id_type = 'T';
+    } /* end if */
+    else {
+        HDfprintf(stderr, "%s: Heap ID type not supported yet!\n", FUNC);
+        HGOTO_ERROR(H5E_HEAP, H5E_UNSUPPORTED, FAIL, "heap ID type not supported yet")
+    } /* end else */
+
+    /* Get the length of the heap object */
+    if (H5HF_get_obj_len(fh, id, &obj_len) < 0)
+        HGOTO_ERROR(H5E_HEAP, H5E_CANTGET, FAIL, "can't retrieve heap ID length")
+
+    /* Get the offset of the heap object */
+    if (H5HF_get_obj_off(fh, id, &obj_off) < 0)
+        HGOTO_ERROR(H5E_HEAP, H5E_CANTGET, FAIL, "can't retrieve heap ID length")
+
+    /* Display the heap ID */
+    HDfprintf(stream, "%*s%-*s (%c, %" PRIuHSIZE " , %zu)\n", indent, "", fwidth,
+              "Heap ID info: (type, offset, length)", id_type, obj_off, obj_len);
+
+done:
+    FUNC_LEAVE_NOAPI(ret_value)
+} /* end H5HF_id_print() */
+
+/*-------------------------------------------------------------------------
+ * Function:	H5HF__dtable_debug
  *
  * Purpose:	Prints debugging info about a doubling table
  *
@@ -102,9 +173,9 @@ static herr_t H5HF_dtable_debug(const H5HF_dtable_t *dtable, FILE *stream, int i
  *-------------------------------------------------------------------------
  */
 static herr_t
-H5HF_dtable_debug(const H5HF_dtable_t *dtable, FILE *stream, int indent, int fwidth)
+H5HF__dtable_debug(const H5HF_dtable_t *dtable, FILE *stream, int indent, int fwidth)
 {
-    FUNC_ENTER_NOAPI_NOINIT_NOERR
+    FUNC_ENTER_STATIC_NOERR
 
     /*
      * Check arguments.
@@ -145,7 +216,7 @@ H5HF_dtable_debug(const H5HF_dtable_t *dtable, FILE *stream, int indent, int fwi
               "# of IDs in first row:", dtable->num_id_first_row);
 
     FUNC_LEAVE_NOAPI(SUCCEED)
-} /* end H5HF_dtable_debug() */
+} /* end H5HF__dtable_debug() */
 
 /*-------------------------------------------------------------------------
  * Function:	H5HF_hdr_print
@@ -160,8 +231,7 @@ H5HF_dtable_debug(const H5HF_dtable_t *dtable, FILE *stream, int indent, int fwi
  *-------------------------------------------------------------------------
  */
 void
-H5HF_hdr_print(const H5HF_hdr_t *hdr, hid_t dxpl_id, hbool_t dump_internal, FILE *stream, int indent,
-               int fwidth)
+H5HF_hdr_print(const H5HF_hdr_t *hdr, hbool_t dump_internal, FILE *stream, int indent, int fwidth)
 {
     FUNC_ENTER_NOAPI_NOINIT_NOERR
 
@@ -215,7 +285,7 @@ H5HF_hdr_print(const H5HF_hdr_t *hdr, hid_t dxpl_id, hbool_t dump_internal, FILE
               "Number of 'tiny' objects in heap:", hdr->tiny_nobjs);
 
     HDfprintf(stream, "%*sManaged Objects Doubling-Table Info...\n", indent, "");
-    H5HF_dtable_debug(&hdr->man_dtable, stream, indent + 3, MAX(0, fwidth - 3));
+    H5HF__dtable_debug(&hdr->man_dtable, stream, indent + 3, MAX(0, fwidth - 3));
 
     /* Print information about I/O filters */
     if (hdr->filter_len > 0) {
@@ -226,7 +296,7 @@ H5HF_hdr_print(const H5HF_hdr_t *hdr, hid_t dxpl_id, hbool_t dump_internal, FILE
             HDfprintf(stream, "%*s%-*s %x\n", indent + 3, "", MAX(0, fwidth - 3),
                       "Filter mask for root direct block:", hdr->pline_root_direct_filter_mask);
         } /* end if */
-        H5O_debug_id(H5O_PLINE_ID, hdr->f, dxpl_id, &(hdr->pline), stream, indent + 3, MAX(0, fwidth - 3));
+        H5O_debug_id(H5O_PLINE_ID, hdr->f, &(hdr->pline), stream, indent + 3, MAX(0, fwidth - 3));
     } /* end if */
 
     /* Print internal (runtime) information, if requested */
@@ -258,7 +328,7 @@ H5HF_hdr_print(const H5HF_hdr_t *hdr, hid_t dxpl_id, hbool_t dump_internal, FILE
  *-------------------------------------------------------------------------
  */
 herr_t
-H5HF_hdr_debug(H5F_t *f, hid_t dxpl_id, haddr_t addr, FILE *stream, int indent, int fwidth)
+H5HF_hdr_debug(H5F_t *f, haddr_t addr, FILE *stream, int indent, int fwidth)
 {
     H5HF_hdr_t *hdr       = NULL;    /* Fractal heap header info */
     herr_t      ret_value = SUCCEED; /* Return value */
@@ -275,14 +345,14 @@ H5HF_hdr_debug(H5F_t *f, hid_t dxpl_id, haddr_t addr, FILE *stream, int indent,
     HDassert(fwidth >= 0);
 
     /* Load the fractal heap header */
-    if (NULL == (hdr = H5HF_hdr_protect(f, dxpl_id, addr, H5AC_READ)))
+    if (NULL == (hdr = H5HF__hdr_protect(f, addr, H5AC__READ_ONLY_FLAG)))
         HGOTO_ERROR(H5E_HEAP, H5E_CANTPROTECT, FAIL, "unable to protect fractal heap header")
 
     /* Print the information about the heap's header */
-    H5HF_hdr_print(hdr, dxpl_id, FALSE, stream, indent, fwidth);
+    H5HF_hdr_print(hdr, FALSE, stream, indent, fwidth);
 
 done:
-    if (hdr && H5AC_unprotect(f, dxpl_id, H5AC_FHEAP_HDR, addr, hdr, H5AC__NO_FLAGS_SET) < 0)
+    if (hdr && H5AC_unprotect(f, H5AC_FHEAP_HDR, addr, hdr, H5AC__NO_FLAGS_SET) < 0)
         HDONE_ERROR(H5E_HEAP, H5E_PROTECT, FAIL, "unable to release fractal heap header")
 
     FUNC_LEAVE_NOAPI(ret_value)
@@ -303,7 +373,7 @@ done:
 static herr_t
 H5HF_dblock_debug_cb(H5FS_section_info_t *_sect, void *_udata)
 {
-    H5HF_free_section_t   *sect  = (H5HF_free_section_t *)_sect;    /* Section to dump info */
+    H5HF_free_section_t *  sect  = (H5HF_free_section_t *)_sect;    /* Section to dump info */
     H5HF_debug_iter_ud1_t *udata = (H5HF_debug_iter_ud1_t *)_udata; /* User data for callbacks */
     haddr_t                sect_start, sect_end;     /* Section's beginning and ending offsets */
     haddr_t                dblock_start, dblock_end; /* Direct block's beginning and ending offsets */
@@ -383,14 +453,14 @@ H5HF_dblock_debug_cb(H5FS_section_info_t *_sect, void *_udata)
  *-------------------------------------------------------------------------
  */
 herr_t
-H5HF_dblock_debug(H5F_t *f, hid_t dxpl_id, haddr_t addr, FILE *stream, int indent, int fwidth,
-                  haddr_t hdr_addr, size_t block_size)
+H5HF_dblock_debug(H5F_t *f, haddr_t addr, FILE *stream, int indent, int fwidth, haddr_t hdr_addr,
+                  size_t block_size)
 {
-    H5HF_hdr_t    *hdr    = NULL;       /* Fractal heap header info */
+    H5HF_hdr_t *   hdr    = NULL;       /* Fractal heap header info */
     H5HF_direct_t *dblock = NULL;       /* Fractal heap direct block info */
     size_t         blk_prefix_size;     /* Size of prefix for block */
     size_t         amount_free;         /* Amount of free space in block */
-    uint8_t       *marker    = NULL;    /* Track free space for block */
+    uint8_t *      marker    = NULL;    /* Track free space for block */
     herr_t         ret_value = SUCCEED; /* Return value */
 
     FUNC_ENTER_NOAPI(FAIL)
@@ -407,13 +477,13 @@ H5HF_dblock_debug(H5F_t *f, hid_t dxpl_id, haddr_t addr, FILE *stream, int inden
     HDassert(block_size > 0);
 
     /* Load the fractal heap header */
-    if (NULL == (hdr = H5HF_hdr_protect(f, dxpl_id, hdr_addr, H5AC_READ)))
+    if (NULL == (hdr = H5HF__hdr_protect(f, hdr_addr, H5AC__READ_ONLY_FLAG)))
         HGOTO_ERROR(H5E_HEAP, H5E_CANTPROTECT, FAIL, "unable to protect fractal heap header")
 
     /*
      * Load the heap direct block
      */
-    if (NULL == (dblock = H5HF_man_dblock_protect(hdr, dxpl_id, addr, block_size, NULL, 0, H5AC_READ)))
+    if (NULL == (dblock = H5HF__man_dblock_protect(hdr, addr, block_size, NULL, 0, H5AC__READ_ONLY_FLAG)))
         HGOTO_ERROR(H5E_HEAP, H5E_CANTLOAD, FAIL, "unable to load fractal heap direct block")
 
     /* Print opening message */
@@ -428,14 +498,13 @@ H5HF_dblock_debug(H5F_t *f, hid_t dxpl_id, haddr_t addr, FILE *stream, int inden
               "Offset of direct block in heap:", dblock->block_off);
     blk_prefix_size = H5HF_MAN_ABS_DIRECT_OVERHEAD(hdr);
     HDfprintf(stream, "%*s%-*s %zu\n", indent, "", fwidth, "Size of block header:", blk_prefix_size);
-    HDfprintf(stream, "%*s%-*s %Zu\n", indent, "", fwidth, "Size of block offsets:", dblock->blk_off_size);
 
     /* Allocate space for the free space markers */
     if (NULL == (marker = (uint8_t *)H5MM_calloc(dblock->size)))
         HGOTO_ERROR(H5E_RESOURCE, H5E_NOSPACE, FAIL, "memory allocation failed")
 
     /* Initialize the free space information for the heap */
-    if (H5HF_space_start(hdr, dxpl_id, FALSE) < 0)
+    if (H5HF__space_start(hdr, FALSE) < 0)
         HGOTO_ERROR(H5E_HEAP, H5E_CANTINIT, FAIL, "can't initialize heap free space")
 
     /* If there is a free space manager for the heap, check for sections that overlap this block */
@@ -456,11 +525,11 @@ H5HF_dblock_debug(H5F_t *f, hid_t dxpl_id, haddr_t addr, FILE *stream, int inden
         HDfprintf(stream, "%*sFree Blocks (offset, size):\n", indent, "");
 
         /* Iterate over the free space sections, to detect overlaps with this block */
-        if (H5FS_sect_iterate(f, dxpl_id, hdr->fspace, H5HF_dblock_debug_cb, &udata) < 0)
+        if (H5FS_sect_iterate(f, hdr->fspace, H5HF_dblock_debug_cb, &udata) < 0)
             HGOTO_ERROR(H5E_HEAP, H5E_BADITER, FAIL, "can't iterate over heap's free space")
 
         /* Close the free space information */
-        if (H5HF_space_close(hdr, dxpl_id) < 0)
+        if (H5HF__space_close(hdr) < 0)
             HGOTO_ERROR(H5E_HEAP, H5E_CANTRELEASE, FAIL, "can't release free space info")
 
         /* Keep the amount of space free */
@@ -474,7 +543,7 @@ H5HF_dblock_debug(H5F_t *f, hid_t dxpl_id, haddr_t addr, FILE *stream, int inden
         amount_free = 0;
 
     HDfprintf(stream, "%*s%-*s %.2f%%\n", indent, "", fwidth, "Percent of available space for data used:",
-              ((double)100.0f * (double)((dblock->size - blk_prefix_size) - amount_free) /
+              (100.0 * (double)((dblock->size - blk_prefix_size) - amount_free) /
                (double)(dblock->size - blk_prefix_size)));
 
     /*
@@ -483,9 +552,9 @@ H5HF_dblock_debug(H5F_t *f, hid_t dxpl_id, haddr_t addr, FILE *stream, int inden
     H5_buffer_dump(stream, indent, dblock->blk, marker, (size_t)0, dblock->size);
 
 done:
-    if (dblock && H5AC_unprotect(f, dxpl_id, H5AC_FHEAP_DBLOCK, addr, dblock, H5AC__NO_FLAGS_SET) < 0)
+    if (dblock && H5AC_unprotect(f, H5AC_FHEAP_DBLOCK, addr, dblock, H5AC__NO_FLAGS_SET) < 0)
         HDONE_ERROR(H5E_HEAP, H5E_PROTECT, FAIL, "unable to release fractal heap direct block")
-    if (hdr && H5AC_unprotect(f, dxpl_id, H5AC_FHEAP_HDR, hdr_addr, hdr, H5AC__NO_FLAGS_SET) < 0)
+    if (hdr && H5AC_unprotect(f, H5AC_FHEAP_HDR, hdr_addr, hdr, H5AC__NO_FLAGS_SET) < 0)
         HDONE_ERROR(H5E_HEAP, H5E_PROTECT, FAIL, "unable to release fractal heap header")
     H5MM_xfree(marker);
 
@@ -618,10 +687,10 @@ H5HF_iblock_print(const H5HF_indirect_t *iblock, hbool_t dump_internal, FILE *st
  *-------------------------------------------------------------------------
  */
 herr_t
-H5HF_iblock_debug(H5F_t *f, hid_t dxpl_id, haddr_t addr, FILE *stream, int indent, int fwidth,
-                  haddr_t hdr_addr, unsigned nrows)
+H5HF_iblock_debug(H5F_t *f, haddr_t addr, FILE *stream, int indent, int fwidth, haddr_t hdr_addr,
+                  unsigned nrows)
 {
-    H5HF_hdr_t      *hdr         = NULL;    /* Fractal heap header info */
+    H5HF_hdr_t *     hdr         = NULL;    /* Fractal heap header info */
     H5HF_indirect_t *iblock      = NULL;    /* Fractal heap direct block info */
     hbool_t          did_protect = FALSE;   /* Whether we protected the indirect block or not */
     herr_t           ret_value   = SUCCEED; /* Return value */
@@ -640,23 +709,23 @@ H5HF_iblock_debug(H5F_t *f, hid_t dxpl_id, haddr_t addr, FILE *stream, int inden
     HDassert(nrows > 0);
 
     /* Load the fractal heap header */
-    if (NULL == (hdr = H5HF_hdr_protect(f, dxpl_id, hdr_addr, H5AC_READ)))
+    if (NULL == (hdr = H5HF__hdr_protect(f, hdr_addr, H5AC__READ_ONLY_FLAG)))
         HGOTO_ERROR(H5E_HEAP, H5E_CANTPROTECT, FAIL, "unable to protect fractal heap header")
 
     /*
      * Load the heap indirect block
      */
-    if (NULL == (iblock = H5HF_man_iblock_protect(hdr, dxpl_id, addr, nrows, NULL, 0, FALSE, H5AC_READ,
-                                                  &did_protect)))
+    if (NULL == (iblock = H5HF__man_iblock_protect(hdr, addr, nrows, NULL, 0, FALSE, H5AC__READ_ONLY_FLAG,
+                                                   &did_protect)))
         HGOTO_ERROR(H5E_HEAP, H5E_CANTLOAD, FAIL, "unable to load fractal heap indirect block")
 
     /* Print the information about the heap's indirect block */
     H5HF_iblock_print(iblock, FALSE, stream, indent, fwidth);
 
 done:
-    if (iblock && H5HF_man_iblock_unprotect(iblock, dxpl_id, H5AC__NO_FLAGS_SET, did_protect) < 0)
+    if (iblock && H5HF__man_iblock_unprotect(iblock, H5AC__NO_FLAGS_SET, did_protect) < 0)
         HDONE_ERROR(H5E_HEAP, H5E_PROTECT, FAIL, "unable to release fractal heap direct block")
-    if (hdr && H5AC_unprotect(f, dxpl_id, H5AC_FHEAP_HDR, hdr_addr, hdr, H5AC__NO_FLAGS_SET) < 0)
+    if (hdr && H5AC_unprotect(f, H5AC_FHEAP_HDR, hdr_addr, hdr, H5AC__NO_FLAGS_SET) < 0)
         HDONE_ERROR(H5E_HEAP, H5E_PROTECT, FAIL, "unable to release fractal heap header")
 
     FUNC_LEAVE_NOAPI(ret_value)
@@ -677,7 +746,7 @@ done:
 static herr_t
 H5HF_sects_debug_cb(H5FS_section_info_t *_sect, void *_udata)
 {
-    H5HF_free_section_t   *sect      = (H5HF_free_section_t *)_sect;    /* Section to dump info */
+    H5HF_free_section_t *  sect      = (H5HF_free_section_t *)_sect;    /* Section to dump info */
     H5HF_debug_iter_ud2_t *udata     = (H5HF_debug_iter_ud2_t *)_udata; /* User data for callbacks */
     herr_t                 ret_value = SUCCEED;                         /* Return value */
 
@@ -724,7 +793,7 @@ done:
  *-------------------------------------------------------------------------
  */
 herr_t
-H5HF_sects_debug(H5F_t *f, hid_t dxpl_id, haddr_t fh_addr, FILE *stream, int indent, int fwidth)
+H5HF_sects_debug(H5F_t *f, haddr_t fh_addr, FILE *stream, int indent, int fwidth)
 {
     H5HF_hdr_t *hdr       = NULL;    /* Fractal heap header info */
     herr_t      ret_value = SUCCEED; /* Return value */
@@ -741,11 +810,11 @@ H5HF_sects_debug(H5F_t *f, hid_t dxpl_id, haddr_t fh_addr, FILE *stream, int ind
     HDassert(fwidth >= 0);
 
     /* Load the fractal heap header */
-    if (NULL == (hdr = H5HF_hdr_protect(f, dxpl_id, fh_addr, H5AC_READ)))
+    if (NULL == (hdr = H5HF__hdr_protect(f, fh_addr, H5AC__READ_ONLY_FLAG)))
         HGOTO_ERROR(H5E_HEAP, H5E_CANTPROTECT, FAIL, "unable to protect fractal heap header")
 
     /* Initialize the free space information for the heap */
-    if (H5HF_space_start(hdr, dxpl_id, FALSE) < 0)
+    if (H5HF__space_start(hdr, FALSE) < 0)
         HGOTO_ERROR(H5E_HEAP, H5E_CANTINIT, FAIL, "can't initialize heap free space")
 
     /* If there is a free space manager for the heap, iterate over them */
@@ -759,16 +828,16 @@ H5HF_sects_debug(H5F_t *f, hid_t dxpl_id, haddr_t fh_addr, FILE *stream, int ind
         udata.fwidth = fwidth;
 
         /* Iterate over all the free space sections */
-        if (H5FS_sect_iterate(f, dxpl_id, hdr->fspace, H5HF_sects_debug_cb, &udata) < 0)
+        if (H5FS_sect_iterate(f, hdr->fspace, H5HF_sects_debug_cb, &udata) < 0)
             HGOTO_ERROR(H5E_HEAP, H5E_BADITER, FAIL, "can't iterate over heap's free space")
 
         /* Close the free space information */
-        if (H5HF_space_close(hdr, dxpl_id) < 0)
+        if (H5HF__space_close(hdr) < 0)
             HGOTO_ERROR(H5E_HEAP, H5E_CANTRELEASE, FAIL, "can't release free space info")
     } /* end if */
 
 done:
-    if (hdr && H5AC_unprotect(f, dxpl_id, H5AC_FHEAP_HDR, fh_addr, hdr, H5AC__NO_FLAGS_SET) < 0)
+    if (hdr && H5AC_unprotect(f, H5AC_FHEAP_HDR, fh_addr, hdr, H5AC__NO_FLAGS_SET) < 0)
         HDONE_ERROR(H5E_HEAP, H5E_PROTECT, FAIL, "unable to release fractal heap header")
 
     FUNC_LEAVE_NOAPI(ret_value)
