@@ -26,7 +26,7 @@
 /* Module Setup */
 /****************/
 
-#define H5HF_PACKAGE /*suppress error about including H5HFpkg  */
+#include "H5HFmodule.h" /* This source code file is part of the H5HF module */
 
 /***********/
 /* Headers */
@@ -70,7 +70,7 @@ H5FL_DEFINE(H5HF_direct_t);
 /*******************/
 
 /*-------------------------------------------------------------------------
- * Function:	H5HF_man_dblock_create
+ * Function:	H5HF__man_dblock_create
  *
  * Purpose:	Allocate & initialize a managed direct block
  *
@@ -82,16 +82,16 @@ H5FL_DEFINE(H5HF_direct_t);
  *-------------------------------------------------------------------------
  */
 herr_t
-H5HF_man_dblock_create(hid_t dxpl_id, H5HF_hdr_t *hdr, H5HF_indirect_t *par_iblock, unsigned par_entry,
-                       haddr_t *addr_p, H5HF_free_section_t **ret_sec_node)
+H5HF__man_dblock_create(H5HF_hdr_t *hdr, H5HF_indirect_t *par_iblock, unsigned par_entry, haddr_t *addr_p,
+                        H5HF_free_section_t **ret_sec_node)
 {
     H5HF_free_section_t *sec_node;            /* Pointer to free space section for block */
-    H5HF_direct_t       *dblock = NULL;       /* Pointer to direct block */
+    H5HF_direct_t *      dblock = NULL;       /* Pointer to direct block */
     haddr_t              dblock_addr;         /* Direct block's address */
     size_t               free_space;          /* Free space in new block */
     herr_t               ret_value = SUCCEED; /* Return value */
 
-    FUNC_ENTER_NOAPI_NOINIT
+    FUNC_ENTER_PACKAGE
 
     /*
      * Check arguments.
@@ -109,7 +109,7 @@ H5HF_man_dblock_create(hid_t dxpl_id, H5HF_hdr_t *hdr, H5HF_indirect_t *par_iblo
 
     /* Share common heap information */
     dblock->hdr = hdr;
-    if (H5HF_hdr_incr(hdr) < 0)
+    if (H5HF__hdr_incr(hdr) < 0)
         HGOTO_ERROR(H5E_HEAP, H5E_CANTINC, FAIL, "can't increment reference count on shared heap header")
 
     /* Set info for direct block */
@@ -128,17 +128,17 @@ H5HF_man_dblock_create(hid_t dxpl_id, H5HF_hdr_t *hdr, H5HF_indirect_t *par_iblo
         dblock->block_off = 0;
         dblock->size      = hdr->man_dtable.cparam.start_block_size;
     } /* end else */
-    dblock->file_size    = 0;
-    dblock->blk_off_size = H5HF_SIZEOF_OFFSET_LEN(dblock->size);
-    free_space           = dblock->size - H5HF_MAN_ABS_DIRECT_OVERHEAD(hdr);
+    dblock->file_size = 0;
+    free_space        = dblock->size - H5HF_MAN_ABS_DIRECT_OVERHEAD(hdr);
 
     /* Allocate buffer for block */
     /* XXX: Change to using free-list factories */
     if ((dblock->blk = H5FL_BLK_MALLOC(direct_block, dblock->size)) == NULL)
         HGOTO_ERROR(H5E_RESOURCE, H5E_NOSPACE, FAIL, "memory allocation failed")
-#ifdef H5_CLEAR_MEMORY
     HDmemset(dblock->blk, 0, dblock->size);
-#endif /* H5_CLEAR_MEMORY */
+
+    dblock->write_buf  = NULL;
+    dblock->write_size = 0;
 
     /* Allocate [temporary] space for the direct block on disk */
     if (H5F_USE_TMP_SPACE(hdr->f)) {
@@ -147,22 +147,25 @@ H5HF_man_dblock_create(hid_t dxpl_id, H5HF_hdr_t *hdr, H5HF_indirect_t *par_iblo
                         "file allocation failed for fractal heap direct block")
     } /* end if */
     else {
-        if (HADDR_UNDEF ==
-            (dblock_addr = H5MF_alloc(hdr->f, H5FD_MEM_FHEAP_DBLOCK, dxpl_id, (hsize_t)dblock->size)))
+        if (HADDR_UNDEF == (dblock_addr = H5MF_alloc(hdr->f, H5FD_MEM_FHEAP_DBLOCK, (hsize_t)dblock->size)))
             HGOTO_ERROR(H5E_RESOURCE, H5E_NOSPACE, FAIL,
                         "file allocation failed for fractal heap direct block")
     } /* end else */
 
     /* Attach to parent indirect block, if there is one */
     dblock->parent = par_iblock;
-    if (dblock->parent)
-        if (H5HF_man_iblock_attach(dblock->parent, par_entry, dblock_addr) < 0)
+    if (dblock->parent) {
+        if (H5HF__man_iblock_attach(dblock->parent, par_entry, dblock_addr) < 0)
             HGOTO_ERROR(H5E_HEAP, H5E_CANTATTACH, FAIL, "can't attach direct block to parent indirect block")
+        dblock->fd_parent = par_iblock;
+    } /* end if */
+    else
+        dblock->fd_parent = hdr;
     dblock->par_entry = par_entry;
 
     /* Create a new 'single' section for the free space in the block */
-    if (NULL == (sec_node = H5HF_sect_single_new((dblock->block_off + H5HF_MAN_ABS_DIRECT_OVERHEAD(hdr)),
-                                                 free_space, dblock->parent, dblock->par_entry)))
+    if (NULL == (sec_node = H5HF__sect_single_new((dblock->block_off + H5HF_MAN_ABS_DIRECT_OVERHEAD(hdr)),
+                                                  free_space, dblock->parent, dblock->par_entry)))
         HGOTO_ERROR(H5E_HEAP, H5E_CANTINIT, FAIL, "can't create section for new direct block's free space")
 
     /* Check what to do with section node */
@@ -171,16 +174,16 @@ H5HF_man_dblock_create(hid_t dxpl_id, H5HF_hdr_t *hdr, H5HF_indirect_t *par_iblo
         *ret_sec_node = sec_node;
     else {
         /* Add new free space to the heap's list of space */
-        if (H5HF_space_add(hdr, dxpl_id, sec_node, 0) < 0)
+        if (H5HF__space_add(hdr, sec_node, 0) < 0)
             HGOTO_ERROR(H5E_HEAP, H5E_CANTINIT, FAIL, "can't add direct block free space to global list")
     } /* end else */
 
     /* Cache the new fractal heap direct block */
-    if (H5AC_insert_entry(hdr->f, dxpl_id, H5AC_FHEAP_DBLOCK, dblock_addr, dblock, H5AC__NO_FLAGS_SET) < 0)
+    if (H5AC_insert_entry(hdr->f, H5AC_FHEAP_DBLOCK, dblock_addr, dblock, H5AC__NO_FLAGS_SET) < 0)
         HGOTO_ERROR(H5E_HEAP, H5E_CANTINIT, FAIL, "can't add fractal heap direct block to cache")
 
     /* Increase the allocated heap size */
-    if (H5HF_hdr_inc_alloc(hdr, dblock->size) < 0)
+    if (H5HF__hdr_inc_alloc(hdr, dblock->size) < 0)
         HGOTO_ERROR(H5E_HEAP, H5E_CANTRELEASE, FAIL, "can't increase allocated heap size")
 
     /* Set the address of of direct block, if requested */
@@ -190,14 +193,14 @@ H5HF_man_dblock_create(hid_t dxpl_id, H5HF_hdr_t *hdr, H5HF_indirect_t *par_iblo
 done:
     if (ret_value < 0)
         if (dblock)
-            if (H5HF_man_dblock_dest(dblock) < 0)
+            if (H5HF__man_dblock_dest(dblock) < 0)
                 HDONE_ERROR(H5E_HEAP, H5E_CANTFREE, FAIL, "unable to destroy fractal heap direct block")
 
     FUNC_LEAVE_NOAPI(ret_value)
-} /* end H5HF_man_dblock_create() */
+} /* end H5HF__man_dblock_create() */
 
 /*-------------------------------------------------------------------------
- * Function:	H5HF_man_dblock_destroy
+ * Function:	H5HF__man_dblock_destroy
  *
  * Purpose:	Destroy a managed direct block
  *
@@ -213,13 +216,13 @@ done:
  *-------------------------------------------------------------------------
  */
 herr_t
-H5HF_man_dblock_destroy(H5HF_hdr_t *hdr, hid_t dxpl_id, H5HF_direct_t *dblock, haddr_t dblock_addr)
+H5HF__man_dblock_destroy(H5HF_hdr_t *hdr, H5HF_direct_t *dblock, haddr_t dblock_addr, hbool_t *parent_removed)
 {
     hsize_t  dblock_size;                      /* Size of direct block on disk */
     unsigned cache_flags = H5AC__NO_FLAGS_SET; /* Flags for unprotecting indirect block */
     herr_t   ret_value   = SUCCEED;            /* Return value */
 
-    FUNC_ENTER_NOAPI_NOINIT
+    FUNC_ENTER_PACKAGE
 
     /*
      * Check arguments.
@@ -248,6 +251,10 @@ H5HF_man_dblock_destroy(H5HF_hdr_t *hdr, hid_t dxpl_id, H5HF_direct_t *dblock, h
     else
         dblock_size = (hsize_t)dblock->size;
 
+    /* Reset the parent_removed flag */
+    if (parent_removed)
+        *parent_removed = FALSE;
+
     /* Check for root direct block */
     if (hdr->man_dtable.curr_root_rows == 0) {
         /* Sanity check */
@@ -255,13 +262,10 @@ H5HF_man_dblock_destroy(H5HF_hdr_t *hdr, hid_t dxpl_id, H5HF_direct_t *dblock, h
         HDassert(hdr->man_dtable.cparam.start_block_size == dblock->size);
 
         /* Sanity check block iterator */
-        HDassert(!H5HF_man_iter_ready(&hdr->next_block));
-
-        /* Reset root pointer information */
-        hdr->man_dtable.table_addr = HADDR_UNDEF;
+        HDassert(!H5HF__man_iter_ready(&hdr->next_block));
 
         /* Reset header information back to "empty heap" state */
-        if (H5HF_hdr_empty(hdr) < 0)
+        if (H5HF__hdr_empty(hdr) < 0)
             HGOTO_ERROR(H5E_HEAP, H5E_CANTSHRINK, FAIL, "can't make heap empty")
     } /* end if */
     else {
@@ -269,49 +273,49 @@ H5HF_man_dblock_destroy(H5HF_hdr_t *hdr, hid_t dxpl_id, H5HF_direct_t *dblock, h
         hdr->man_alloc_size -= dblock->size;
 
         /* Check for this direct block being the highest in the heap */
-        if ((dblock->block_off + dblock->size) == hdr->man_iter_off) {
+        if ((dblock->block_off + dblock->size) == hdr->man_iter_off)
             /* Move 'next block' iterator backwards (may shrink heap) */
-            if (H5HF_hdr_reverse_iter(hdr, dxpl_id, dblock_addr) < 0)
+            if (H5HF__hdr_reverse_iter(hdr, dblock_addr) < 0)
                 HGOTO_ERROR(H5E_HEAP, H5E_CANTRELEASE, FAIL, "can't reverse 'next block' iterator")
-        } /* end if */
-#if 0
-        else {
-            unsigned par_row, par_col;  /* Row & column in parent indirect block */
-
-            /* Compute row & column in parent indirect block */
-            par_row = dblock->par_entry / hdr->man_dtable.cparam.width;
-            par_col = dblock->par_entry % hdr->man_dtable.cparam.width;
-
-            /* Add a 'range' section for the space in the destroyed block */
-            if(H5HF_sect_range_add(hdr, dxpl_id, dblock->block_off, hdr->man_dtable.row_tot_dblock_free[par_row],
-                    dblock->parent, par_row, par_col, 1) < 0)
-                HGOTO_ERROR(H5E_HEAP, H5E_CANTINSERT, FAIL, "can't create range section for direct block being destroyed")
-        } /* end else */
-#endif /* 0 */
 
         /* Detach from parent indirect block */
         if (dblock->parent) {
-            if (H5HF_man_iblock_detach(dblock->parent, dxpl_id, dblock->par_entry) < 0)
+            /* Destroy flush dependency between direct block and parent */
+            if (H5AC_destroy_flush_dependency(dblock->fd_parent, dblock) < 0)
+                HGOTO_ERROR(H5E_HEAP, H5E_CANTUNDEPEND, FAIL, "unable to destroy flush dependency")
+            dblock->fd_parent = NULL;
+
+            /* If this is the last direct block for the indirect block, the
+             *  indirect block will be removed when this direct block is detached
+             */
+            if (parent_removed && 1 == dblock->parent->nchildren)
+                *parent_removed = TRUE;
+
+            if (H5HF__man_iblock_detach(dblock->parent, dblock->par_entry) < 0)
                 HGOTO_ERROR(H5E_HEAP, H5E_CANTATTACH, FAIL, "can't detach from parent indirect block");
             dblock->parent    = NULL;
             dblock->par_entry = 0;
         } /* end if */
     }     /* end else */
 
-    /* Indicate that the indirect block should be deleted & file space freed */
+    /* Indicate that the direct block should be deleted */
     dblock->file_size = dblock_size;
-    cache_flags |= H5AC__DIRTIED_FLAG | H5AC__DELETED_FLAG | H5AC__FREE_FILE_SPACE_FLAG;
+    cache_flags |= H5AC__DIRTIED_FLAG | H5AC__DELETED_FLAG;
+
+    /* If the dblock is in real file space, also tell the cache to free its file space */
+    if (!H5F_IS_TMP_ADDR(hdr->f, dblock_addr))
+        cache_flags |= H5AC__FREE_FILE_SPACE_FLAG;
 
 done:
     /* Unprotect the indirect block, with appropriate flags */
-    if (H5AC_unprotect(hdr->f, dxpl_id, H5AC_FHEAP_DBLOCK, dblock_addr, dblock, cache_flags) < 0)
+    if (H5AC_unprotect(hdr->f, H5AC_FHEAP_DBLOCK, dblock_addr, dblock, cache_flags) < 0)
         HDONE_ERROR(H5E_HEAP, H5E_CANTUNPROTECT, FAIL, "unable to release fractal heap direct block")
 
     FUNC_LEAVE_NOAPI(ret_value)
-} /* end H5HF_man_dblock_destroy() */
+} /* end H5HF__man_dblock_destroy() */
 
 /*-------------------------------------------------------------------------
- * Function:	H5HF_man_dblock_new
+ * Function:	H5HF__man_dblock_new
  *
  * Purpose:	Create a direct block large enough to hold an object of
  *              the requested size
@@ -324,13 +328,13 @@ done:
  *-------------------------------------------------------------------------
  */
 herr_t
-H5HF_man_dblock_new(H5HF_hdr_t *hdr, hid_t dxpl_id, size_t request, H5HF_free_section_t **ret_sec_node)
+H5HF__man_dblock_new(H5HF_hdr_t *hdr, size_t request, H5HF_free_section_t **ret_sec_node)
 {
     haddr_t dblock_addr;         /* Address of new direct block */
     size_t  min_dblock_size;     /* Min. size of direct block to allocate */
     herr_t  ret_value = SUCCEED; /* Return value */
 
-    FUNC_ENTER_NOAPI_NOINIT
+    FUNC_ENTER_PACKAGE
 
     /*
      * Check arguments.
@@ -347,14 +351,14 @@ H5HF_man_dblock_new(H5HF_hdr_t *hdr, hid_t dxpl_id, size_t request, H5HF_free_se
     } /* end else */
 
     /* Adjust the size of block needed to fulfill request, with overhead */
-    if ((min_dblock_size - request) < H5HF_MAN_ABS_DIRECT_OVERHEAD(hdr))
+    if (min_dblock_size < H5HF_MAN_ABS_DIRECT_OVERHEAD(hdr) + request)
         min_dblock_size *= 2;
 
     /* Check if this is the first block in the heap */
     if (!H5F_addr_defined(hdr->man_dtable.table_addr) &&
         min_dblock_size == hdr->man_dtable.cparam.start_block_size) {
         /* Create new direct block at starting offset */
-        if (H5HF_man_dblock_create(dxpl_id, hdr, NULL, 0, &dblock_addr, ret_sec_node) < 0)
+        if (H5HF__man_dblock_create(hdr, NULL, 0, &dblock_addr, ret_sec_node) < 0)
             HGOTO_ERROR(H5E_HEAP, H5E_CANTALLOC, FAIL, "can't allocate fractal heap direct block")
 
         /* Point root at new direct block */
@@ -366,8 +370,8 @@ H5HF_man_dblock_new(H5HF_hdr_t *hdr, hid_t dxpl_id, size_t request, H5HF_free_se
         } /* end if */
 
         /* Extend heap to cover new direct block */
-        if (H5HF_hdr_adjust_heap(hdr, (hsize_t)hdr->man_dtable.cparam.start_block_size,
-                                 (hssize_t)hdr->man_dtable.row_tot_dblock_free[0]) < 0)
+        if (H5HF__hdr_adjust_heap(hdr, (hsize_t)hdr->man_dtable.cparam.start_block_size,
+                                  (hssize_t)hdr->man_dtable.row_tot_dblock_free[0]) < 0)
             HGOTO_ERROR(H5E_HEAP, H5E_CANTEXTEND, FAIL, "can't increase space to cover root direct block")
     } /* end if */
     /* Root entry already exists, allocate direct block from root indirect block */
@@ -379,11 +383,11 @@ H5HF_man_dblock_new(H5HF_hdr_t *hdr, hid_t dxpl_id, size_t request, H5HF_free_se
 
         /* Update iterator to reflect any previous increments as well as allow for requested direct block size
          */
-        if (H5HF_hdr_update_iter(hdr, dxpl_id, min_dblock_size) < 0)
+        if (H5HF__hdr_update_iter(hdr, min_dblock_size) < 0)
             HGOTO_ERROR(H5E_HEAP, H5E_CANTUPDATE, FAIL, "unable to update block iterator")
 
         /* Retrieve information about current iterator position */
-        if (H5HF_man_iter_curr(&hdr->next_block, &next_row, NULL, &next_entry, &iblock) < 0)
+        if (H5HF__man_iter_curr(&hdr->next_block, &next_row, NULL, &next_entry, &iblock) < 0)
             HGOTO_ERROR(H5E_HEAP, H5E_CANTGET, FAIL, "unable to retrieve current block iterator location")
         HDassert(next_row < iblock->nrows);
         H5_CHECKED_ASSIGN(next_size, size_t, hdr->man_dtable.row_block_size[next_row], hsize_t);
@@ -392,26 +396,26 @@ H5HF_man_dblock_new(H5HF_hdr_t *hdr, hid_t dxpl_id, size_t request, H5HF_free_se
         if (min_dblock_size > next_size) {
             HDfprintf(
                 stderr,
-                "%s: Skipping direct block sizes not supported, min_dblock_size = %Zu, next_size = %Zu\n",
+                "%s: Skipping direct block sizes not supported, min_dblock_size = %zu, next_size = %zu\n",
                 FUNC, min_dblock_size, next_size);
             HGOTO_ERROR(H5E_HEAP, H5E_UNSUPPORTED, FAIL, "skipping direct block sizes not supported yet")
         } /* end if */
 
         /* Advance "next block" iterator to next direct block entry */
-        if (H5HF_hdr_inc_iter(hdr, (hsize_t)next_size, 1) < 0)
+        if (H5HF__hdr_inc_iter(hdr, (hsize_t)next_size, 1) < 0)
             HGOTO_ERROR(H5E_HEAP, H5E_CANTINC, FAIL, "can't increment 'next block' iterator")
 
         /* Create new direct block at current location*/
-        if (H5HF_man_dblock_create(dxpl_id, hdr, iblock, next_entry, &dblock_addr, ret_sec_node) < 0)
+        if (H5HF__man_dblock_create(hdr, iblock, next_entry, &dblock_addr, ret_sec_node) < 0)
             HGOTO_ERROR(H5E_HEAP, H5E_CANTALLOC, FAIL, "can't allocate fractal heap direct block")
     } /* end else */
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
-} /* end H5HF_man_dblock_new() */
+} /* end H5HF__man_dblock_new() */
 
 /*-------------------------------------------------------------------------
- * Function:	H5HF_man_dblock_protect
+ * Function:	H5HF__man_dblock_protect
  *
  * Purpose:	Convenience wrapper around H5AC_protect on a direct block
  *              (Use H5AC_unprotect to unprotect it for now)
@@ -424,14 +428,14 @@ done:
  *-------------------------------------------------------------------------
  */
 H5HF_direct_t *
-H5HF_man_dblock_protect(H5HF_hdr_t *hdr, hid_t dxpl_id, haddr_t dblock_addr, size_t dblock_size,
-                        H5HF_indirect_t *par_iblock, unsigned par_entry, H5AC_protect_t rw)
+H5HF__man_dblock_protect(H5HF_hdr_t *hdr, haddr_t dblock_addr, size_t dblock_size,
+                         H5HF_indirect_t *par_iblock, unsigned par_entry, unsigned flags)
 {
-    H5HF_direct_t         *dblock;           /* Direct block from cache */
-    H5HF_dblock_cache_ud_t udata;            /* parent and other infor for deserializing direct block */
-    H5HF_direct_t         *ret_value = NULL; /* Return value */
+    H5HF_direct_t *        dblock;           /* Direct block from cache */
+    H5HF_dblock_cache_ud_t udata;            /* parent and other info for deserializing direct block */
+    H5HF_direct_t *        ret_value = NULL; /* Return value */
 
-    FUNC_ENTER_NOAPI_NOINIT
+    FUNC_ENTER_PACKAGE
 
     /*
      * Check arguments.
@@ -440,6 +444,9 @@ H5HF_man_dblock_protect(H5HF_hdr_t *hdr, hid_t dxpl_id, haddr_t dblock_addr, siz
     HDassert(H5F_addr_defined(dblock_addr));
     HDassert(dblock_size > 0);
 
+    /* only H5AC__READ_ONLY_FLAG may appear in flags */
+    HDassert((flags & (unsigned)(~H5AC__READ_ONLY_FLAG)) == 0);
+
     /* Set up parent info */
     udata.par_info.hdr    = hdr;
     udata.par_info.iblock = par_iblock;
@@ -473,9 +480,13 @@ H5HF_man_dblock_protect(H5HF_hdr_t *hdr, hid_t dxpl_id, haddr_t dblock_addr, siz
         udata.filter_mask = 0;
     } /* end else */
 
+    /* Reset compression context info */
+    udata.decompressed = FALSE;
+    udata.dblk         = NULL;
+
     /* Protect the direct block */
     if (NULL ==
-        (dblock = (H5HF_direct_t *)H5AC_protect(hdr->f, dxpl_id, H5AC_FHEAP_DBLOCK, dblock_addr, &udata, rw)))
+        (dblock = (H5HF_direct_t *)H5AC_protect(hdr->f, H5AC_FHEAP_DBLOCK, dblock_addr, &udata, flags)))
         HGOTO_ERROR(H5E_HEAP, H5E_CANTPROTECT, NULL, "unable to protect fractal heap direct block")
 
     /* Set the return value */
@@ -483,10 +494,10 @@ H5HF_man_dblock_protect(H5HF_hdr_t *hdr, hid_t dxpl_id, haddr_t dblock_addr, siz
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
-} /* end H5HF_man_dblock_protect() */
+} /* end H5HF__man_dblock_protect() */
 
 /*-------------------------------------------------------------------------
- * Function:	H5HF_man_dblock_locate
+ * Function:	H5HF__man_dblock_locate
  *
  * Purpose:	Locate a direct block in a managed heap
  *
@@ -498,8 +509,8 @@ done:
  *-------------------------------------------------------------------------
  */
 herr_t
-H5HF_man_dblock_locate(H5HF_hdr_t *hdr, hid_t dxpl_id, hsize_t obj_off, H5HF_indirect_t **ret_iblock,
-                       unsigned *ret_entry, hbool_t *ret_did_protect, H5AC_protect_t rw)
+H5HF__man_dblock_locate(H5HF_hdr_t *hdr, hsize_t obj_off, H5HF_indirect_t **ret_iblock, unsigned *ret_entry,
+                        hbool_t *ret_did_protect, unsigned flags)
 {
     haddr_t          iblock_addr;         /* Indirect block's address */
     H5HF_indirect_t *iblock;              /* Pointer to indirect block */
@@ -508,7 +519,7 @@ H5HF_man_dblock_locate(H5HF_hdr_t *hdr, hid_t dxpl_id, hsize_t obj_off, H5HF_ind
     unsigned         entry;               /* Entry of block */
     herr_t           ret_value = SUCCEED; /* Return value */
 
-    FUNC_ENTER_NOAPI_NOINIT
+    FUNC_ENTER_PACKAGE
 
     /*
      * Check arguments.
@@ -518,16 +529,19 @@ H5HF_man_dblock_locate(H5HF_hdr_t *hdr, hid_t dxpl_id, hsize_t obj_off, H5HF_ind
     HDassert(ret_iblock);
     HDassert(ret_did_protect);
 
+    /* only H5AC__READ_ONLY_FLAG may appear in flags */
+    HDassert((flags & (unsigned)(~H5AC__READ_ONLY_FLAG)) == 0);
+
     /* Look up row & column for object */
-    if (H5HF_dtable_lookup(&hdr->man_dtable, obj_off, &row, &col) < 0)
+    if (H5HF__dtable_lookup(&hdr->man_dtable, obj_off, &row, &col) < 0)
         HGOTO_ERROR(H5E_HEAP, H5E_CANTCOMPUTE, FAIL, "can't compute row & column of object")
 
     /* Set initial indirect block info */
     iblock_addr = hdr->man_dtable.table_addr;
 
     /* Lock root indirect block */
-    if (NULL == (iblock = H5HF_man_iblock_protect(hdr, dxpl_id, iblock_addr, hdr->man_dtable.curr_root_rows,
-                                                  NULL, 0, FALSE, rw, &did_protect)))
+    if (NULL == (iblock = H5HF__man_iblock_protect(hdr, iblock_addr, hdr->man_dtable.curr_root_rows, NULL, 0,
+                                                   FALSE, flags, &did_protect)))
         HGOTO_ERROR(H5E_HEAP, H5E_CANTPROTECT, FAIL, "unable to protect fractal heap indirect block")
 
     /* Check for indirect block row */
@@ -549,7 +563,7 @@ H5HF_man_dblock_locate(H5HF_hdr_t *hdr, hid_t dxpl_id, hsize_t obj_off, H5HF_ind
 
         /* Check if we need to (re-)create the child indirect block */
         if (!H5F_addr_defined(iblock_addr)) {
-            if (H5HF_man_iblock_create(hdr, dxpl_id, iblock, entry, nrows, nrows, &iblock_addr) < 0)
+            if (H5HF__man_iblock_create(hdr, iblock, entry, nrows, nrows, &iblock_addr) < 0)
                 HGOTO_ERROR(H5E_HEAP, H5E_CANTALLOC, FAIL, "can't allocate fractal heap indirect block")
 
             /* Indicate that the parent indirect block was modified */
@@ -557,12 +571,12 @@ H5HF_man_dblock_locate(H5HF_hdr_t *hdr, hid_t dxpl_id, hsize_t obj_off, H5HF_ind
         } /* end if */
 
         /* Lock child indirect block */
-        if (NULL == (new_iblock = H5HF_man_iblock_protect(hdr, dxpl_id, iblock_addr, nrows, iblock, entry,
-                                                          FALSE, rw, &new_did_protect)))
+        if (NULL == (new_iblock = H5HF__man_iblock_protect(hdr, iblock_addr, nrows, iblock, entry, FALSE,
+                                                           flags, &new_did_protect)))
             HGOTO_ERROR(H5E_HEAP, H5E_CANTPROTECT, FAIL, "unable to protect fractal heap indirect block")
 
         /* Release the current indirect block */
-        if (H5HF_man_iblock_unprotect(iblock, dxpl_id, cache_flags, did_protect) < 0)
+        if (H5HF__man_iblock_unprotect(iblock, cache_flags, did_protect) < 0)
             HGOTO_ERROR(H5E_HEAP, H5E_CANTUNPROTECT, FAIL, "unable to release fractal heap indirect block")
 
         /* Switch variables to use new indirect block */
@@ -570,7 +584,7 @@ H5HF_man_dblock_locate(H5HF_hdr_t *hdr, hid_t dxpl_id, hsize_t obj_off, H5HF_ind
         did_protect = new_did_protect;
 
         /* Look up row & column in new indirect block for object */
-        if (H5HF_dtable_lookup(&hdr->man_dtable, (obj_off - iblock->block_off), &row, &col) < 0)
+        if (H5HF__dtable_lookup(&hdr->man_dtable, (obj_off - iblock->block_off), &row, &col) < 0)
             HGOTO_ERROR(H5E_HEAP, H5E_CANTCOMPUTE, FAIL, "can't compute row & column of object")
         HDassert(row < iblock->nrows); /* child must be smaller than parent */
     }                                  /* end while */
@@ -583,16 +597,16 @@ H5HF_man_dblock_locate(H5HF_hdr_t *hdr, hid_t dxpl_id, hsize_t obj_off, H5HF_ind
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
-} /* end H5HF_man_dblock_locate() */
+} /* end H5HF__man_dblock_locate() */
 
 /*-------------------------------------------------------------------------
- * Function:	H5HF_man_dblock_delete
+ * Function:	H5HF__man_dblock_delete
  *
  * Purpose:	Delete a managed direct block
  *
  * Note:	This routine does _not_ modify any indirect block that points
  *              to this direct block, it is assumed that the whole heap is
- *              being deleted.  (H5HF_man_dblock_destroy modifies the indirect
+ *              being deleted.  (H5HF__man_dblock_destroy modifies the indirect
  *              block)
  *
  * Return:	SUCCEED/FAIL
@@ -603,18 +617,19 @@ done:
  *-------------------------------------------------------------------------
  */
 herr_t
-H5HF_man_dblock_delete(H5F_t *f, hid_t dxpl_id, haddr_t dblock_addr, hsize_t dblock_size)
+H5HF__man_dblock_delete(H5F_t *f, haddr_t dblock_addr, hsize_t dblock_size)
 {
     unsigned dblock_status = 0;       /* Direct block's status in the metadata cache */
     herr_t   ret_value     = SUCCEED; /* Return value */
 
-    FUNC_ENTER_NOAPI_NOINIT
+    FUNC_ENTER_PACKAGE
 
     /*
      * Check arguments.
      */
     HDassert(f);
     HDassert(H5F_addr_defined(dblock_addr));
+    HDassert(dblock_size > 0);
 
     /* Check the direct block's status in the metadata cache */
     if (H5AC_get_entry_status(f, dblock_addr, &dblock_status) < 0)
@@ -627,13 +642,13 @@ H5HF_man_dblock_delete(H5F_t *f, hid_t dxpl_id, haddr_t dblock_addr, hsize_t dbl
         HDassert(!(dblock_status & H5AC_ES__IS_PROTECTED));
 
         /* Evict the direct block from the metadata cache */
-        if (H5AC_expunge_entry(f, dxpl_id, H5AC_FHEAP_DBLOCK, dblock_addr, H5AC__NO_FLAGS_SET) < 0)
+        if (H5AC_expunge_entry(f, H5AC_FHEAP_DBLOCK, dblock_addr, H5AC__NO_FLAGS_SET) < 0)
             HGOTO_ERROR(H5E_HEAP, H5E_CANTREMOVE, FAIL, "unable to remove direct block from cache")
     } /* end if */
 
     /* Check if the direct block is NOT currently allocated in temp. file space */
     /* (temp. file space does not need to be freed) */
-    if (!H5F_IS_TMP_ADDR(f, dblock_addr)) {
+    if (!H5F_IS_TMP_ADDR(f, dblock_addr))
         /* Release direct block's disk space */
         /* (XXX: Under the best of circumstances, this block's space in the file
          *          would be freed in the H5AC_expunge_entry() call above (and the
@@ -643,21 +658,17 @@ H5HF_man_dblock_delete(H5F_t *f, hid_t dxpl_id, haddr_t dblock_addr, hsize_t dbl
          *          "file_size" field for the direct block structure.  In order to
          *          do that, we'd have to protect/unprotect the direct block and
          *          that would add a bunch of unnecessary overhead to the process,
-         *          so we just release the file space here, directly.  When the
-         *          revised metadata cache is operating, it will "know" the file
-         *          size of each entry in the cache and we can the the
-         *          H5AC_expunge_entry() method.  -QAK)
+         *          so we just release the file space here, directly.  -QAK)
          */
-        if (H5MF_xfree(f, H5FD_MEM_FHEAP_DBLOCK, dxpl_id, dblock_addr, dblock_size) < 0)
-            HGOTO_ERROR(H5E_HEAP, H5E_CANTFREE, FAIL, "unable to free fractal heap direct block")
-    } /* end if */
+        if (H5MF_xfree(f, H5FD_MEM_FHEAP_DBLOCK, dblock_addr, dblock_size) < 0)
+            HGOTO_ERROR(H5E_HEAP, H5E_CANTFREE, FAIL, "unable to free fractal heap direct block file space")
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
-} /* end H5HF_man_dblock_delete() */
+} /* end H5HF__man_dblock_delete() */
 
 /*-------------------------------------------------------------------------
- * Function:	H5HF_man_dblock_dest
+ * Function:	H5HF__man_dblock_dest
  *
  * Purpose:	Destroys a fractal heap direct block in memory.
  *
@@ -669,11 +680,11 @@ done:
  *-------------------------------------------------------------------------
  */
 herr_t
-H5HF_man_dblock_dest(H5HF_direct_t *dblock)
+H5HF__man_dblock_dest(H5HF_direct_t *dblock)
 {
     herr_t ret_value = SUCCEED; /* Return value */
 
-    FUNC_ENTER_NOAPI_NOINIT
+    FUNC_ENTER_PACKAGE
 
     /*
      * Check arguments.
@@ -682,10 +693,10 @@ H5HF_man_dblock_dest(H5HF_direct_t *dblock)
 
     /* Decrement reference count on shared fractal heap info */
     HDassert(dblock->hdr != NULL);
-    if (H5HF_hdr_decr(dblock->hdr) < 0)
+    if (H5HF__hdr_decr(dblock->hdr) < 0)
         HGOTO_ERROR(H5E_HEAP, H5E_CANTDEC, FAIL, "can't decrement reference count on shared heap header")
     if (dblock->parent)
-        if (H5HF_iblock_decr(dblock->parent) < 0)
+        if (H5HF__iblock_decr(dblock->parent) < 0)
             HGOTO_ERROR(H5E_HEAP, H5E_CANTDEC, FAIL,
                         "can't decrement reference count on shared indirect block")
 
@@ -697,4 +708,4 @@ H5HF_man_dblock_dest(H5HF_direct_t *dblock)
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
-} /* end H5HF_man_dblock_dest() */
+} /* end H5HF__man_dblock_dest() */
