@@ -15,19 +15,13 @@
  * Programmer:  Robb Matzke
  *              Tuesday, March  3, 1998
  *
- * Purpose:	Tests datasets stored in external raw files.
+ * Purpose:    Tests datasets stored in external raw files.
  */
-#include "h5test.h"
+#include "external_common.h"
+#include "external_fname.h"
 
-const char *FILENAME[] = {"extern_1", "extern_2", "extern_3", "extern_4", "extern_dir/file_1", NULL};
-
-/* A similar collection of files is used for the tests that
- * perform file I/O.
- */
-#define N_EXT_FILES      4
-#define PART_SIZE        25
-#define TOTAL_SIZE       100
-#define GARBAGE_PER_FILE 10
+#define AEF_EXNAME_MAX_LEN 12 /* string buffer size for external file name */
+                              /* used in __add_external_files()            */
 
 /*-------------------------------------------------------------------------
  * Function:    files_have_same_contents
@@ -35,7 +29,7 @@ const char *FILENAME[] = {"extern_1", "extern_2", "extern_3", "extern_4", "exter
  * Purpose:     Determines whether two files contain the same data.
  *
  * Return:      Success:    nonzero if same, zero if different.
- *		        Failure:    zero
+ *              Failure:    zero
  *
  * Programmer:  Robb Matzke
  *              Wednesday, March  4, 1998
@@ -45,14 +39,17 @@ const char *FILENAME[] = {"extern_1", "extern_2", "extern_3", "extern_4", "exter
 static hbool_t
 files_have_same_contents(const char *name1, const char *name2)
 {
-    int     fd1 = 0, fd2 = 0;
-    ssize_t n1, n2;
-    char    buf1[1024], buf2[1024];
+    int     fd1 = 0;
+    int     fd2 = 0;
+    ssize_t n1  = 0;
+    ssize_t n2  = 0;
+    char    buf1[1024];
+    char    buf2[1024];
     hbool_t ret = FALSE; /* not equal until proven otherwise */
 
-    if ((fd1 = HDopen(name1, O_RDONLY, 0666)) < 0)
+    if ((fd1 = HDopen(name1, O_RDONLY)) < 0)
         goto out;
-    if ((fd2 = HDopen(name2, O_RDONLY, 0666)) < 0)
+    if ((fd2 = HDopen(name2, O_RDONLY)) < 0)
         goto out;
 
     /* Loop until files are empty or we encounter a problem */
@@ -75,7 +72,7 @@ files_have_same_contents(const char *name1, const char *name2)
             break;
         }
 
-        if (HDmemcmp(buf1, buf2, (size_t)n1))
+        if (HDmemcmp(buf1, buf2, (size_t)n1) != 0)
             break;
 
     } /* end while */
@@ -88,105 +85,6 @@ out:
     return ret;
 } /* end files_have_same_contents() */
 
-/*-------------------------------------------------------------------------
- * Function:    reset_raw_data_files
- *
- * Purpose:     Resets the data in the raw data files for tests that
- *              perform dataset I/O on a set of files.
- *
- * Return:      SUCCEED/FAIL
- *
- * Programmer:  Dana Robinson
- *              February 2016
- *
- *-------------------------------------------------------------------------
- */
-static herr_t
-reset_raw_data_files(void)
-{
-    int      fd = 0;          /* external file descriptor             */
-    size_t   i, j;            /* iterators                            */
-    hssize_t n;               /* bytes of I/O                         */
-    char     filename[1024];  /* file name                            */
-    int      data[PART_SIZE]; /* raw data buffer                      */
-    uint8_t *garbage = NULL;  /* buffer of garbage data               */
-    size_t   garbage_count;   /* size of garbage buffer               */
-    size_t   garbage_bytes;   /* # of garbage bytes written to file   */
-
-    /* Set up garbage buffer */
-    garbage_count = N_EXT_FILES * GARBAGE_PER_FILE;
-    if (NULL == (garbage = (uint8_t *)HDcalloc(garbage_count, sizeof(uint8_t))))
-        goto error;
-    for (i = 0; i < garbage_count; i++)
-        garbage[i] = 0xFF;
-
-    /* The *r files are pre-filled with data and are used to
-     * verify that read operations work correctly.
-     */
-    for (i = 0; i < N_EXT_FILES; i++) {
-
-        /* Open file */
-        HDsprintf(filename, "extern_%lur.raw", (unsigned long)i + 1);
-        if ((fd = HDopen(filename, O_RDWR | O_CREAT | O_TRUNC, 0666)) < 0)
-            goto error;
-
-        /* Write garbage data to the file. This allows us to test the
-         * the ability to set an offset in the raw data file.
-         */
-        garbage_bytes = i * 10;
-        n             = HDwrite(fd, garbage, garbage_bytes);
-        if (n < 0 || (size_t)n != garbage_bytes)
-            goto error;
-
-        /* Fill array with data */
-        for (j = 0; j < PART_SIZE; j++) {
-            data[j] = (int)(i * 25 + j);
-        } /* end for */
-
-        /* Write raw data to the file. */
-        n = HDwrite(fd, data, sizeof(data));
-        if (n != sizeof(data))
-            goto error;
-
-        /* Close this file */
-        HDclose(fd);
-
-    } /* end for */
-
-    /* The *w files are only pre-filled with the garbage data and are
-     * used to verify that write operations work correctly. The individual
-     * tests fill in the actual data.
-     */
-    for (i = 0; i < N_EXT_FILES; i++) {
-
-        /* Open file */
-        HDsprintf(filename, "extern_%luw.raw", (unsigned long)i + 1);
-        if ((fd = HDopen(filename, O_RDWR | O_CREAT | O_TRUNC, 0666)) < 0)
-            goto error;
-
-        /* Write garbage data to the file. This allows us to test the
-         * the ability to set an offset in the raw data file.
-         */
-        garbage_bytes = i * 10;
-        n             = HDwrite(fd, garbage, garbage_bytes);
-        if (n < 0 || (size_t)n != garbage_bytes)
-            goto error;
-
-        /* Close this file */
-        HDclose(fd);
-
-    } /* end for */
-    HDfree(garbage);
-    return SUCCEED;
-
-error:
-    if (fd)
-        HDclose(fd);
-    if (garbage)
-        HDfree(garbage);
-    return FAIL;
-} /* end reset_raw_data_files() */
-
 /*-------------------------------------------------------------------------
  * Function:    test_non_extendible
  *
@@ -203,23 +101,21 @@ error:
 static int
 test_non_extendible(hid_t file)
 {
-    hid_t   dcpl  = -1;  /* dataset creation properties          */
-    hid_t   space = -1;  /* data space                           */
-    hid_t   dset  = -1;  /* dataset                              */
-    hsize_t cur_size[1]; /* data space current size              */
-    hsize_t max_size[1]; /* data space maximum size              */
-    int     n;           /* number of external files             */
-    char    name[256];   /* external file name                   */
-    off_t   file_offset; /* external file offset                 */
-    hsize_t file_size;   /* sizeof external file segment         */
-    haddr_t dset_addr;   /* address of dataset                   */
+    hid_t   dcpl        = -1;          /* dataset creation properties          */
+    hid_t   space       = -1;          /* data space                           */
+    hid_t   dset        = -1;          /* dataset                              */
+    hsize_t cur_size[1] = {100};       /* data space current size              */
+    hsize_t max_size[1] = {100};       /* data space maximum size              */
+    int     n           = 0;           /* number of external files             */
+    off_t   file_offset = 0;           /* external file offset                 */
+    hsize_t file_size   = 0;           /* sizeof external file segment         */
+    haddr_t dset_addr   = HADDR_UNDEF; /* address of dataset                   */
 
     TESTING("fixed-size data space, exact storage");
 
-    /* Create the dataset */
+    /* Create the dataset and close */
     if ((dcpl = H5Pcreate(H5P_DATASET_CREATE)) < 0)
         FAIL_STACK_ERROR
-    cur_size[0] = max_size[0] = 100;
     if (H5Pset_external(dcpl, "ext1.data", (off_t)0, (hsize_t)(max_size[0] * sizeof(int))) < 0)
         FAIL_STACK_ERROR
     if ((space = H5Screate_simple(1, cur_size, max_size)) < 0)
@@ -256,28 +152,24 @@ test_non_extendible(hid_t file)
         HDputs("    Returned external count is wrong.");
         HDprintf("   got: %d\n    ans: 1\n", n);
         goto error;
-    } /* end if */
+    }
 
-    HDstrcpy(name + sizeof(name) - 4, "...");
-    if (H5Pget_external(dcpl, 0, sizeof(name) - 4, name, &file_offset, &file_size) < 0)
+    /* Verify external file settings */
+    if (H5Pget_external(dcpl, 0, 0, NULL, &file_offset, &file_size) < 0)
         FAIL_STACK_ERROR
-
-    /* Check file offset */
     if (file_offset != 0) {
         H5_FAILED();
         HDputs("    Wrong file offset.");
         HDprintf("    got: %lu\n    ans: 0\n", (unsigned long)file_offset);
         goto error;
-    } /* end if */
-
-    /* Check file size */
+    }
     if (file_size != (max_size[0] * sizeof(int))) {
         H5_FAILED();
         HDputs("    Wrong file size.");
         HDprintf("    got: %lu\n    ans: %lu\n", (unsigned long)file_size,
                  (unsigned long)max_size[0] * sizeof(int));
         goto error;
-    } /* end if */
+    }
 
     /* Done (dataspace was previously closed) */
     if (H5Pclose(dcpl) < 0)
@@ -307,7 +199,7 @@ error:
  * Return:      Success:    0
  *              Failure:    1
  *
- * Programmer:	Robb Matzke
+ * Programmer:  Robb Matzke
  *              Monday, November 23, 1998
  *
  *-------------------------------------------------------------------------
@@ -315,18 +207,18 @@ error:
 static int
 test_too_small(hid_t file)
 {
-    hid_t   dcpl  = -1;  /* dataset creation properties          */
-    hid_t   space = -1;  /* data space                           */
-    hid_t   dset  = -1;  /* dataset                              */
-    hsize_t cur_size[1]; /* current data space size              */
-    hsize_t max_size[1]; /* maximum data space size              */
+    hid_t   dcpl        = -1;    /* dataset creation properties          */
+    hid_t   space       = -1;    /* data space                           */
+    hid_t   dset        = -1;    /* dataset                              */
+    hsize_t cur_size[1] = {100}; /* current data space size              */
+    hsize_t max_size[1] = {100}; /* maximum data space size              */
 
     TESTING("external storage is too small");
 
     if ((dcpl = H5Pcreate(H5P_DATASET_CREATE)) < 0)
         FAIL_STACK_ERROR
-    cur_size[0] = max_size[0] = 100;
-    if (H5Pset_external(dcpl, "ext1.data", (off_t)0, (hsize_t)(max_size[0] * sizeof(int) - 1)) < 0)
+    if (H5Pset_external(dcpl, "ext1.data", (off_t)0, (hsize_t)(max_size[0] * sizeof(int) - 1)) <
+        0) /* note -1 */
         FAIL_STACK_ERROR
     if ((space = H5Screate_simple(1, cur_size, max_size)) < 0)
         FAIL_STACK_ERROR
@@ -364,10 +256,10 @@ error:
  *              represent the current data and large enough to represent the
  *              eventual size of the data.
  *
- * Return:  Success:    0
- *          Failure:    1
+ * Return:      Success:    0
+ *              Failure:    1
  *
- * Programmer:	Robb Matzke
+ * Programmer:  Robb Matzke
  *              Monday, November 23, 1998
  *
  *-------------------------------------------------------------------------
@@ -375,18 +267,16 @@ error:
 static int
 test_large_enough_current_eventual(hid_t file)
 {
-    hid_t   dcpl  = -1;  /* dataset creation properties          */
-    hid_t   space = -1;  /* data space                           */
-    hid_t   dset  = -1;  /* dataset                              */
-    hsize_t cur_size[1]; /* current data space size              */
-    hsize_t max_size[1]; /* maximum data space size              */
+    hid_t   dcpl        = -1;    /* dataset creation properties          */
+    hid_t   space       = -1;    /* data space                           */
+    hid_t   dset        = -1;    /* dataset                              */
+    hsize_t cur_size[1] = {100}; /* current data space size              */
+    hsize_t max_size[1] = {200}; /* maximum data space size              */
 
     TESTING("extendible dataspace, exact external size");
 
     if ((dcpl = H5Pcreate(H5P_DATASET_CREATE)) < 0)
         FAIL_STACK_ERROR
-    cur_size[0] = 100;
-    max_size[0] = 200;
     if (H5Pset_external(dcpl, "ext1.data", (off_t)0, (hsize_t)(max_size[0] * sizeof(int))) < 0)
         FAIL_STACK_ERROR
     if ((space = H5Screate_simple(1, cur_size, max_size)) < 0)
@@ -432,19 +322,18 @@ error:
 static int
 test_large_enough_current_not_eventual(hid_t file)
 {
-    hid_t   dcpl  = -1;  /* dataset creation properties          */
-    hid_t   space = -1;  /* data space                           */
-    hid_t   dset  = -1;  /* dataset                              */
-    hsize_t cur_size[1]; /* current data space size              */
-    hsize_t max_size[1]; /* maximum data space size              */
+    hid_t   dcpl        = -1;    /* dataset creation properties          */
+    hid_t   space       = -1;    /* data space                           */
+    hid_t   dset        = -1;    /* dataset                              */
+    hsize_t cur_size[1] = {100}; /* current data space size              */
+    hsize_t max_size[1] = {200}; /* maximum data space size              */
 
     TESTING("extendible dataspace, external storage is too small");
 
     if ((dcpl = H5Pcreate(H5P_DATASET_CREATE)) < 0)
         FAIL_STACK_ERROR
-    cur_size[0] = 100;
-    max_size[0] = 200;
-    if (H5Pset_external(dcpl, "ext1.data", (off_t)0, (hsize_t)(max_size[0] * sizeof(int) - 1)) < 0)
+    if (H5Pset_external(dcpl, "ext1.data", (off_t)0, (hsize_t)(max_size[0] * sizeof(int) - 1)) <
+        0) /* note -1 */
         FAIL_STACK_ERROR
     if ((space = H5Screate_simple(1, cur_size, max_size)) < 0)
         FAIL_STACK_ERROR
@@ -493,15 +382,14 @@ error:
 static int
 test_unlimited(hid_t file)
 {
-    hid_t   dcpl  = -1;  /* dataset creation properties          */
-    hid_t   space = -1;  /* data space                           */
-    hid_t   dset  = -1;  /* dataset                              */
-    hsize_t cur_size[1]; /* data space current size              */
-    hsize_t max_size[1]; /* data space maximum size              */
-    int     n;           /* number of external files             */
-    char    name[256];   /* external file name                   */
-    off_t   file_offset; /* external file offset                 */
-    hsize_t file_size;   /* sizeof external file segment         */
+    hid_t   dcpl        = -1;              /* dataset creation properties   */
+    hid_t   space       = -1;              /* data space                    */
+    hid_t   dset        = -1;              /* dataset                       */
+    hsize_t cur_size[1] = {100};           /* data space current size       */
+    hsize_t max_size[1] = {H5S_UNLIMITED}; /* data space maximum size       */
+    int     n;                             /* number of external files      */
+    off_t   file_offset;                   /* external file offset          */
+    hsize_t file_size;                     /* sizeof external file segment  */
 
     TESTING("unlimited dataspace, unlimited external storage");
 
@@ -510,8 +398,6 @@ test_unlimited(hid_t file)
         FAIL_STACK_ERROR
     if (H5Pset_external(dcpl, "ext1.data", (off_t)0, H5F_UNLIMITED) < 0)
         FAIL_STACK_ERROR
-    cur_size[0] = 100;
-    max_size[0] = H5S_UNLIMITED;
     if ((space = H5Screate_simple(1, cur_size, max_size)) < 0)
         FAIL_STACK_ERROR
     if ((dset = H5Dcreate2(file, "dset5", H5T_NATIVE_INT, space, H5P_DEFAULT, dcpl, H5P_DEFAULT)) < 0)
@@ -538,22 +424,20 @@ test_unlimited(hid_t file)
         goto error;
     } /* end if */
 
-    HDstrcpy(name + sizeof(name) - 4, "...");
-    if (H5Pget_external(dcpl, 0, sizeof(name) - 4, name, &file_offset, &file_size) < 0)
+    if (H5Pget_external(dcpl, 0, 0, NULL, &file_offset, &file_size) < 0)
         FAIL_STACK_ERROR
     if (file_offset != 0) {
         H5_FAILED();
         HDputs("    Wrong file offset.");
         HDprintf("    got: %lu\n    ans: 0\n", (unsigned long)file_offset);
         goto error;
-    } /* end if */
-
+    }
     if (H5F_UNLIMITED != file_size) {
         H5_FAILED();
         HDputs("    Wrong file size.");
         HDprintf("    got: %lu\n    ans: INF\n", (unsigned long)file_size);
         goto error;
-    } /* end if */
+    }
 
     if (H5Pclose(dcpl) < 0)
         FAIL_STACK_ERROR
@@ -574,6 +458,45 @@ error:
     return 1;
 } /* end test_unlimited() */
 
+/*-------------------------------------------------------------------------
+ * Function:    __add_external_files
+ *
+ * Purpose:     Add external file names to the DCPL with the given properties.
+ *              Used in test_multiple_files().
+ *              Limit to no more than 999 external files.
+ *
+ * Return:      Success:    0
+ *              Failure:    -1
+ *
+ * Programmer:  Jacob Smith
+ *              29 Sep 2019
+ *
+ *-------------------------------------------------------------------------
+ */
+static int
+add_external_files(hid_t dcpl_id, unsigned int n_external_files, off_t offset, hsize_t max_ext_size)
+{
+    char         exname[AEF_EXNAME_MAX_LEN + 1];
+    unsigned int i = 0;
+
+    if (dcpl_id < 0) {
+        return -1;
+    }
+    for (i = 0; i < n_external_files; i++) {
+        if (HDsnprintf(exname, AEF_EXNAME_MAX_LEN, "ext%d.data", i + 1) > AEF_EXNAME_MAX_LEN) {
+            HDfprintf(stderr, "External file %d overflows name buffer\n", i + 1);
+            HDfflush(stderr);
+            return -1;
+        }
+        if (H5Pset_external(dcpl_id, exname, offset, max_ext_size) < 0) {
+            HDfprintf(stderr, "Problem adding external file %s\n", exname);
+            HDfflush(stderr);
+            return -1;
+        }
+    }
+    return 0;
+} /* end __add_external_files() */
+
 /*-------------------------------------------------------------------------
  * Function:    test_multiple_files
  *
@@ -590,38 +513,61 @@ error:
 static int
 test_multiple_files(hid_t file)
 {
-    hid_t   dcpl  = -1;  /* dataset creation properties          */
-    hid_t   space = -1;  /* dataspace                            */
-    hid_t   dset  = -1;  /* dataset                              */
-    hsize_t cur_size[1]; /* data space current size              */
-    hsize_t max_size[1]; /* data space maximum size              */
+    hid_t        dcpl        = -1;    /* dataset creation properties         */
+    hid_t        space       = -1;    /* dataspace                           */
+    hid_t        dset        = -1;    /* dataset                             */
+    hsize_t      cur_size[1] = {100}; /* data space current size             */
+    hsize_t      max_size[1] = {100}; /* data space maximum size             */
+    hsize_t      max_ext_size;        /* maximum size of external files      */
+    unsigned int n_external_files = 4;
 
     TESTING("multiple external files");
 
     if ((dcpl = H5Pcreate(H5P_DATASET_CREATE)) < 0)
         FAIL_STACK_ERROR
 
-    cur_size[0] = max_size[0] = 100;
+    max_ext_size = (hsize_t)(sizeof(int) * max_size[0] / n_external_files);
+
+    if (add_external_files(dcpl, n_external_files, 0, max_ext_size) < 0) {
+        FAIL_STACK_ERROR;
+    }
 
-    if (H5Pset_external(dcpl, "ext1.data", (off_t)0, (hsize_t)(max_size[0] * sizeof(int) / 4)) < 0)
-        FAIL_STACK_ERROR
-    if (H5Pset_external(dcpl, "ext2.data", (off_t)0, (hsize_t)(max_size[0] * sizeof(int) / 4)) < 0)
-        FAIL_STACK_ERROR
-    if (H5Pset_external(dcpl, "ext3.data", (off_t)0, (hsize_t)(max_size[0] * sizeof(int) / 4)) < 0)
-        FAIL_STACK_ERROR
-    if (H5Pset_external(dcpl, "ext4.data", (off_t)0, (hsize_t)(max_size[0] * sizeof(int) / 4)) < 0)
-        FAIL_STACK_ERROR
     if ((space = H5Screate_simple(1, cur_size, max_size)) < 0)
         FAIL_STACK_ERROR
+
     if ((dset = H5Dcreate2(file, "dset6", H5T_NATIVE_INT, space, H5P_DEFAULT, dcpl, H5P_DEFAULT)) < 0)
         FAIL_STACK_ERROR
 
     if (H5Dclose(dset) < 0)
         FAIL_STACK_ERROR
-    if (H5Sclose(space) < 0)
-        FAIL_STACK_ERROR
     if (H5Pclose(dcpl) < 0)
         FAIL_STACK_ERROR
+    /* Re-use space below */
+
+    /* ----------------------------------------------
+     * Verify that too-small external files will fail
+     */
+    if ((dcpl = H5Pcreate(H5P_DATASET_CREATE)) < 0)
+        FAIL_STACK_ERROR
+
+    max_ext_size -= 1;
+
+    if (add_external_files(dcpl, n_external_files, 0, max_ext_size) < 0) {
+        FAIL_STACK_ERROR;
+    }
+
+    H5E_BEGIN_TRY
+    {
+        dset = H5Dcreate2(file, "dset7", H5T_NATIVE_INT, space, H5P_DEFAULT, dcpl, H5P_DEFAULT);
+    }
+    H5E_END_TRY;
+    if (dset >= 0)
+        FAIL_PUTS_ERROR("    Small external files succeeded instead of failing.");
+
+    if (H5Pclose(dcpl) < 0)
+        FAIL_STACK_ERROR
+    if (H5Sclose(space) < 0)
+        FAIL_STACK_ERROR
 
     PASSED();
     return 0;
@@ -654,9 +600,9 @@ error:
 static int
 test_add_to_unlimited(void)
 {
-    hid_t  dcpl = -1; /* dataset creation properties          */
-    herr_t status;    /* function return status               */
-    int    n;         /* number of external files             */
+    hid_t  dcpl   = -1;   /* dataset creation properties          */
+    herr_t status = FAIL; /* function return status               */
+    int    n      = 0;    /* number of external files             */
 
     TESTING("external file following unlimited file");
 
@@ -709,8 +655,8 @@ error:
 static int
 test_overflow(void)
 {
-    hid_t  dcpl = -1; /* dataset creation properties          */
-    herr_t status;    /* return status                        */
+    hid_t  dcpl   = -1;   /* dataset creation properties          */
+    herr_t status = FAIL; /* return status                        */
 
     TESTING("address overflow in external files");
 
@@ -763,7 +709,7 @@ test_read_file_set(hid_t fapl)
     hid_t   space = -1;        /* data space                           */
     hid_t   dset  = -1;        /* dataset                              */
     hid_t   grp   = -1;        /* group to emit diagnostics            */
-    size_t  i;                 /* miscellaneous counter                */
+    size_t  i     = 0;         /* miscellaneous counter                */
     char    filename[1024];    /* file names                           */
     int     part[PART_SIZE];   /* raw data buffer (partial)            */
     int     whole[TOTAL_SIZE]; /* raw data buffer (total)              */
@@ -778,14 +724,14 @@ test_read_file_set(hid_t fapl)
         TEST_ERROR
 
     /* Reset the raw data files */
-    if (reset_raw_data_files() < 0)
+    if (reset_raw_data_files(FALSE) < 0)
         TEST_ERROR
 
     /* Create the file and an initial group.  This causes messages about
      * debugging to be emitted before we start playing games with what the
      * output looks like.
      */
-    h5_fixname(FILENAME[1], fapl, filename, sizeof(filename));
+    h5_fixname(EXT_FNAME[1], fapl, filename, sizeof(filename));
     if ((file = H5Fcreate(filename, H5F_ACC_TRUNC, H5P_DEFAULT, fapl)) < 0)
         FAIL_STACK_ERROR
     if ((grp = H5Gcreate2(file, "emit-diagnostics", H5P_DEFAULT, H5P_DEFAULT, H5P_DEFAULT)) < 0)
@@ -800,7 +746,7 @@ test_read_file_set(hid_t fapl)
         HDsnprintf(filename, sizeof(filename), "extern_%dr.raw", (int)i + 1);
         if (H5Pset_external(dcpl, filename, (off_t)(i * GARBAGE_PER_FILE), (hsize_t)sizeof(part)) < 0)
             FAIL_STACK_ERROR
-    } /* end for */
+    }
 
     /* Create the dataspace */
     cur_size = TOTAL_SIZE;
@@ -856,6 +802,7 @@ test_read_file_set(hid_t fapl)
 error:
     H5E_BEGIN_TRY
     {
+        H5Gclose(grp);
         H5Dclose(dset);
         H5Pclose(dcpl);
         H5Sclose(space);
@@ -887,7 +834,7 @@ test_write_file_set(hid_t fapl)
     hid_t    mem_space  = -1;   /* memory data space                    */
     hid_t    file_space = -1;   /* file data space                      */
     hid_t    dset       = -1;   /* dataset                              */
-    unsigned i;                 /* miscellaneous counter                */
+    unsigned i          = 0;    /* miscellaneous counter                */
     int      part[PART_SIZE];   /* raw data buffer (partial)            */
     int      whole[TOTAL_SIZE]; /* raw data buffer (total)              */
     hsize_t  cur_size = 100;    /* current data space size              */
@@ -902,7 +849,7 @@ test_write_file_set(hid_t fapl)
         TEST_ERROR
 
     /* Create another file */
-    h5_fixname(FILENAME[2], fapl, filename, sizeof(filename));
+    h5_fixname(EXT_FNAME[2], fapl, filename, sizeof(filename));
     if ((file = H5Fcreate(filename, H5F_ACC_TRUNC, H5P_DEFAULT, fapl)) < 0)
         FAIL_STACK_ERROR
 
@@ -924,7 +871,7 @@ test_write_file_set(hid_t fapl)
     } /* end for */
 
     /* Reset the raw data files */
-    if (reset_raw_data_files() < 0)
+    if (reset_raw_data_files(FALSE) < 0)
         TEST_ERROR
 
     /* Create the dataset */
@@ -943,8 +890,8 @@ test_write_file_set(hid_t fapl)
     for (i = 0; i < N_EXT_FILES; i++) {
         char name1[64], name2[64];
 
-        HDsprintf(name1, "extern_%dr.raw", i + 1);
-        HDsprintf(name2, "extern_%dw.raw", i + 1);
+        HDsnprintf(name1, sizeof(name1), "extern_%dr.raw", i + 1);
+        HDsnprintf(name2, sizeof(name2), "extern_%dw.raw", i + 1);
         if (!files_have_same_contents(name1, name2))
             FAIL_PUTS_ERROR("   Output differs from expected value.")
     } /* end for */
@@ -1016,21 +963,21 @@ test_path_absolute(hid_t fapl)
     hid_t   dcpl  = -1;        /* dataset creation properties          */
     hid_t   space = -1;        /* data space                           */
     hid_t   dset  = -1;        /* dataset                              */
-    size_t  i;                 /* miscellaneous counter                */
+    size_t  i     = 0;         /* miscellaneous counter                */
     char    cwdpath[1024];     /* working directory                    */
-    char    filename[1024];    /* file name                            */
+    char    filename[1088];    /* file name                            */
     int     part[PART_SIZE];   /* raw data buffer (partial)            */
     int     whole[TOTAL_SIZE]; /* raw data buffer (total)              */
     hsize_t cur_size;          /* current data space size              */
 
     TESTING("absolute filenames for external file");
 
-    h5_fixname(FILENAME[3], fapl, filename, sizeof(filename));
+    h5_fixname(EXT_FNAME[3], fapl, filename, sizeof(filename));
     if ((file = H5Fcreate(filename, H5F_ACC_TRUNC, H5P_DEFAULT, fapl)) < 0)
         FAIL_STACK_ERROR
 
     /* Reset the raw data files */
-    if (reset_raw_data_files() < 0)
+    if (reset_raw_data_files(FALSE) < 0)
         TEST_ERROR
 
     /* Create the dcpl */
@@ -1125,12 +1072,12 @@ test_path_relative(hid_t fapl)
     if (HDmkdir("extern_dir", (mode_t)0755) < 0 && errno != EEXIST)
         TEST_ERROR;
 
-    h5_fixname(FILENAME[4], fapl, filename, sizeof(filename));
+    h5_fixname(EXT_FNAME[4], fapl, filename, sizeof(filename));
     if ((file = H5Fcreate(filename, H5F_ACC_TRUNC, H5P_DEFAULT, fapl)) < 0)
         FAIL_STACK_ERROR;
 
     /* Reset the raw data files */
-    if (reset_raw_data_files() < 0)
+    if (reset_raw_data_files(FALSE) < 0)
         TEST_ERROR
 
     /* Create the dataset */
@@ -1222,12 +1169,12 @@ test_path_relative_cwd(hid_t fapl)
     if (HDmkdir("extern_dir", (mode_t)0755) < 0 && errno != EEXIST)
         TEST_ERROR;
 
-    h5_fixname(FILENAME[4], fapl, filename, sizeof(filename));
+    h5_fixname(EXT_FNAME[4], fapl, filename, sizeof(filename));
     if ((file = H5Fcreate(filename, H5F_ACC_TRUNC, H5P_DEFAULT, fapl)) < 0)
         FAIL_STACK_ERROR;
 
     /* Reset the raw data files */
-    if (reset_raw_data_files() < 0)
+    if (reset_raw_data_files(FALSE) < 0)
         TEST_ERROR
 
     /* Create the dataset */
@@ -1270,7 +1217,7 @@ test_path_relative_cwd(hid_t fapl)
     }
     H5E_END_TRY;
     if (dset3 >= 0)
-        FAIL_PUTS_ERROR("reopening the dataset with a different efile_prefix succeded");
+        FAIL_PUTS_ERROR("reopening the dataset with a different efile_prefix succeeded");
 
     /* Read the entire dataset and compare with the original */
     HDmemset(whole, 0, sizeof(whole));
@@ -1286,7 +1233,7 @@ test_path_relative_cwd(hid_t fapl)
     if (H5Dclose(dset) < 0)
         FAIL_STACK_ERROR
 
-    /* Open dataset (use a differend prefix than for create.
+    /* Open dataset (use a different prefix than for create.
      * This works because the dataset was closed.
      */
     if (H5Pset_efile_prefix(dapl2, "${ORIGIN}/.") < 0)
@@ -1307,7 +1254,7 @@ test_path_relative_cwd(hid_t fapl)
     }
     H5E_END_TRY;
     if (dset3 >= 0)
-        FAIL_PUTS_ERROR("reopening the dataset with a different efile_prefix succeded");
+        FAIL_PUTS_ERROR("reopening the dataset with a different efile_prefix succeeded");
 
     /* Read the entire dataset and compare with the original */
     HDmemset(whole, 0, sizeof(whole));
@@ -1351,120 +1298,109 @@ error:
 } /* end test_path_relative_cwd() */
 
 /*-------------------------------------------------------------------------
- * Function:    test_path_env
+ * Function:    test_h5d_get_access_plist
  *
- * Purpose:     Test whether the value of HDF5_EXTFILE_PREFIX will overwrite
- *              the efile_prefix dataset access property.
- *              This will create an HDF5 file in a subdirectory which will
- *              refer to ../extern_*a.raw
- *              The files are then accessed by setting the HDF5_EXTFILE_PREFIX
- *              environment variable to "${ORIGIN}".
- *              The efile_prefix dataset access property is set to "someprefix",
- *              which will cause an error if the value is not overwritten by
- *              the environment variable.
+ * Purpose:     Ensure that H5Dget_access_plist returns correct values.
  *
  * Return:      Success:    0
  *              Failure:    1
  *
- * Programmer:  Steffen Kiess
- *              March 10, 2015
+ * Programmer:  Dana Robinson
+ *              March 2016
  *
  *-------------------------------------------------------------------------
  */
 static int
-test_path_env(hid_t fapl)
+test_h5d_get_access_plist(hid_t fapl_id)
 {
-    hid_t   file  = -1;        /* file to write to                     */
-    hid_t   dcpl  = -1;        /* dataset creation properties          */
-    hid_t   space = -1;        /* data space                           */
-    hid_t   dapl  = -1;        /* dataset access property list         */
-    hid_t   dset  = -1;        /* dataset                              */
-    size_t  i;                 /* miscellaneous counters               */
-    char    cwdpath[1024];     /* working directory                    */
-    char    filename[1088];    /* file name                            */
-    int     part[PART_SIZE];   /* raw data buffer (partial)            */
-    int     whole[TOTAL_SIZE]; /* raw data buffer (total)              */
-    hsize_t cur_size;          /* current data space size              */
-    char    buffer[1024];      /* buffer to read efile_prefix          */
+    hid_t   fid     = -1;   /* file to write to                     */
+    hid_t   dcpl_id = -1;   /* dataset creation properties          */
+    hid_t   dapl_id = -1;   /* dataset access properties            */
+    hid_t   sid     = -1;   /* data space                           */
+    hid_t   did     = -1;   /* dataset                              */
+    hsize_t dims    = 0;    /* dataset size                         */
+    char *  buffer  = NULL; /* saved prefix name from dapl          */
+    char    filename[1024]; /* file names                           */
 
-    TESTING("prefix in HDF5_EXTFILE_PREFIX");
+    TESTING("H5Dget_access_plist() returns correct prefix");
 
-    if (HDsetenv("HDF5_EXTFILE_PREFIX", "${ORIGIN}", 1))
+    if (HDsetenv("HDF5_EXTFILE_PREFIX", "", 1) < 0)
         TEST_ERROR
 
-    if (HDmkdir("extern_dir", (mode_t)0755) < 0 && errno != EEXIST)
-        TEST_ERROR;
-
-    h5_fixname(FILENAME[4], fapl, filename, sizeof(filename));
-    if ((file = H5Fcreate(filename, H5F_ACC_TRUNC, H5P_DEFAULT, fapl)) < 0)
-        FAIL_STACK_ERROR
-
     /* Reset the raw data files */
-    if (reset_raw_data_files() < 0)
+    if (reset_raw_data_files(FALSE) < 0)
         TEST_ERROR
 
+    /* Create the file */
+    h5_fixname(EXT_FNAME[5], fapl_id, filename, sizeof(filename));
+    if ((fid = H5Fcreate(filename, H5F_ACC_TRUNC, H5P_DEFAULT, fapl_id)) < 0)
+        FAIL_STACK_ERROR
+
+    /* Create the dcpl and set external storage */
+    if ((dcpl_id = H5Pcreate(H5P_DATASET_CREATE)) < 0)
+        FAIL_STACK_ERROR
+    if (H5Pset_external(dcpl_id, "extern_1r.raw", (off_t)0, (hsize_t)0) < 0)
+        FAIL_STACK_ERROR
+
+    /* Create the dapl and set the prefix */
+    if ((dapl_id = H5Pcreate(H5P_DATASET_ACCESS)) < 0)
+        FAIL_STACK_ERROR
+    if (H5Pset_efile_prefix(dapl_id, "someprefix") < 0)
+        FAIL_STACK_ERROR
+
     /* Create the dataset */
-    if ((dcpl = H5Pcreate(H5P_DATASET_CREATE)) < 0)
+    if ((sid = H5Screate_simple(1, &dims, NULL)) < 0)
         FAIL_STACK_ERROR
-    if (NULL == HDgetcwd(cwdpath, sizeof(cwdpath)))
+    if ((did = H5Dcreate2(fid, "dset1", H5T_NATIVE_INT, sid, H5P_DEFAULT, dcpl_id, dapl_id)) < 0)
+        FAIL_STACK_ERROR
+
+    /* Close the dapl */
+    if (H5Pclose(dapl_id) < 0)
+        FAIL_STACK_ERROR
+    dapl_id = -1;
+
+    /* Get a data access property list from the dataset */
+    if ((dapl_id = H5Dget_access_plist(did)) < 0)
+        FAIL_STACK_ERROR
+
+    /* Check the value for the external prefix */
+    if ((buffer = (char *)HDcalloc((size_t)64, sizeof(char))) == NULL)
         TEST_ERROR
-    for (i = 0; i < N_EXT_FILES; i++) {
-        HDsnprintf(filename, sizeof(filename), "..%sextern_%dr.raw", H5_DIR_SEPS, (int)i + 1);
-        if (H5Pset_external(dcpl, filename, (off_t)(i * GARBAGE_PER_FILE), (hsize_t)sizeof(part)) < 0)
-            FAIL_STACK_ERROR
-    } /* end for */
-
-    cur_size = TOTAL_SIZE;
-    if ((space = H5Screate_simple(1, &cur_size, NULL)) < 0)
-        FAIL_STACK_ERROR
-    if ((dapl = H5Pcreate(H5P_DATASET_ACCESS)) < 0)
-        FAIL_STACK_ERROR
-
-    /* Set prefix to a nonexistent directory, will be overwritten by environment variable */
-    if (H5Pset_efile_prefix(dapl, "someprefix") < 0)
-        FAIL_STACK_ERROR
-    if (H5Pget_efile_prefix(dapl, buffer, sizeof(buffer)) < 0)
+    if (H5Pget_efile_prefix(dapl_id, buffer, (size_t)64) < 0)
         FAIL_STACK_ERROR
     if (HDstrcmp(buffer, "someprefix") != 0)
-        FAIL_PUTS_ERROR("efile prefix not set correctly");
+        FAIL_PUTS_ERROR("external file prefix from dapl incorrect");
 
-    /* Create dataset */
-    if ((dset = H5Dcreate2(file, "dset1", H5T_NATIVE_INT, space, H5P_DEFAULT, dcpl, dapl)) < 0)
+    /* Close everything */
+    HDfree(buffer);
+    if (H5Sclose(sid) < 0)
+        FAIL_STACK_ERROR
+    if (H5Dclose(did) < 0)
+        FAIL_STACK_ERROR
+    if (H5Pclose(dcpl_id) < 0)
+        FAIL_STACK_ERROR
+    if (H5Pclose(dapl_id) < 0)
+        FAIL_STACK_ERROR
+    if (H5Fclose(fid) < 0)
         FAIL_STACK_ERROR
 
-    /* Read the entire dataset and compare with the original */
-    HDmemset(whole, 0, sizeof(whole));
-    if (H5Dread(dset, H5T_NATIVE_INT, space, space, H5P_DEFAULT, whole) < 0)
-        FAIL_STACK_ERROR
-    for (i = 0; i < TOTAL_SIZE; i++)
-        if (whole[i] != (signed)i)
-            FAIL_PUTS_ERROR("Incorrect value(s) read.");
-
-    if (H5Dclose(dset) < 0)
-        FAIL_STACK_ERROR
-    if (H5Pclose(dapl) < 0)
-        FAIL_STACK_ERROR
-    if (H5Pclose(dcpl) < 0)
-        FAIL_STACK_ERROR
-    if (H5Sclose(space) < 0)
-        FAIL_STACK_ERROR
-    if (H5Fclose(file) < 0)
-        FAIL_STACK_ERROR
     PASSED();
     return 0;
 
 error:
+    if (buffer)
+        HDfree(buffer);
     H5E_BEGIN_TRY
     {
-        H5Pclose(dapl);
-        H5Dclose(dset);
-        H5Pclose(dcpl);
-        H5Sclose(space);
-        H5Fclose(file);
+        H5Dclose(did);
+        H5Pclose(dcpl_id);
+        H5Pclose(dapl_id);
+        H5Sclose(sid);
+        H5Fclose(fid);
     }
     H5E_END_TRY;
     return 1;
-} /* end test_path_env() */
+} /* end test_h5d_get_access_plist() */
 
 /*-------------------------------------------------------------------------
  * Function:    main
@@ -1473,7 +1409,7 @@ error:
  *
  * Return:      EXIT_SUCCESS/EXIT_FAILURE
  *
- * Programmer:	Robb Matzke
+ * Programmer:  Robb Matzke
  *              Tuesday, March  3, 1998
  *
  *-------------------------------------------------------------------------
@@ -1493,7 +1429,7 @@ main(void)
 
     /* Get a fapl for the old (default) file format */
     fapl_id_old = h5_fileaccess();
-    h5_fixname(FILENAME[0], fapl_id_old, filename, sizeof(filename));
+    h5_fixname(EXT_FNAME[0], fapl_id_old, filename, sizeof(filename));
 
     /* Copy and set up a fapl for the latest file format */
     if ((fapl_id_new = H5Pcopy(fapl_id_old)) < 0)
@@ -1501,6 +1437,10 @@ main(void)
     if (H5Pset_libver_bounds(fapl_id_new, H5F_LIBVER_LATEST, H5F_LIBVER_LATEST) < 0)
         FAIL_STACK_ERROR
 
+    /* The file format doesn't matter for this test */
+    nerrors += test_h5d_get_access_plist(fapl_id_new);
+    HDputs("");
+
     /* Test with old & new format groups */
     for (latest_format = FALSE; latest_format <= TRUE; latest_format++) {
         hid_t current_fapl_id = -1;
@@ -1509,11 +1449,11 @@ main(void)
         if (latest_format) {
             HDputs("\nTesting with the latest file format:");
             current_fapl_id = fapl_id_new;
-        } /* end if */
+        }
         else {
             HDputs("Testing with the default file format:");
             current_fapl_id = fapl_id_old;
-        } /* end else */
+        }
 
         /* Create the common file used by some of the tests */
         if ((fid = H5Fcreate(filename, H5F_ACC_TRUNC, H5P_DEFAULT, current_fapl_id)) < 0)
@@ -1543,16 +1483,15 @@ main(void)
         nerrors += test_path_absolute(current_fapl_id);
         nerrors += test_path_relative(current_fapl_id);
         nerrors += test_path_relative_cwd(current_fapl_id);
-        nerrors += test_path_env(current_fapl_id);
 
         /* Verify symbol table messages are cached */
-        nerrors += (h5_verify_cached_stabs(FILENAME, current_fapl_id) < 0 ? 1 : 0);
+        nerrors += (h5_verify_cached_stabs(EXT_FNAME, current_fapl_id) < 0 ? 1 : 0);
 
         /* Close the common file */
         if (H5Fclose(fid) < 0)
             FAIL_STACK_ERROR
 
-    } /* end for */
+    } /* end for old and new format */
 
     if (nerrors > 0)
         goto error;
@@ -1564,7 +1503,7 @@ main(void)
     HDputs("All external storage tests passed.");
 
     /* Clean up files used by file set tests */
-    if (h5_cleanup(FILENAME, fapl_id_old)) {
+    if (h5_cleanup(EXT_FNAME, fapl_id_old)) {
         HDremove("extern_1r.raw");
         HDremove("extern_2r.raw");
         HDremove("extern_3r.raw");
@@ -1576,7 +1515,7 @@ main(void)
         HDremove("extern_4w.raw");
 
         HDrmdir("extern_dir");
-    } /* end if */
+    }
 
     return EXIT_SUCCESS;
 
