@@ -17,7 +17,7 @@
  *
  * Test the element coordinates for dataspace selection.  For
  * chunked dataset, when the hyperslab selection of some
- * dimensions is full, the library optimize it by "flattenning"
+ * dimensions is full, the library optimize it by "flattening"
  * the fully selected dimensions.  This program tests if the
  * coordinates of selected elements are correctly calculated.
  *
@@ -87,10 +87,10 @@ test_singleEnd_selElements(hid_t file, hbool_t is_chunked)
     }
 
     /* Construct dataset's name */
-    memset(dset_name, 0, (size_t)NAME_LEN);
-    strcat(dset_name, SINGLE_END_DSET);
+    HDmemset(dset_name, 0, (size_t)NAME_LEN);
+    HDstrcat(dset_name, SINGLE_END_DSET);
     if (is_chunked)
-        strcat(dset_name, "_chunked");
+        HDstrcat(dset_name, "_chunked");
 
     did = H5Dcreate2(file, dset_name, H5T_NATIVE_INT, sid, H5P_DEFAULT, plid, H5P_DEFAULT);
     CHECK(did, FAIL, "H5Dcreate2");
@@ -259,10 +259,10 @@ test_singleEnd_selHyperslab(hid_t file, hbool_t is_chunked)
     hsize_t mem3_block[4]  = {1, 3, 6, 1};
 
     /* Construct dataset's name */
-    memset(dset_name, 0, NAME_LEN);
-    strcat(dset_name, SINGLE_END_DSET);
+    HDmemset(dset_name, 0, NAME_LEN);
+    HDstrcat(dset_name, SINGLE_END_DSET);
     if (is_chunked)
-        strcat(dset_name, "_chunked");
+        HDstrcat(dset_name, "_chunked");
 
     /* Dataspace for the dataset in file */
     sid = H5Screate_simple(4, da_dims, da_dims);
@@ -436,10 +436,10 @@ test_multiple_ends(hid_t file, hbool_t is_chunked)
     }
 
     /* Construct dataset's name */
-    memset(dset_name, 0, NAME_LEN);
-    strcat(dset_name, MULTI_ENDS_SEL_HYPER_DSET);
+    HDmemset(dset_name, 0, NAME_LEN);
+    HDstrcat(dset_name, MULTI_ENDS_SEL_HYPER_DSET);
     if (is_chunked)
-        strcat(dset_name, "_chunked");
+        HDstrcat(dset_name, "_chunked");
 
     did = H5Dcreate2(file, dset_name, H5T_NATIVE_INT, sid, H5P_DEFAULT, plid, H5P_DEFAULT);
     CHECK(did, FAIL, "H5Dcreate2");
@@ -648,22 +648,22 @@ void
 test_coords(void)
 {
     hid_t   fid;
+    hbool_t is_chunk[2] = {TRUE, FALSE};
     int     i;
-    hbool_t is_chunk;
     herr_t  ret; /* Generic error return */
 
     fid = H5Fcreate(FILENAME, H5F_ACC_TRUNC, H5P_DEFAULT, H5P_DEFAULT);
     CHECK(fid, FAIL, "H5Fcreate");
 
-    for (i = 0, is_chunk = FALSE; i < 2; i++, is_chunk++) {
+    for (i = 0; i < 2; i++) {
         /* Test H5Sselect_elements with selection of one block of data */
-        test_singleEnd_selElements(fid, is_chunk);
+        test_singleEnd_selElements(fid, is_chunk[i]);
 
         /* Test H5Sselect_hyperslab with selection of one block of data */
-        test_singleEnd_selHyperslab(fid, is_chunk);
+        test_singleEnd_selHyperslab(fid, is_chunk[i]);
 
         /* Test H5Sselect_hyperslab with selection of multiple blocks of data */
-        test_multiple_ends(fid, is_chunk);
+        test_multiple_ends(fid, is_chunk[i]);
     }
 
     ret = H5Fclose(fid);
@@ -687,5 +687,5 @@ test_coords(void)
 void
 cleanup_coords(void)
 {
-    remove(FILENAME);
+    HDremove(FILENAME);
 }
