@@ -24,9 +24,8 @@
 /*
  * Definitions for the testing structure.
  */
-#define MAXNUMOFTESTS 60
-#define MAXTESTNAME   16
-#define MAXTESTDESC   64
+#define MAXTESTNAME 16
+#define MAXTESTDESC 64
 
 typedef struct TestStruct {
     int  NumErrors;
@@ -73,10 +72,6 @@ AddTest(const char *TheName, void (*TheCall)(void), void (*Cleanup)(void), const
         const void *Parameters)
 {
     /* Sanity checking */
-    if (Index >= MAXNUMOFTESTS) {
-        HDprintf("Too many tests added, increase MAXNUMOFTESTS(%d).\n", MAXNUMOFTESTS);
-        HDexit(EXIT_FAILURE);
-    } /* end if */
     if (HDstrlen(TheDescr) >= MAXTESTDESC) {
         HDprintf("Test description ('%s') too long, increase MAXTESTDESC(%d).\n", TheDescr, MAXTESTDESC);
         HDexit(EXIT_FAILURE);
@@ -227,7 +222,8 @@ TestInfo(const char *ProgName)
 void
 TestParseCmdLine(int argc, char *argv[])
 {
-    int ret_code;
+    hbool_t skipped_all = FALSE;
+    int     ret_code;
 
     while (argv++, --argc > 0) {
         if ((HDstrcmp(*argv, "-verbose") == 0) || (HDstrcmp(*argv, "-v") == 0)) {
@@ -271,8 +267,11 @@ TestParseCmdLine(int argc, char *argv[])
                 ++argv;
 
                 /* Skip all tests, then activate only one. */
-                for (Loop = 0; Loop < Index; Loop++)
-                    Test[Loop].SkipFlag = 1;
+                if (!skipped_all) {
+                    for (Loop = 0; Loop < Index; Loop++)
+                        Test[Loop].SkipFlag = 1;
+                    skipped_all = TRUE;
+                } /* end if */
                 SetTest(*argv, ONLYTEST);
             }
             else {
@@ -321,9 +320,9 @@ PerformTests(void)
             MESSAGE(5, ("===============================================\n"));
             Test[Loop].NumErrors = num_errs;
             Test_parameters      = Test[Loop].Parameters;
-            ALARM_ON;
+            TestAlarmOn();
             Test[Loop].Call();
-            ALARM_OFF;
+            TestAlarmOff();
             Test[Loop].NumErrors = num_errs - Test[Loop].NumErrors;
             MESSAGE(5, ("===============================================\n"));
             MESSAGE(5, ("There were %d errors detected.\n\n", (int)Test[Loop].NumErrors));
@@ -389,7 +388,7 @@ TestShutdown(void)
 /*
  * Retrieve the verbosity level for the testing framework
  */
-int
+H5_ATTR_PURE int
 GetTestVerbosity(void)
 {
     return (TestVerbosity);
@@ -414,20 +413,16 @@ SetTestVerbosity(int newval)
  Values:
  0: Exhaustive run
     Tests should take as long as necessary
- 1: Full run.  Default if H5_TEST_EXPRESS_LEVEL_DEFAULT
-    and HDF5TestExpress are not defined
+ 1: Full run.  Default if HDF5TestExpress is not defined
     Tests should take no more than 30 minutes
  2: Quick run
     Tests should take no more than 10 minutes
- 3: Smoke test.
-    Default if HDF5TestExpress is set to a value other than 0-3
+ 3: Smoke test.  Default if HDF5TestExpress is set to a value other than 0-3
     Tests should take less than 1 minute
 
  Design:
  If the environment variable $HDF5TestExpress is defined,
- or if a default testing level > 1 has been set via
- H5_TEST_EXPRESS_LEVEL_DEFAULT, then test programs should
- skip some tests so that they
+ then test programs should skip some tests so that they
  complete sooner.
 
  Terms:
@@ -447,27 +442,18 @@ GetTestExpress(void)
 
     /* set it here for now.  Should be done in something like h5test_init(). */
     if (TestExpress == -1) {
-        int express_val = 1;
-
-        /* Check if a default test express level is defined (e.g., by build system) */
-#ifdef H5_TEST_EXPRESS_LEVEL_DEFAULT
-        express_val = H5_TEST_EXPRESS_LEVEL_DEFAULT;
-#endif
-
-        /* Check if HDF5TestExpress is set to override the default level */
         env_val = HDgetenv("HDF5TestExpress");
-        if (env_val) {
-            if (HDstrcmp(env_val, "0") == 0)
-                express_val = 0;
-            else if (HDstrcmp(env_val, "1") == 0)
-                express_val = 1;
-            else if (HDstrcmp(env_val, "2") == 0)
-                express_val = 2;
-            else
-                express_val = 3;
-        }
 
-        SetTestExpress(express_val);
+        if (env_val == NULL)
+            SetTestExpress(1);
+        else if (HDstrcmp(env_val, "0") == 0)
+            SetTestExpress(0);
+        else if (HDstrcmp(env_val, "1") == 0)
+            SetTestExpress(1);
+        else if (HDstrcmp(env_val, "2") == 0)
+            SetTestExpress(2);
+        else
+            SetTestExpress(3);
     }
 
     return (TestExpress);
@@ -492,7 +478,7 @@ SetTestExpress(int newval)
  * Retrieve Summary request value.
  *     0 means no summary, 1 means yes.
  */
-int
+H5_ATTR_PURE int
 GetTestSummary(void)
 {
     return (Summary);
@@ -502,7 +488,7 @@ GetTestSummary(void)
  * Retrieve Cleanup request value.
  *     0 means no Cleanup, 1 means yes.
  */
-int
+H5_ATTR_PURE int
 GetTestCleanup(void)
 {
     return (CleanUp);
@@ -535,13 +521,13 @@ ParseTestVerbosity(char *argv)
     else if (*argv == 'h')
         SetTestVerbosity(VERBO_HI);
     else
-        SetTestVerbosity(atoi(argv));
+        SetTestVerbosity(HDatoi(argv));
 }
 
 /*
  * Retrieve the number of testing errors for the testing framework
  */
-int
+H5_ATTR_PURE int
 GetTestNumErrs(void)
 {
     return (num_errs);
@@ -559,7 +545,7 @@ IncTestNumErrs(void)
 /*
  * Retrieve the current Test Parameters pointer.
  */
-const void *
+H5_ATTR_PURE const void *
 GetTestParameters(void)
 {
     return (Test_parameters);
@@ -620,17 +606,12 @@ SetTest(const char *testname, int action)
             break;
         case ONLYTEST:
             for (Loop = 0; Loop < Index; Loop++) {
-                if (HDstrcmp(testname, Test[Loop].Name) != 0)
-                    Test[Loop].SkipFlag = 1;
-                else {
+                if (HDstrcmp(testname, Test[Loop].Name) == 0) {
                     /* Found it. Set it to run. Break to skip the rest. */
                     Test[Loop].SkipFlag = 0;
                     break;
                 }
             }
-            /* skip the rest */
-            while (++Loop < Index)
-                Test[Loop].SkipFlag = 1;
             break;
         default:
             /* error */
@@ -639,13 +620,16 @@ SetTest(const char *testname, int action)
     }
 }
 
-/*
- * Enable alarm on test execution, configurable by environment variable
+/* Enable a test timer that will kill long-running tests, the time is configurable
+ * via an environment variable.
+ *
+ * Only useful on POSIX systems where alarm(2) is present.
  */
 void
 TestAlarmOn(void)
 {
-    char         *env_val   = HDgetenv("HDF5_ALARM_SECONDS"); /* Alarm environment */
+#ifdef H5_HAVE_ALARM
+    char *        env_val   = HDgetenv("HDF5_ALARM_SECONDS"); /* Alarm environment */
     unsigned long alarm_sec = H5_ALARM_SEC;                   /* Number of seconds before alarm goes off */
 
     /* Get the alarm value from the environment variable, if set */
@@ -654,4 +638,15 @@ TestAlarmOn(void)
 
     /* Set the number of seconds before alarm goes off */
     HDalarm((unsigned)alarm_sec);
+#endif
+}
+
+/* Disable the test timer */
+void
+TestAlarmOff(void)
+{
+#ifdef H5_HAVE_ALARM
+    /* Set the number of seconds to zero */
+    HDalarm(0);
+#endif
 }
