@@ -6,7 +6,7 @@
  * This file is part of HDF5.  The full HDF5 copyright notice, including     *
  * terms governing use, modification, and redistribution, is contained in    *
  * the COPYING file, which can be found at the root of the source code       *
- * distribution tree, or in https://support.hdfgroup.org/ftp/HDF5/releases.  *
+ * distribution tree, or in https://www.hdfgroup.org/licenses.               *
  * If you do not have access to either file, you may request a copy from     *
  * help@hdfgroup.org.                                                        *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
@@ -22,10 +22,10 @@
  *-------------------------------------------------------------------------
  */
 
-static int check_options(pack_opt_t *options);
-static int check_objects(const char* fname, pack_opt_t *options);
-static const char* get_sfilter(H5Z_filter_t filtn);
-static int have_request(pack_opt_t *options);
+static int         check_options(pack_opt_t *options);
+static int         check_objects(const char *fname, pack_opt_t *options);
+static const char *get_sfilter(H5Z_filter_t filtn);
+static int         have_request(pack_opt_t *options);
 
 /*-------------------------------------------------------------------------
  * Function: h5repack
@@ -42,7 +42,7 @@ static int have_request(pack_opt_t *options);
  *-------------------------------------------------------------------------
  */
 int
-h5repack(const char* infile, const char* outfile, pack_opt_t *options)
+h5repack(const char *infile, const char *outfile, pack_opt_t *options)
 {
     /* check input */
     if (check_options(options) < 0)
@@ -73,15 +73,17 @@ h5repack_init(pack_opt_t *options, int verbose, hbool_t latest)
     int k, n;
 
     HDmemset(options, 0, sizeof(pack_opt_t));
-    options->min_comp = 0;
-    options->verbose = verbose;
-    options->latest = latest;
-    options->layout_g = H5D_LAYOUT_ERROR;
-    options->low_bound = H5F_LIBVER_EARLIEST;
+    options->min_comp   = 0;
+    options->verbose    = verbose;
+    options->latest     = latest;
+    options->layout_g   = H5D_LAYOUT_ERROR;
+    options->low_bound  = H5F_LIBVER_EARLIEST;
     options->high_bound = H5F_LIBVER_LATEST;
+    options->fin_fapl   = H5P_DEFAULT;
+    options->fout_fapl  = H5P_DEFAULT;
 
     for (n = 0; n < H5_REPACK_MAX_NFILTERS; n++) {
-        options->filter_g[n].filtn = -1;
+        options->filter_g[n].filtn     = -1;
         options->filter_g[n].cd_nelmts = 0;
         for (k = 0; k < CD_VALUES; k++)
             options->filter_g[n].cd_values[k] = 0;
@@ -115,7 +117,7 @@ h5repack_end(pack_opt_t *options)
 int
 h5repack_addfilter(const char *str, pack_opt_t *options)
 {
-    obj_list_t   *obj_list = NULL; /* one object list for the -f and -l option entry */
+    obj_list_t *  obj_list = NULL; /* one object list for the -f and -l option entry */
     filter_info_t filter;          /* filter info for the current -f option entry */
     unsigned      n_objs;          /* number of objects in the current -f or -l option entry */
     int           is_glb;          /* is the filter global */
@@ -164,7 +166,7 @@ h5repack_addlayout(const char *str, pack_opt_t *options)
     init_packobject(&pack);
 
     if (options->all_layout == 1) {
-        error_msg( "invalid layout input: 'all' option is present with other objects <%s>\n", str);
+        error_msg("invalid layout input: 'all' option is present with other objects <%s>\n", str);
         return ret_value;
     }
 
@@ -219,28 +221,28 @@ h5repack_addlayout(const char *str, pack_opt_t *options)
  *          to free the stack.
  *-------------------------------------------------------------------------
  */
+
 hid_t
-copy_named_datatype(hid_t type_in, hid_t fidout, named_dt_t **named_dt_head_p, trav_table_t *travt, pack_opt_t *options)
+copy_named_datatype(hid_t type_in, hid_t fidout, named_dt_t **named_dt_head_p, trav_table_t *travt,
+                    pack_opt_t *options)
 {
-    named_dt_t  *dt = *named_dt_head_p; /* Stack pointer */
-    named_dt_t  *dt_ret = NULL;         /* Datatype to return */
-    H5O_info2_t  oinfo;                 /* Object info of input dtype */
-    int          token_cmp;
-    hid_t        ret_value = H5I_INVALID_HID;
+    named_dt_t *dt     = NULL; /* Stack pointer */
+    named_dt_t *dt_ret = NULL; /* Datatype to return */
+    H5O_info2_t oinfo;         /* Object info of input dtype */
+    int         token_cmp;
+    hid_t       ret_value = H5I_INVALID_HID;
 
     if (H5Oget_info3(type_in, &oinfo, H5O_INFO_BASIC) < 0)
         H5TOOLS_GOTO_ERROR(H5I_INVALID_HID, "H5Oget_info failed");
 
     if (*named_dt_head_p) {
-        if (H5Otoken_cmp(type_in, &dt->obj_token, &oinfo.token, &token_cmp) < 0)
-            H5TOOLS_GOTO_ERROR(H5I_INVALID_HID, "failed to compare object tokens");
-
-        /* Stack already exists, search for the datatype */
-        while (dt && token_cmp) {
-            dt = dt->next;
-
+        /* Search the stack for the datatype. */
+        for (dt = *named_dt_head_p; dt != NULL; dt = dt->next) {
             if (H5Otoken_cmp(type_in, &dt->obj_token, &oinfo.token, &token_cmp) < 0)
                 H5TOOLS_GOTO_ERROR(H5I_INVALID_HID, "failed to compare object tokens");
+
+            if (token_cmp == 0)
+                break; // found it!
         }
 
         dt_ret = dt;
@@ -254,10 +256,10 @@ copy_named_datatype(hid_t type_in, hid_t fidout, named_dt_t **named_dt_head_p, t
                 /* Push onto the stack */
                 if (NULL == (dt = (named_dt_t *)HDmalloc(sizeof(named_dt_t))))
                     H5TOOLS_GOTO_ERROR(H5I_INVALID_HID, "buffer allocation failed failed");
-                dt->next = *named_dt_head_p;
+                dt->next         = *named_dt_head_p;
                 *named_dt_head_p = dt;
 
-                /* Update the address and id */
+                /* Update the token/address and id */
                 HDmemcpy(&dt->obj_token, &travt->objs[i].obj_token, sizeof(H5O_token_t));
                 dt->id_out = H5I_INVALID_HID;
 
@@ -267,8 +269,8 @@ copy_named_datatype(hid_t type_in, hid_t fidout, named_dt_t **named_dt_head_p, t
                 if (!token_cmp)
                     dt_ret = dt;
             } /* end if named datatype */
-        } /* end for each object in traversal table */
-    } /* end else (create the stack) */
+        }     /* end for each object in traversal table */
+    }         /* end else (create the stack) */
 
     /* Handle the case that the requested datatype was not found.  This is
      * possible if the datatype was committed anonymously in the input file.
@@ -277,10 +279,10 @@ copy_named_datatype(hid_t type_in, hid_t fidout, named_dt_t **named_dt_head_p, t
         /* Push the new datatype onto the stack */
         if (NULL == (dt_ret = (named_dt_t *)HDmalloc(sizeof(named_dt_t))))
             H5TOOLS_GOTO_ERROR(H5I_INVALID_HID, "buffer allocation failed failed");
-        dt_ret->next = *named_dt_head_p;
+        dt_ret->next     = *named_dt_head_p;
         *named_dt_head_p = dt_ret;
 
-        /* Update the address and id */
+        /* Update the token/address and id */
         HDmemcpy(&dt_ret->obj_token, &oinfo.token, sizeof(H5O_token_t));
         dt_ret->id_out = H5I_INVALID_HID;
     } /* end if requested datatype not found */
@@ -321,8 +323,8 @@ done:
 int
 named_datatype_free(named_dt_t **named_dt_head_p, int ignore_err)
 {
-    named_dt_t *dt = *named_dt_head_p;
-    int ret_value = -1;
+    named_dt_t *dt        = *named_dt_head_p;
+    int         ret_value = -1;
 
     while (dt) {
         /* Pop the datatype off the stack and free it */
@@ -353,24 +355,28 @@ done:
 int
 copy_attr(hid_t loc_in, hid_t loc_out, named_dt_t **named_dt_head_p, trav_table_t *travt, pack_opt_t *options)
 {
-    hid_t       attr_id = H5I_INVALID_HID;  /* attr ID */
-    hid_t       attr_out = H5I_INVALID_HID; /* attr ID */
-    hid_t       space_id = H5I_INVALID_HID; /* space ID */
-    hid_t       ftype_id = H5I_INVALID_HID; /* file type ID */
-    hid_t       wtype_id = H5I_INVALID_HID; /* read/write type ID */
-    size_t      msize;         /* size of type */
-    void       *buf = NULL;    /* data buffer */
-    hsize_t     nelmts;        /* number of elements in dataset */
-    int         rank;          /* rank of dataset */
-    htri_t      is_named;      /* Whether the datatype is named */
-    hsize_t     dims[H5S_MAX_RANK];/* dimensions of dataset */
-    char        name[255];
-    H5O_info2_t oinfo;         /* object info */
-    int         j;
-    unsigned    u;
-    hbool_t     is_ref = 0;
-    H5T_class_t type_class = -1;
-    int         ret_value = 0;
+    hid_t         attr_id  = H5I_INVALID_HID; /* attr ID */
+    hid_t         attr_out = H5I_INVALID_HID; /* attr ID */
+    hid_t         space_id = H5I_INVALID_HID; /* space ID */
+    hid_t         ftype_id = H5I_INVALID_HID; /* file type ID */
+    hid_t         wtype_id = H5I_INVALID_HID; /* read/write type ID */
+    size_t        msize;                      /* size of type */
+    void *        buf = NULL;                 /* data buffer */
+    hsize_t       nelmts;                     /* number of elements in dataset */
+    int           rank;                       /* rank of dataset */
+    htri_t        is_named;                   /* Whether the datatype is named */
+    hsize_t       dims[H5S_MAX_RANK];         /* dimensions of dataset */
+    H5_timer_t    timer;                      /* Timer for read/write operations */
+    H5_timevals_t times;                      /* Elapsed time for each operation */
+    static double read_time  = 0;
+    static double write_time = 0;
+    char          name[255];
+    H5O_info2_t   oinfo; /* object info */
+    int           j;
+    unsigned      u;
+    hbool_t       is_ref     = 0;
+    H5T_class_t   type_class = -1;
+    int           ret_value  = 0;
 
     if (H5Oget_info3(loc_in, &oinfo, H5O_INFO_NUM_ATTRS) < 0)
         H5TOOLS_GOTO_ERROR((-1), "H5Oget_info failed");
@@ -379,12 +385,13 @@ copy_attr(hid_t loc_in, hid_t loc_out, named_dt_t **named_dt_head_p, trav_table_
      * copy all attributes
      *-------------------------------------------------------------------------
      */
-    for (u = 0; u < (unsigned) oinfo.num_attrs; u++) {
+    for (u = 0; u < (unsigned)oinfo.num_attrs; u++) {
         /* open attribute */
-        if ((attr_id = H5Aopen_by_idx(loc_in, ".", H5_INDEX_CRT_ORDER, H5_ITER_INC, (hsize_t) u, H5P_DEFAULT, H5P_DEFAULT)) < 0)
+        if ((attr_id = H5Aopen_by_idx(loc_in, ".", H5_INDEX_CRT_ORDER, H5_ITER_INC, (hsize_t)u, H5P_DEFAULT,
+                                      H5P_DEFAULT)) < 0)
             H5TOOLS_GOTO_ERROR((-1), "H5Aopen_by_idx failed");
 
-        if (H5Aget_name(attr_id, (size_t) 255, name) < 0)
+        if (H5Aget_name(attr_id, (size_t)255, name) < 0)
             H5TOOLS_GOTO_ERROR((-1), "H5Pclose failed");
 
         /* get the file datatype  */
@@ -440,12 +447,12 @@ copy_attr(hid_t loc_in, hid_t loc_out, named_dt_t **named_dt_head_p, trav_table_
          *---------------------------------------------------------------------
          */
         type_class = H5Tget_class(wtype_id);
-        is_ref = (type_class == H5T_REFERENCE);
+        is_ref     = (type_class == H5T_REFERENCE);
         if (type_class == H5T_VLEN || type_class == H5T_ARRAY) {
             hid_t base_type = H5I_INVALID_HID;
 
             base_type = H5Tget_super(ftype_id);
-            is_ref = (is_ref || (H5Tget_class(base_type) == H5T_REFERENCE));
+            is_ref    = (is_ref || (H5Tget_class(base_type) == H5T_REFERENCE));
             if (H5Tclose(base_type) < 0)
                 H5TOOLS_ERROR((-1), "H5Tclose base_type failed");
         } /* end if type_class is variable length or array */
@@ -454,7 +461,7 @@ copy_attr(hid_t loc_in, hid_t loc_out, named_dt_t **named_dt_head_p, trav_table_
             int nmembers = H5Tget_nmembers(wtype_id);
 
             for (j = 0; j < nmembers; j++) {
-                hid_t mtid = H5Tget_member_type(wtype_id, (unsigned)j);
+                hid_t       mtid    = H5Tget_member_type(wtype_id, (unsigned)j);
                 H5T_class_t mtclass = H5Tget_class(mtid);
                 if (H5Tclose(mtid) < 0)
                     H5TOOLS_ERROR((-1), "H5Tclose mtid failed");
@@ -464,7 +471,10 @@ copy_attr(hid_t loc_in, hid_t loc_out, named_dt_t **named_dt_head_p, trav_table_
                     break;
                 }
             } /* end for each member */
-        } /* end if type_class is H5T_COMPOUND */
+        }     /* end if type_class is H5T_COMPOUND */
+
+        read_time  = 0;
+        write_time = 0;
 
         if (!is_ref) {
             /*-----------------------------------------------------------------
@@ -476,8 +486,17 @@ copy_attr(hid_t loc_in, hid_t loc_out, named_dt_t **named_dt_head_p, trav_table_
             if (buf == NULL) {
                 H5TOOLS_GOTO_ERROR((-1), "HDmalloc failed");
             } /* end if */
+            if (options->verbose == 2) {
+                H5_timer_init(&timer);
+                H5_timer_start(&timer);
+            }
             if (H5Aread(attr_id, wtype_id, buf) < 0)
                 H5TOOLS_GOTO_ERROR((-1), "H5Aread failed");
+            if (options->verbose == 2) {
+                H5_timer_stop(&timer);
+                H5_timer_get_times(timer, &times);
+                read_time += times.elapsed;
+            }
 
             /*-----------------------------------------------------------------
              * copy
@@ -486,8 +505,18 @@ copy_attr(hid_t loc_in, hid_t loc_out, named_dt_t **named_dt_head_p, trav_table_
 
             if ((attr_out = H5Acreate2(loc_out, name, wtype_id, space_id, H5P_DEFAULT, H5P_DEFAULT)) < 0)
                 H5TOOLS_GOTO_ERROR((-1), "H5Acreate2 failed on ,%s>", name);
+
+            if (options->verbose == 2) {
+                H5_timer_init(&timer);
+                H5_timer_start(&timer);
+            }
             if (H5Awrite(attr_out, wtype_id, buf) < 0)
                 H5TOOLS_GOTO_ERROR((-1), "H5Awrite failed");
+            if (options->verbose == 2) {
+                H5_timer_stop(&timer);
+                H5_timer_get_times(timer, &times);
+                write_time += times.elapsed;
+            }
 
             /*close*/
             if (H5Aclose(attr_out) < 0)
@@ -497,11 +526,14 @@ copy_attr(hid_t loc_in, hid_t loc_out, named_dt_t **named_dt_head_p, trav_table_
              * be reclaimed */
             if (TRUE == h5tools_detect_vlen(wtype_id))
                 H5Treclaim(wtype_id, space_id, H5P_DEFAULT, buf);
+
             HDfree(buf);
             buf = NULL;
         } /*H5T_REFERENCE*/
 
-        if (options->verbose)
+        if (options->verbose == 2)
+            HDprintf(FORMAT_OBJ_ATTR_TIME, "attr", read_time, write_time, name);
+        else
             HDprintf(FORMAT_OBJ_ATTR, "attr", name);
 
         /*---------------------------------------------------------------------
@@ -523,7 +555,8 @@ copy_attr(hid_t loc_in, hid_t loc_out, named_dt_t **named_dt_head_p, trav_table_
     } /* for u (each attribute) */
 
 done:
-    H5E_BEGIN_TRY {
+    H5E_BEGIN_TRY
+    {
         if (buf) {
             /* Check if we have VL data and string in the attribute's
              * datatype that must be reclaimed
@@ -540,7 +573,8 @@ done:
         H5Tclose(wtype_id);
         H5Tclose(ftype_id);
         H5Aclose(attr_id);
-    } H5E_END_TRY;
+    }
+    H5E_END_TRY;
 
     return ret_value;
 } /* end copy_attr() */
@@ -565,35 +599,35 @@ check_options(pack_opt_t *options)
      * Objects to layout
      *-------------------------------------------------------------------------
      */
-    if (options->verbose && have_request(options)) {
+    if (options->verbose > 0 && have_request(options)) {
         if (options->all_layout == 1) {
             HDprintf("All objects to modify layout are...\n");
             switch (options->layout_g) {
-            case H5D_COMPACT:
-                strcpy(slayout, "compact");
-                break;
-            case H5D_CONTIGUOUS:
-                strcpy(slayout, "contiguous");
-                break;
-            case H5D_CHUNKED:
-                strcpy(slayout, "chunked");
-                break;
-            case H5D_VIRTUAL:
-                strcpy(slayout, "virtual");
-                break;
-            case H5D_LAYOUT_ERROR:
-            case H5D_NLAYOUTS:
-                H5TOOLS_GOTO_ERROR((-1), "invalid layout");
-                break;
-            default:
-                strcpy(slayout, "invalid layout\n");
-                H5TOOLS_GOTO_DONE((-1));
+                case H5D_COMPACT:
+                    strcpy(slayout, "compact");
+                    break;
+                case H5D_CONTIGUOUS:
+                    strcpy(slayout, "contiguous");
+                    break;
+                case H5D_CHUNKED:
+                    strcpy(slayout, "chunked");
+                    break;
+                case H5D_VIRTUAL:
+                    strcpy(slayout, "virtual");
+                    break;
+                case H5D_LAYOUT_ERROR:
+                case H5D_NLAYOUTS:
+                    H5TOOLS_GOTO_ERROR((-1), "invalid layout");
+                    break;
+                default:
+                    strcpy(slayout, "invalid layout\n");
+                    H5TOOLS_GOTO_DONE((-1));
             }
             HDprintf(" Apply %s layout to all", slayout);
             if (H5D_CHUNKED == options->layout_g) {
                 HDprintf("with dimension [ ");
                 for (j = 0; j < options->chunk_g.rank; j++)
-                    HDprintf("%d ", (int) options->chunk_g.chunk_lengths[j]);
+                    HDprintf("%d ", (int)options->chunk_g.chunk_lengths[j]);
                 HDprintf("]");
             }
             HDprintf("\n");
@@ -603,19 +637,19 @@ check_options(pack_opt_t *options)
     } /* end if verbose */
 
     for (i = 0; i < options->op_tbl->nelems; i++) {
-        char* name = options->op_tbl->objs[i].path;
+        char *name = options->op_tbl->objs[i].path;
 
         if (options->op_tbl->objs[i].chunk.rank > 0) {
-            if (options->verbose) {
+            if (options->verbose > 0) {
                 HDprintf(" <%s> with chunk size ", name);
                 for (k = 0; k < options->op_tbl->objs[i].chunk.rank; k++)
-                    HDprintf("%d ", (int) options->op_tbl->objs[i].chunk.chunk_lengths[k]);
+                    HDprintf("%d ", (int)options->op_tbl->objs[i].chunk.chunk_lengths[k]);
                 HDprintf("\n");
             }
             has_ck = 1;
         }
         else if (options->op_tbl->objs[i].chunk.rank == -2) { /* TODO: replace 'magic number' */
-            if (options->verbose)
+            if (options->verbose > 0)
                 HDprintf(" <%s> %s\n", name, "NONE (contiguous)");
             has_ck = 1;
         }
@@ -629,7 +663,7 @@ check_options(pack_opt_t *options)
      *-------------------------------------------------------------------------
      */
 
-    if (options->verbose && have_request(options)) {
+    if (options->verbose > 0 && have_request(options)) {
         if (options->all_filter == 1) {
             HDprintf("All objects to apply filter are...\n");
             for (k = 0; k < options->n_filter_g; k++) {
@@ -639,36 +673,38 @@ check_options(pack_opt_t *options)
                     continue;
                 }
                 switch (filtn) {
-                case H5Z_FILTER_NONE:
-                    HDprintf(" Uncompress all\n");
-                    break;
-                case H5Z_FILTER_SHUFFLE:
-                case H5Z_FILTER_FLETCHER32:
-                    HDprintf(" All with %s\n", get_sfilter(filtn));
-                    break;
-                case H5Z_FILTER_SZIP:
-                case H5Z_FILTER_DEFLATE:
-                    HDprintf(" All with %s, parameter %d\n", get_sfilter(filtn), options->filter_g[k].cd_values[0]);
-                    break;
-                default:
-                    HDprintf(" User Defined %d\n", filtn);
-                    break;
+                    case H5Z_FILTER_NONE:
+                        HDprintf(" Uncompress all\n");
+                        break;
+                    case H5Z_FILTER_SHUFFLE:
+                    case H5Z_FILTER_FLETCHER32:
+                        HDprintf(" All with %s\n", get_sfilter(filtn));
+                        break;
+                    case H5Z_FILTER_SZIP:
+                    case H5Z_FILTER_DEFLATE:
+                        HDprintf(" All with %s, parameter %d\n", get_sfilter(filtn),
+                                 options->filter_g[k].cd_values[0]);
+                        break;
+                    default:
+                        HDprintf(" User Defined %d\n", filtn);
+                        break;
                 } /* end switch */
-            } /* end for each filter */
-        } /* end if options->all_filter == 1 (TODO: meaning) */
+            }     /* end for each filter */
+        }         /* end if options->all_filter == 1 (TODO: meaning) */
         else
             HDprintf("No all objects to apply filter\n");
     } /* end if verbose */
 
     for (i = 0; i < options->op_tbl->nelems; i++) {
         pack_info_t pack = options->op_tbl->objs[i];
-        char* name = pack.path;
+        char *      name = pack.path;
 
         for (j = 0; j < pack.nfilters; j++) {
-            if (options->verbose) {
+            if (options->verbose > 0) {
                 if (pack.filter[j].filtn >= 0) {
                     if (pack.filter[j].filtn > H5Z_FILTER_SCALEOFFSET) {
-                        HDprintf(" <%s> with %s filter %d\n", name, get_sfilter(pack.filter[j].filtn), pack.filter[j].filtn);
+                        HDprintf(" <%s> with %s filter %d\n", name, get_sfilter(pack.filter[j].filtn),
+                                 pack.filter[j].filtn);
                     }
                     else {
                         HDprintf(" <%s> with %s filter\n", name, get_sfilter(pack.filter[j].filtn));
@@ -677,7 +713,7 @@ check_options(pack_opt_t *options)
             }
             has_cp = 1;
         } /* end for each filter */
-    } /* end for each object in options table */
+    }     /* end for each object in options table */
 
     if (options->all_filter == 1 && has_cp)
         H5TOOLS_GOTO_ERROR((-1), "invalid compression input: 'all' option is present with other objects");
@@ -702,14 +738,15 @@ check_options(pack_opt_t *options)
      *------------------------------------------------------------------------
      */
     if (options->ublock_filename != NULL && options->ublock_size == 0) {
-        if (options->verbose) {
-            HDprintf("Warning: user block size missing for file %s. Assigning a default size of 1024...\n", options->ublock_filename);
+        if (options->verbose > 0) {
+            HDprintf("Warning: user block size missing for file %s. Assigning a default size of 1024...\n",
+                     options->ublock_filename);
             options->ublock_size = 1024;
         }
     }
 
     if (options->ublock_filename == NULL && options->ublock_size != 0)
-        H5TOOLS_GOTO_ERROR((-1), "file name missing for user block", options->ublock_filename);
+        H5TOOLS_GOTO_ERROR((-1), "file name missing for user block");
 
     /*------------------------------------------------------------------------
      * Verify alignment options; threshold is zero default but alignment not
@@ -733,14 +770,14 @@ done:
  *-------------------------------------------------------------------------
  */
 static int
-check_objects(const char* fname, pack_opt_t *options)
+check_objects(const char *fname, pack_opt_t *options)
 {
     hid_t         fid = H5I_INVALID_HID;
     hid_t         did = H5I_INVALID_HID;
     hid_t         sid = H5I_INVALID_HID;
     unsigned int  i;
     int           ifil;
-    trav_table_t *travt = NULL;
+    trav_table_t *travt     = NULL;
     int           ret_value = 0;
 
     /* nothing to do */
@@ -751,7 +788,8 @@ check_objects(const char* fname, pack_opt_t *options)
      * open the file
      *-------------------------------------------------------------------------
      */
-    if ((fid = h5tools_fopen(fname, H5F_ACC_RDONLY, H5P_DEFAULT, NULL, NULL, 0)) < 0)
+    if ((fid = h5tools_fopen(fname, H5F_ACC_RDONLY, options->fin_fapl,
+                             (options->fin_fapl == H5P_DEFAULT) ? FALSE : TRUE, NULL, 0)) < 0)
         H5TOOLS_GOTO_ERROR((-1), "h5tools_fopen failed <%s>: %s", fname, H5FOPENERROR);
 
     /*-------------------------------------------------------------------------
@@ -773,21 +811,21 @@ check_objects(const char* fname, pack_opt_t *options)
      *-------------------------------------------------------------------------
      */
 
-    if (options->verbose)
+    if (options->verbose > 0)
         HDprintf("Opening file. Searching %zu objects to modify ...\n", travt->nobjs);
 
     for (i = 0; i < options->op_tbl->nelems; i++) {
-        pack_info_t obj = options->op_tbl->objs[i];
-        char* name = obj.path;
+        pack_info_t obj  = options->op_tbl->objs[i];
+        char *      name = obj.path;
 
-        if (options->verbose)
+        if (options->verbose > 0)
             HDprintf(" <%s>", name);
 
         /* the input object names are present in the file and are valid */
         if (h5trav_getindext(name, travt) < 0)
             H5TOOLS_GOTO_ERROR((-1), "%s Could not find <%s> in file <%s>. Exiting...\n",
-                    (options->verbose ? "\n" : ""), name, fname);
-        if (options->verbose)
+                               (options->verbose > 0 ? "\n" : ""), name, fname);
+        if (options->verbose > 0)
             HDprintf("...Found\n");
 
         for (ifil = 0; ifil < obj.nfilters; ifil++) {
@@ -795,14 +833,13 @@ check_objects(const char* fname, pack_opt_t *options)
                 H5TOOLS_GOTO_ERROR((-1), "invalid filter");
             /* check for extra filter conditions */
             switch (obj.filter[ifil].filtn) {
-            /* chunk size must be smaller than pixels per block */
-            case H5Z_FILTER_SZIP:
-                {
-                    int j;
-                    hsize_t csize = 1;
-                    unsigned ppb = obj.filter[ifil].cd_values[0];
-                    hsize_t dims[H5S_MAX_RANK];
-                    int rank;
+                /* chunk size must be smaller than pixels per block */
+                case H5Z_FILTER_SZIP: {
+                    int      j;
+                    hsize_t  csize = 1;
+                    unsigned ppb   = obj.filter[ifil].cd_values[0];
+                    hsize_t  dims[H5S_MAX_RANK];
+                    int      rank;
 
                     if (obj.chunk.rank > 0) {
                         rank = obj.chunk.rank;
@@ -833,18 +870,20 @@ check_objects(const char* fname, pack_opt_t *options)
                     }
                 } /* end case SZIP */
                 break;
-            default:
-                break;
+                default:
+                    break;
             } /* end switch */
-        } /* for ifil (each user-defined filter) */
-    } /* for i (each object in options traversal table) */
+        }     /* for ifil (each user-defined filter) */
+    }         /* for i (each object in options traversal table) */
 
 done:
-    H5E_BEGIN_TRY {
+    H5E_BEGIN_TRY
+    {
         H5Sclose(sid);
         H5Dclose(did);
         H5Fclose(fid);
-    } H5E_END_TRY;
+    }
+    H5E_END_TRY;
     if (travt)
         trav_table_free(travt);
     return ret_value;
@@ -898,4 +937,3 @@ get_sfilter(H5Z_filter_t filtn)
     else
         return "UD";
 } /* end get_sfilter() */
-
